Class: Google::Apis::SqladminV1beta4::ConnectPoolNodeConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Details of a single read pool node of a read pool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConnectPoolNodeConfig

Returns a new instance of ConnectPoolNodeConfig.



878
879
880
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 878

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dns_nameString

Output only. The DNS name of the read pool node. Corresponds to the JSON property dnsName

Returns:

  • (String)


860
861
862
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 860

def dns_name
  @dns_name
end

#dns_namesArray<Google::Apis::SqladminV1beta4::DnsNameMapping>

Output only. The list of DNS names used by this read pool node. Corresponds to the JSON property dnsNames



865
866
867
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 865

def dns_names
  @dns_names
end

#ip_addressesArray<Google::Apis::SqladminV1beta4::IpMapping>

Output only. Mappings containing IP addresses that can be used to connect to the read pool node. Corresponds to the JSON property ipAddresses



871
872
873
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 871

def ip_addresses
  @ip_addresses
end

#nameString

Output only. The name of the read pool node. Doesn't include the project ID. Corresponds to the JSON property name

Returns:

  • (String)


876
877
878
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 876

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



883
884
885
886
887
888
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 883

def update!(**args)
  @dns_name = args[:dns_name] if args.key?(:dns_name)
  @dns_names = args[:dns_names] if args.key?(:dns_names)
  @ip_addresses = args[:ip_addresses] if args.key?(:ip_addresses)
  @name = args[:name] if args.key?(:name)
end