Class: Google::Apis::SqladminV1beta4::ConnectionPoolFlags

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Connection pool flags for Cloud SQL instances managed connection pool configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConnectionPoolFlags

Returns a new instance of ConnectionPoolFlags.



1050
1051
1052
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1050

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Required. The name of the flag. Corresponds to the JSON property name

Returns:

  • (String)


1042
1043
1044
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1042

def name
  @name
end

#valueString

Required. The value of the flag. Boolean flags are set to on for true and off for false. This field must be omitted if the flag doesn't take a value. Corresponds to the JSON property value

Returns:

  • (String)


1048
1049
1050
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1048

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1055
1056
1057
1058
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1055

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @value = args[:value] if args.key?(:value)
end