Class: Google::Apis::SqladminV1beta4::ExportContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Database instance export context.

Defined Under Namespace

Classes: BakExportOptions, CsvExportOptions, SqlExportOptions, TdeExportOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExportContext

Returns a new instance of ExportContext.



2047
2048
2049
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2047

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bak_export_optionsGoogle::Apis::SqladminV1beta4::ExportContext::BakExportOptions

Options for exporting BAK files (SQL Server-only) Corresponds to the JSON property bakExportOptions



1990
1991
1992
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1990

def bak_export_options
  @bak_export_options
end

#csv_export_optionsGoogle::Apis::SqladminV1beta4::ExportContext::CsvExportOptions

Options for exporting data as CSV. MySQL and PostgreSQL instances only. Corresponds to the JSON property csvExportOptions



1995
1996
1997
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1995

def csv_export_options
  @csv_export_options
end

#databasesArray<String>

Databases to be exported. MySQL instances: If fileType is SQL and no database is specified, all databases are exported, except for the mysql system database. If fileType is CSV, you can specify one database, either by using this property or by using the csvExportOptions.selectQuery property, which takes precedence over this property. PostgreSQL instances: If you don' t specify a database by name, all user databases in the instance are exported. This excludes system databases and Cloud SQL databases used to manage internal operations. Exporting all user databases is only available for directory- formatted parallel export. If fileType is CSV, this database must match the one specified in the csvExportOptions.selectQuery property. SQL Server instances: You must specify one database to be exported, and the fileType must be BAK. Corresponds to the JSON property databases

Returns:

  • (Array<String>)


2011
2012
2013
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2011

def databases
  @databases
end

#file_typeString

The file type for the specified uri. Corresponds to the JSON property fileType

Returns:

  • (String)


2016
2017
2018
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2016

def file_type
  @file_type
end

#kindString

This is always sql#exportContext. Corresponds to the JSON property kind

Returns:

  • (String)


2021
2022
2023
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2021

def kind
  @kind
end

#offloadBoolean Also known as: offload?

Whether to perform a serverless export. Corresponds to the JSON property offload

Returns:

  • (Boolean)


2026
2027
2028
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2026

def offload
  @offload
end

#sql_export_optionsGoogle::Apis::SqladminV1beta4::ExportContext::SqlExportOptions

Options for exporting data as SQL statements. Corresponds to the JSON property sqlExportOptions



2032
2033
2034
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2032

def sql_export_options
  @sql_export_options
end

#tde_export_optionsGoogle::Apis::SqladminV1beta4::ExportContext::TdeExportOptions

Optional. Export parameters specific to SQL Server TDE certificates Corresponds to the JSON property tdeExportOptions



2037
2038
2039
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2037

def tde_export_options
  @tde_export_options
end

#uriString

The path to the file in Google Cloud Storage where the export will be stored. The URI is in the form gs://bucketName/fileName. If the file already exists, the request succeeds, but the operation fails. If fileType is SQL and the filename ends with .gz, the contents are compressed. Corresponds to the JSON property uri

Returns:

  • (String)


2045
2046
2047
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2045

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2052
2053
2054
2055
2056
2057
2058
2059
2060
2061
2062
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2052

def update!(**args)
  @bak_export_options = args[:bak_export_options] if args.key?(:bak_export_options)
  @csv_export_options = args[:csv_export_options] if args.key?(:csv_export_options)
  @databases = args[:databases] if args.key?(:databases)
  @file_type = args[:file_type] if args.key?(:file_type)
  @kind = args[:kind] if args.key?(:kind)
  @offload = args[:offload] if args.key?(:offload)
  @sql_export_options = args[:sql_export_options] if args.key?(:sql_export_options)
  @tde_export_options = args[:tde_export_options] if args.key?(:tde_export_options)
  @uri = args[:uri] if args.key?(:uri)
end