Class: Google::Apis::SqladminV1beta4::ExportContext::CsvExportOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Options for exporting data as CSV. MySQL and PostgreSQL instances only.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CsvExportOptions

Returns a new instance of CsvExportOptions.



2135
2136
2137
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2135

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#escape_characterString

Specifies the character that should appear before a data character that needs to be escaped. Corresponds to the JSON property escapeCharacter

Returns:

  • (String)


2111
2112
2113
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2111

def escape_character
  @escape_character
end

#fields_terminated_byString

Specifies the character that separates columns within each row (line) of the file. Corresponds to the JSON property fieldsTerminatedBy

Returns:

  • (String)


2117
2118
2119
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2117

def fields_terminated_by
  @fields_terminated_by
end

#lines_terminated_byString

This is used to separate lines. If a line does not contain all fields, the rest of the columns are set to their default values. Corresponds to the JSON property linesTerminatedBy

Returns:

  • (String)


2123
2124
2125
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2123

def lines_terminated_by
  @lines_terminated_by
end

#quote_characterString

Specifies the quoting character to be used when a data value is quoted. Corresponds to the JSON property quoteCharacter

Returns:

  • (String)


2128
2129
2130
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2128

def quote_character
  @quote_character
end

#select_queryString

The select query used to extract the data. Corresponds to the JSON property selectQuery

Returns:

  • (String)


2133
2134
2135
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2133

def select_query
  @select_query
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2140
2141
2142
2143
2144
2145
2146
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2140

def update!(**args)
  @escape_character = args[:escape_character] if args.key?(:escape_character)
  @fields_terminated_by = args[:fields_terminated_by] if args.key?(:fields_terminated_by)
  @lines_terminated_by = args[:lines_terminated_by] if args.key?(:lines_terminated_by)
  @quote_character = args[:quote_character] if args.key?(:quote_character)
  @select_query = args[:select_query] if args.key?(:select_query)
end