Class: Google::Apis::SqladminV1beta4::ExportContext::TdeExportOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Optional. Export parameters specific to SQL Server TDE certificates

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TdeExportOptions

Returns a new instance of TdeExportOptions.



2282
2283
2284
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2282

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#certificate_pathString

Required. Path to the TDE certificate public key in the form gs://bucketName/ fileName. The instance must have write access to the location. Applicable only for SQL Server instances. Corresponds to the JSON property certificatePath

Returns:

  • (String)


2263
2264
2265
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2263

def certificate_path
  @certificate_path
end

#nameString

Required. Certificate name. Applicable only for SQL Server instances. Corresponds to the JSON property name

Returns:

  • (String)


2268
2269
2270
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2268

def name
  @name
end

#private_key_passwordString

Required. Password that encrypts the private key. Corresponds to the JSON property privateKeyPassword

Returns:

  • (String)


2273
2274
2275
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2273

def private_key_password
  @private_key_password
end

#private_key_pathString

Required. Path to the TDE certificate private key in the form gs://bucketName/ fileName. The instance must have write access to the location. Applicable only for SQL Server instances. Corresponds to the JSON property privateKeyPath

Returns:

  • (String)


2280
2281
2282
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2280

def private_key_path
  @private_key_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2287
2288
2289
2290
2291
2292
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2287

def update!(**args)
  @certificate_path = args[:certificate_path] if args.key?(:certificate_path)
  @name = args[:name] if args.key?(:name)
  @private_key_password = args[:private_key_password] if args.key?(:private_key_password)
  @private_key_path = args[:private_key_path] if args.key?(:private_key_path)
end