Class: Google::Apis::SqladminV1beta4::FinalBackupConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Config used to determine the final backup settings for the instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FinalBackupConfig

Returns a new instance of FinalBackupConfig.



2378
2379
2380
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2378

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

Whether the final backup is enabled for the instance. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


2369
2370
2371
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2369

def enabled
  @enabled
end

#retention_daysFixnum

The number of days to retain the final backup after the instance deletion. The final backup will be purged at (time_of_instance_deletion + retention_days). Corresponds to the JSON property retentionDays

Returns:

  • (Fixnum)


2376
2377
2378
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2376

def retention_days
  @retention_days
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2383
2384
2385
2386
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2383

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
  @retention_days = args[:retention_days] if args.key?(:retention_days)
end