Class: Google::Apis::SqladminV1beta4::Flag

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

A flag resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Flag

Returns a new instance of Flag.



2450
2451
2452
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2450

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_int_valuesArray<Fixnum>

Use this field if only certain integers are accepted. Can be combined with min_value and max_value to add additional values. Corresponds to the JSON property allowedIntValues

Returns:

  • (Array<Fixnum>)


2376
2377
2378
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2376

def allowed_int_values
  @allowed_int_values
end

#allowed_string_valuesArray<String>

For STRING flags, a list of strings that the value can be set to. Corresponds to the JSON property allowedStringValues

Returns:

  • (Array<String>)


2381
2382
2383
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2381

def allowed_string_values
  @allowed_string_values
end

#applies_toArray<String>

The database version this flag applies to. Can be MySQL instances: MYSQL_8_0, MYSQL_8_0_18, MYSQL_8_0_26, MYSQL_5_7, or MYSQL_5_6. PostgreSQL instances: POSTGRES_9_6, POSTGRES_10, POSTGRES_11 or POSTGRES_12. SQL Server instances: SQLSERVER_2017_STANDARD, SQLSERVER_2017_ENTERPRISE, SQLSERVER_2017_EXPRESS, SQLSERVER_2017_WEB, SQLSERVER_2019_STANDARD, SQLSERVER_2019_ENTERPRISE, SQLSERVER_2019_EXPRESS, or SQLSERVER_2019_WEB. See the complete list. Corresponds to the JSON property appliesTo

Returns:

  • (Array<String>)


2392
2393
2394
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2392

def applies_to
  @applies_to
end

#flag_scopeString

Scope of flag. Corresponds to the JSON property flagScope

Returns:

  • (String)


2397
2398
2399
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2397

def flag_scope
  @flag_scope
end

#in_betaBoolean Also known as: in_beta?

Whether or not the flag is considered in beta. Corresponds to the JSON property inBeta

Returns:

  • (Boolean)


2402
2403
2404
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2402

def in_beta
  @in_beta
end

#kindString

This is always sql#flag. Corresponds to the JSON property kind

Returns:

  • (String)


2408
2409
2410
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2408

def kind
  @kind
end

#max_valueFixnum

For INTEGER flags, the maximum allowed value. Corresponds to the JSON property maxValue

Returns:

  • (Fixnum)


2413
2414
2415
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2413

def max_value
  @max_value
end

#min_valueFixnum

For INTEGER flags, the minimum allowed value. Corresponds to the JSON property minValue

Returns:

  • (Fixnum)


2418
2419
2420
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2418

def min_value
  @min_value
end

#nameString

This is the name of the flag. Flag names always use underscores, not hyphens, for example: max_allowed_packet Corresponds to the JSON property name

Returns:

  • (String)


2424
2425
2426
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2424

def name
  @name
end

Recommended flag value in integer format for UI display. Corresponds to the JSON property recommendedIntValue

Returns:

  • (Fixnum)


2429
2430
2431
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2429

def recommended_int_value
  @recommended_int_value
end

Recommended flag value in string format for UI display. Corresponds to the JSON property recommendedStringValue

Returns:

  • (String)


2434
2435
2436
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2434

def recommended_string_value
  @recommended_string_value
end

#requires_restartBoolean Also known as: requires_restart?

Indicates whether changing this flag will trigger a database restart. Only applicable to Second Generation instances. Corresponds to the JSON property requiresRestart

Returns:

  • (Boolean)


2440
2441
2442
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2440

def requires_restart
  @requires_restart
end

#typeString

The type of the flag. Flags are typed to being BOOLEAN, STRING, INTEGER or NONE. NONE is used for flags which do not take a value, such as skip_grant_tables. Corresponds to the JSON property type

Returns:

  • (String)


2448
2449
2450
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2448

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2455
2456
2457
2458
2459
2460
2461
2462
2463
2464
2465
2466
2467
2468
2469
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2455

def update!(**args)
  @allowed_int_values = args[:allowed_int_values] if args.key?(:allowed_int_values)
  @allowed_string_values = args[:allowed_string_values] if args.key?(:allowed_string_values)
  @applies_to = args[:applies_to] if args.key?(:applies_to)
  @flag_scope = args[:flag_scope] if args.key?(:flag_scope)
  @in_beta = args[:in_beta] if args.key?(:in_beta)
  @kind = args[:kind] if args.key?(:kind)
  @max_value = args[:max_value] if args.key?(:max_value)
  @min_value = args[:min_value] if args.key?(:min_value)
  @name = args[:name] if args.key?(:name)
  @recommended_int_value = args[:recommended_int_value] if args.key?(:recommended_int_value)
  @recommended_string_value = args[:recommended_string_value] if args.key?(:recommended_string_value)
  @requires_restart = args[:requires_restart] if args.key?(:requires_restart)
  @type = args[:type] if args.key?(:type)
end