Class: Google::Apis::SqladminV1beta4::ImportContext
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::ImportContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
Database instance import context.
Defined Under Namespace
Classes: BakImportOptions, CsvImportOptions, SqlImportOptions, TdeImportOptions
Instance Attribute Summary collapse
-
#bak_import_options ⇒ Google::Apis::SqladminV1beta4::ImportContext::BakImportOptions
Import parameters specific to SQL Server .BAK files Corresponds to the JSON property
bakImportOptions. -
#csv_import_options ⇒ Google::Apis::SqladminV1beta4::ImportContext::CsvImportOptions
Options for importing data as CSV.
-
#database ⇒ String
The target database for the import.
-
#file_type ⇒ String
The file type for the specified uri.
-
#import_user ⇒ String
The PostgreSQL user for this import operation.
-
#kind ⇒ String
This is always
sql#importContext. -
#sql_import_options ⇒ Google::Apis::SqladminV1beta4::ImportContext::SqlImportOptions
Optional.
-
#tde_import_options ⇒ Google::Apis::SqladminV1beta4::ImportContext::TdeImportOptions
Optional.
-
#uri ⇒ String
Path to the import file in Cloud Storage, in the form
gs://bucketName/ fileName.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImportContext
constructor
A new instance of ImportContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ImportContext
Returns a new instance of ImportContext.
2697 2698 2699 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2697 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bak_import_options ⇒ Google::Apis::SqladminV1beta4::ImportContext::BakImportOptions
Import parameters specific to SQL Server .BAK files
Corresponds to the JSON property bakImportOptions
2644 2645 2646 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2644 def @bak_import_options end |
#csv_import_options ⇒ Google::Apis::SqladminV1beta4::ImportContext::CsvImportOptions
Options for importing data as CSV.
Corresponds to the JSON property csvImportOptions
2649 2650 2651 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2649 def @csv_import_options end |
#database ⇒ String
The target database for the import. If fileType is SQL, this field is
required only if the import file does not specify a database, and is
overridden by any database specification in the import file. For entire
instance parallel import operations, the database is overridden by the
database name stored in subdirectory name. If fileType is CSV, one
database must be specified.
Corresponds to the JSON property database
2659 2660 2661 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2659 def database @database end |
#file_type ⇒ String
The file type for the specified uri. * SQL: The file contains SQL statements.
CSV: The file contains CSV data. *BAK: The file contains backup data for a SQL Server instance. Corresponds to the JSON propertyfileType
2666 2667 2668 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2666 def file_type @file_type end |
#import_user ⇒ String
The PostgreSQL user for this import operation. PostgreSQL instances only.
Corresponds to the JSON property importUser
2671 2672 2673 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2671 def import_user @import_user end |
#kind ⇒ String
This is always sql#importContext.
Corresponds to the JSON property kind
2676 2677 2678 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2676 def kind @kind end |
#sql_import_options ⇒ Google::Apis::SqladminV1beta4::ImportContext::SqlImportOptions
Optional. Options for importing data from SQL statements.
Corresponds to the JSON property sqlImportOptions
2681 2682 2683 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2681 def @sql_import_options end |
#tde_import_options ⇒ Google::Apis::SqladminV1beta4::ImportContext::TdeImportOptions
Optional. Import parameters specific to SQL Server .TDE files Import
parameters specific to SQL Server TDE certificates
Corresponds to the JSON property tdeImportOptions
2687 2688 2689 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2687 def @tde_import_options end |
#uri ⇒ String
Path to the import file in Cloud Storage, in the form gs://bucketName/
fileName. Compressed gzip files (.gz) are supported when fileType is SQL.
The instance must have write permissions to the bucket and read access to the
file.
Corresponds to the JSON property uri
2695 2696 2697 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2695 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2702 2703 2704 2705 2706 2707 2708 2709 2710 2711 2712 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2702 def update!(**args) @bak_import_options = args[:bak_import_options] if args.key?(:bak_import_options) @csv_import_options = args[:csv_import_options] if args.key?(:csv_import_options) @database = args[:database] if args.key?(:database) @file_type = args[:file_type] if args.key?(:file_type) @import_user = args[:import_user] if args.key?(:import_user) @kind = args[:kind] if args.key?(:kind) @sql_import_options = args[:sql_import_options] if args.key?(:sql_import_options) @tde_import_options = args[:tde_import_options] if args.key?(:tde_import_options) @uri = args[:uri] if args.key?(:uri) end |