Class: Google::Apis::SqladminV1beta4::ImportContext::BakImportOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Import parameters specific to SQL Server .BAK files

Defined Under Namespace

Classes: EncryptionOptions

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BakImportOptions

Returns a new instance of BakImportOptions.



2766
2767
2768
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2766

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bak_typeString

Type of the bak content, FULL or DIFF. Corresponds to the JSON property bakType

Returns:

  • (String)


2721
2722
2723
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2721

def bak_type
  @bak_type
end

#encryption_optionsGoogle::Apis::SqladminV1beta4::ImportContext::BakImportOptions::EncryptionOptions

Corresponds to the JSON property encryptionOptions



2726
2727
2728
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2726

def encryption_options
  @encryption_options
end

#no_recoveryBoolean Also known as: no_recovery?

Whether or not the backup importing will restore database with NORECOVERY option. Applies only to Cloud SQL for SQL Server. Corresponds to the JSON property noRecovery

Returns:

  • (Boolean)


2732
2733
2734
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2732

def no_recovery
  @no_recovery
end

#recovery_onlyBoolean Also known as: recovery_only?

Whether or not the backup importing request will just bring database online without downloading Bak content only one of "no_recovery" and "recovery_only" can be true otherwise error will return. Applies only to Cloud SQL for SQL Server. Corresponds to the JSON property recoveryOnly

Returns:

  • (Boolean)


2741
2742
2743
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2741

def recovery_only
  @recovery_only
end

#stop_atString

Optional. The timestamp when the import should stop. This timestamp is in the RFC 3339 format (for example, 2023-10- 01T16:19:00.094). This field is equivalent to the STOPAT keyword and applies to Cloud SQL for SQL Server only. Corresponds to the JSON property stopAt

Returns:

  • (String)


2750
2751
2752
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2750

def stop_at
  @stop_at
end

#stop_at_markString

Optional. The marked transaction where the import should stop. This field is equivalent to the STOPATMARK keyword and applies to Cloud SQL for SQL Server only. Corresponds to the JSON property stopAtMark

Returns:

  • (String)


2757
2758
2759
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2757

def stop_at_mark
  @stop_at_mark
end

#stripedBoolean Also known as: striped?

Whether or not the backup set being restored is striped. Applies only to Cloud SQL for SQL Server. Corresponds to the JSON property striped

Returns:

  • (Boolean)


2763
2764
2765
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2763

def striped
  @striped
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2771
2772
2773
2774
2775
2776
2777
2778
2779
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2771

def update!(**args)
  @bak_type = args[:bak_type] if args.key?(:bak_type)
  @encryption_options = args[:encryption_options] if args.key?(:encryption_options)
  @no_recovery = args[:no_recovery] if args.key?(:no_recovery)
  @recovery_only = args[:recovery_only] if args.key?(:recovery_only)
  @stop_at = args[:stop_at] if args.key?(:stop_at)
  @stop_at_mark = args[:stop_at_mark] if args.key?(:stop_at_mark)
  @striped = args[:striped] if args.key?(:striped)
end