Class: Google::Apis::SqladminV1beta4::ImportContext::CsvImportOptions
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::ImportContext::CsvImportOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
Options for importing data as CSV.
Instance Attribute Summary collapse
-
#columns ⇒ Array<String>
The columns to which CSV data is imported.
-
#escape_character ⇒ String
Specifies the character that should appear before a data character that needs to be escaped.
-
#fields_terminated_by ⇒ String
Specifies the character that separates columns within each row (line) of the file.
-
#lines_terminated_by ⇒ String
This is used to separate lines.
-
#quote_character ⇒ String
Specifies the quoting character to be used when a data value is quoted.
-
#table ⇒ String
The table to which CSV data is imported.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CsvImportOptions
constructor
A new instance of CsvImportOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CsvImportOptions
Returns a new instance of CsvImportOptions.
2862 2863 2864 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2862 def initialize(**args) update!(**args) end |
Instance Attribute Details
#columns ⇒ Array<String>
The columns to which CSV data is imported. If not specified, all columns of
the database table are loaded with CSV data.
Corresponds to the JSON property columns
2832 2833 2834 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2832 def columns @columns end |
#escape_character ⇒ String
Specifies the character that should appear before a data character that needs
to be escaped.
Corresponds to the JSON property escapeCharacter
2838 2839 2840 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2838 def escape_character @escape_character end |
#fields_terminated_by ⇒ String
Specifies the character that separates columns within each row (line) of the
file.
Corresponds to the JSON property fieldsTerminatedBy
2844 2845 2846 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2844 def fields_terminated_by @fields_terminated_by end |
#lines_terminated_by ⇒ String
This is used to separate lines. If a line does not contain all fields, the
rest of the columns are set to their default values.
Corresponds to the JSON property linesTerminatedBy
2850 2851 2852 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2850 def lines_terminated_by @lines_terminated_by end |
#quote_character ⇒ String
Specifies the quoting character to be used when a data value is quoted.
Corresponds to the JSON property quoteCharacter
2855 2856 2857 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2855 def quote_character @quote_character end |
#table ⇒ String
The table to which CSV data is imported.
Corresponds to the JSON property table
2860 2861 2862 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2860 def table @table end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2867 2868 2869 2870 2871 2872 2873 2874 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2867 def update!(**args) @columns = args[:columns] if args.key?(:columns) @escape_character = args[:escape_character] if args.key?(:escape_character) @fields_terminated_by = args[:fields_terminated_by] if args.key?(:fields_terminated_by) @lines_terminated_by = args[:lines_terminated_by] if args.key?(:lines_terminated_by) @quote_character = args[:quote_character] if args.key?(:quote_character) @table = args[:table] if args.key?(:table) end |