Class: Google::Apis::SqladminV1beta4::ImportContext::TdeImportOptions
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::ImportContext::TdeImportOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
Optional. Import parameters specific to SQL Server .TDE files Import parameters specific to SQL Server TDE certificates
Instance Attribute Summary collapse
-
#certificate_path ⇒ String
Required.
-
#name ⇒ String
Required.
-
#private_key_password ⇒ String
Required.
-
#private_key_path ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TdeImportOptions
constructor
A new instance of TdeImportOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TdeImportOptions
Returns a new instance of TdeImportOptions.
2938 2939 2940 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2938 def initialize(**args) update!(**args) end |
Instance Attribute Details
#certificate_path ⇒ String
Required. Path to the TDE certificate public key in the form gs://bucketName/
fileName. The instance must have read access to the file. Applicable only for
SQL Server instances.
Corresponds to the JSON property certificatePath
2919 2920 2921 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2919 def certificate_path @certificate_path end |
#name ⇒ String
Required. Certificate name. Applicable only for SQL Server instances.
Corresponds to the JSON property name
2924 2925 2926 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2924 def name @name end |
#private_key_password ⇒ String
Required. Password that encrypts the private key.
Corresponds to the JSON property privateKeyPassword
2929 2930 2931 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2929 def private_key_password @private_key_password end |
#private_key_path ⇒ String
Required. Path to the TDE certificate private key in the form gs://bucketName/
fileName. The instance must have read access to the file. Applicable only for
SQL Server instances.
Corresponds to the JSON property privateKeyPath
2936 2937 2938 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2936 def private_key_path @private_key_path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2943 2944 2945 2946 2947 2948 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2943 def update!(**args) @certificate_path = args[:certificate_path] if args.key?(:certificate_path) @name = args[:name] if args.key?(:name) @private_key_password = args[:private_key_password] if args.key?(:private_key_password) @private_key_path = args[:private_key_path] if args.key?(:private_key_path) end |