Class: Google::Apis::SqladminV1beta4::InsertSslCertsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

SslCert insert response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InsertSslCertsResponse

Returns a new instance of InsertSslCertsResponse.



6464
6465
6466
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6464

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_certGoogle::Apis::SqladminV1beta4::SslCertDetail

SslCertDetail. Corresponds to the JSON property clientCert



6445
6446
6447
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6445

def client_cert
  @client_cert
end

#kindString

This is always sql#sslCertsInsert. Corresponds to the JSON property kind

Returns:

  • (String)


6450
6451
6452
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6450

def kind
  @kind
end

#operationGoogle::Apis::SqladminV1beta4::Operation

An Operation resource. For successful operations that return an Operation resource, only the fields relevant to the operation are populated in the resource. Corresponds to the JSON property operation



6457
6458
6459
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6457

def operation
  @operation
end

#server_ca_certGoogle::Apis::SqladminV1beta4::SslCert

SslCerts Resource Corresponds to the JSON property serverCaCert



6462
6463
6464
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6462

def server_ca_cert
  @server_ca_cert
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6469
6470
6471
6472
6473
6474
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6469

def update!(**args)
  @client_cert = args[:client_cert] if args.key?(:client_cert)
  @kind = args[:kind] if args.key?(:kind)
  @operation = args[:operation] if args.key?(:operation)
  @server_ca_cert = args[:server_ca_cert] if args.key?(:server_ca_cert)
end