Class: Google::Apis::SqladminV1beta4::InstancesListServerCertificatesResponse
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::InstancesListServerCertificatesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
Instances ListServerCertificatess response.
Instance Attribute Summary collapse
-
#active_version ⇒ String
The
sha1_fingerprintof the active certificate fromserver_certs. -
#ca_certs ⇒ Array<Google::Apis::SqladminV1beta4::SslCert>
List of server CA certificates for the instance.
-
#kind ⇒ String
This is always
sql#instancesListServerCertificates. -
#server_certs ⇒ Array<Google::Apis::SqladminV1beta4::SslCert>
List of server certificates for the instance, signed by the corresponding CA from the
ca_certslist.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstancesListServerCertificatesResponse
constructor
A new instance of InstancesListServerCertificatesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstancesListServerCertificatesResponse
Returns a new instance of InstancesListServerCertificatesResponse.
3303 3304 3305 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3303 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_version ⇒ String
The sha1_fingerprint of the active certificate from server_certs.
Corresponds to the JSON property activeVersion
3285 3286 3287 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3285 def active_version @active_version end |
#ca_certs ⇒ Array<Google::Apis::SqladminV1beta4::SslCert>
List of server CA certificates for the instance.
Corresponds to the JSON property caCerts
3290 3291 3292 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3290 def ca_certs @ca_certs end |
#kind ⇒ String
This is always sql#instancesListServerCertificates.
Corresponds to the JSON property kind
3295 3296 3297 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3295 def kind @kind end |
#server_certs ⇒ Array<Google::Apis::SqladminV1beta4::SslCert>
List of server certificates for the instance, signed by the corresponding CA
from the ca_certs list.
Corresponds to the JSON property serverCerts
3301 3302 3303 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3301 def server_certs @server_certs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3308 3309 3310 3311 3312 3313 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3308 def update!(**args) @active_version = args[:active_version] if args.key?(:active_version) @ca_certs = args[:ca_certs] if args.key?(:ca_certs) @kind = args[:kind] if args.key?(:kind) @server_certs = args[:server_certs] if args.key?(:server_certs) end |