Class: Google::Apis::SqladminV1beta4::IpMapping

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Database instance IP mapping

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IpMapping

Returns a new instance of IpMapping.



3620
3621
3622
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3620

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_addressString

The IP address assigned. Corresponds to the JSON property ipAddress

Returns:

  • (String)


3603
3604
3605
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3603

def ip_address
  @ip_address
end

#time_to_retireString

The due time for this IP to be retired in RFC 3339 format, for example 2012-11-15T16:19:00.094Z. This field is only available when the IP is scheduled to be retired. Corresponds to the JSON property timeToRetire

Returns:

  • (String)


3610
3611
3612
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3610

def time_to_retire
  @time_to_retire
end

#typeString

The type of this IP address. A PRIMARY address is a public address that can accept incoming connections. A PRIVATE address is a private address that can accept incoming connections. An OUTGOING address is the source address of connections originating from the instance, if supported. Corresponds to the JSON property type

Returns:

  • (String)


3618
3619
3620
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3618

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3625
3626
3627
3628
3629
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3625

def update!(**args)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @time_to_retire = args[:time_to_retire] if args.key?(:time_to_retire)
  @type = args[:type] if args.key?(:type)
end