Class: Google::Apis::SqladminV1beta4::ListInstancesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Database instances list response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListInstancesResponse

Returns a new instance of ListInstancesResponse.



3263
3264
3265
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3263

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#itemsArray<Google::Apis::SqladminV1beta4::DatabaseInstance>

List of database instance resources. Corresponds to the JSON property items



3245
3246
3247
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3245

def items
  @items
end

#kindString

This is always sql#instancesList. Corresponds to the JSON property kind

Returns:

  • (String)


3250
3251
3252
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3250

def kind
  @kind
end

#next_page_tokenString

The continuation token, used to page through large result sets. Provide this value in a subsequent request to return the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3256
3257
3258
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3256

def next_page_token
  @next_page_token
end

#warningsArray<Google::Apis::SqladminV1beta4::ApiWarning>

List of warnings that occurred while handling the request. Corresponds to the JSON property warnings



3261
3262
3263
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3261

def warnings
  @warnings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3268
3269
3270
3271
3272
3273
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3268

def update!(**args)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warnings = args[:warnings] if args.key?(:warnings)
end