Class: Google::Apis::SqladminV1beta4::ListOperationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Operations list response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListOperationsResponse

Returns a new instance of ListOperationsResponse.



4336
4337
4338
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4336

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#itemsArray<Google::Apis::SqladminV1beta4::Operation>

List of operation resources. Corresponds to the JSON property items



4323
4324
4325
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4323

def items
  @items
end

#kindString

This is always sql#operationsList. Corresponds to the JSON property kind

Returns:

  • (String)


4328
4329
4330
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4328

def kind
  @kind
end

#next_page_tokenString

The continuation token, used to page through large result sets. Provide this value in a subsequent request to return the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4334
4335
4336
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4334

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4341
4342
4343
4344
4345
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4341

def update!(**args)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end