Class: Google::Apis::SqladminV1beta4::Message

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Represents a notice or warning message from the database.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Message

Returns a new instance of Message.



3767
3768
3769
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3767

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#messageString

The full message string. For PostgreSQL, this is a formatted string that may include severity, code, and the notice/warning message. For MySQL, this contains the warning message. Corresponds to the JSON property message

Returns:

  • (String)


3759
3760
3761
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3759

def message
  @message
end

#severityString

The severity of the message (e.g., "NOTICE" for PostgreSQL, "WARNING" for MySQL). Corresponds to the JSON property severity

Returns:

  • (String)


3765
3766
3767
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3765

def severity
  @severity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3772
3773
3774
3775
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3772

def update!(**args)
  @message = args[:message] if args.key?(:message)
  @severity = args[:severity] if args.key?(:severity)
end