Class: Google::Apis::SqladminV1beta4::MySqlReplicaConfiguration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Read-replica configuration specific to MySQL databases.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MySqlReplicaConfiguration

Returns a new instance of MySqlReplicaConfiguration.



3902
3903
3904
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3902

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ca_certificateString

PEM representation of the trusted CA's x509 certificate. Corresponds to the JSON property caCertificate

Returns:

  • (String)


3843
3844
3845
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3843

def ca_certificate
  @ca_certificate
end

#client_certificateString

PEM representation of the replica's x509 certificate. Corresponds to the JSON property clientCertificate

Returns:

  • (String)


3848
3849
3850
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3848

def client_certificate
  @client_certificate
end

#client_keyString

PEM representation of the replica's private key. The corresponding public key is encoded in the client's certificate. Corresponds to the JSON property clientKey

Returns:

  • (String)


3854
3855
3856
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3854

def client_key
  @client_key
end

#connect_retry_intervalFixnum

Seconds to wait between connect retries. MySQL's default is 60 seconds. Corresponds to the JSON property connectRetryInterval

Returns:

  • (Fixnum)


3859
3860
3861
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3859

def connect_retry_interval
  @connect_retry_interval
end

#dump_file_pathString

Path to a SQL dump file in Google Cloud Storage from which the replica instance is to be created. The URI is in the form gs://bucketName/fileName. Compressed gzip files (.gz) are also supported. Dumps have the binlog co- ordinates from which replication begins. This can be accomplished by setting -- master-data to 1 when using mysqldump. Corresponds to the JSON property dumpFilePath

Returns:

  • (String)


3868
3869
3870
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3868

def dump_file_path
  @dump_file_path
end

#kindString

This is always sql#mysqlReplicaConfiguration. Corresponds to the JSON property kind

Returns:

  • (String)


3873
3874
3875
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3873

def kind
  @kind
end

#master_heartbeat_periodFixnum

Interval in milliseconds between replication heartbeats. Corresponds to the JSON property masterHeartbeatPeriod

Returns:

  • (Fixnum)


3878
3879
3880
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3878

def master_heartbeat_period
  @master_heartbeat_period
end

#passwordString

The password for the replication connection. Corresponds to the JSON property password

Returns:

  • (String)


3883
3884
3885
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3883

def password
  @password
end

#ssl_cipherString

A list of permissible ciphers to use for SSL encryption. Corresponds to the JSON property sslCipher

Returns:

  • (String)


3888
3889
3890
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3888

def ssl_cipher
  @ssl_cipher
end

#usernameString

The username for the replication connection. Corresponds to the JSON property username

Returns:

  • (String)


3893
3894
3895
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3893

def username
  @username
end

#verify_server_certificateBoolean Also known as: verify_server_certificate?

Whether or not to check the primary instance's Common Name value in the certificate that it sends during the SSL handshake. Corresponds to the JSON property verifyServerCertificate

Returns:

  • (Boolean)


3899
3900
3901
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3899

def verify_server_certificate
  @verify_server_certificate
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3907
3908
3909
3910
3911
3912
3913
3914
3915
3916
3917
3918
3919
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3907

def update!(**args)
  @ca_certificate = args[:ca_certificate] if args.key?(:ca_certificate)
  @client_certificate = args[:client_certificate] if args.key?(:client_certificate)
  @client_key = args[:client_key] if args.key?(:client_key)
  @connect_retry_interval = args[:connect_retry_interval] if args.key?(:connect_retry_interval)
  @dump_file_path = args[:dump_file_path] if args.key?(:dump_file_path)
  @kind = args[:kind] if args.key?(:kind)
  @master_heartbeat_period = args[:master_heartbeat_period] if args.key?(:master_heartbeat_period)
  @password = args[:password] if args.key?(:password)
  @ssl_cipher = args[:ssl_cipher] if args.key?(:ssl_cipher)
  @username = args[:username] if args.key?(:username)
  @verify_server_certificate = args[:verify_server_certificate] if args.key?(:verify_server_certificate)
end