Class: Google::Apis::SqladminV1beta4::PerformanceCaptureConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Performance capture configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PerformanceCaptureConfig

Returns a new instance of PerformanceCaptureConfig.



4559
4560
4561
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4559

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpu_utilization_threshold_percentFixnum

Optional. Specifies the minimum percentage of CPU utilization to trigger the performance capture. Valid integers range from 10 to 99. Enter 0 to disable the check. Corresponds to the JSON property cpuUtilizationThresholdPercent

Returns:

  • (Fixnum)


4466
4467
4468
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4466

def cpu_utilization_threshold_percent
  @cpu_utilization_threshold_percent
end

#enabledBoolean Also known as: enabled?

Optional. Enables or disables the performance capture feature. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


4471
4472
4473
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4471

def enabled
  @enabled
end

#history_list_length_threshold_countFixnum

Optional. Specifies the minimum number of undo log entries in the history list length to trigger the performance capture. Valid integers range from 10000 to 10000000. Enter 0 to disable the check. Corresponds to the JSON property historyListLengthThresholdCount

Returns:

  • (Fixnum)


4479
4480
4481
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4479

def history_list_length_threshold_count
  @history_list_length_threshold_count
end

#memory_usage_threshold_percentFixnum

Optional. Specifies the minimum percentage of memory usage to trigger the performance capture. Valid integers range from 10 to 99. Enter 0 to disable the check. Corresponds to the JSON property memoryUsageThresholdPercent

Returns:

  • (Fixnum)


4486
4487
4488
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4486

def memory_usage_threshold_percent
  @memory_usage_threshold_percent
end

#probe_thresholdFixnum

Optional. Specifies the minimum number of consecutive probe threshold that triggers performance capture. Corresponds to the JSON property probeThreshold

Returns:

  • (Fixnum)


4492
4493
4494
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4492

def probe_threshold
  @probe_threshold
end

#probing_interval_secondsFixnum

Optional. Specifies the interval in seconds between consecutive probes that check if any trigger condition thresholds have been reached. Corresponds to the JSON property probingIntervalSeconds

Returns:

  • (Fixnum)


4498
4499
4500
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4498

def probing_interval_seconds
  @probing_interval_seconds
end

#running_threads_thresholdFixnum

Optional. Specifies the minimum number of MySQL Threads_running to trigger the performance capture on the primary instance. Corresponds to the JSON property runningThreadsThreshold

Returns:

  • (Fixnum)


4504
4505
4506
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4504

def running_threads_threshold
  @running_threads_threshold
end

#seconds_behind_source_thresholdFixnum

Optional. Specifies the minimum number of seconds replica must be lagging behind primary instance to trigger the performance capture on replica. Corresponds to the JSON property secondsBehindSourceThreshold

Returns:

  • (Fixnum)


4510
4511
4512
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4510

def seconds_behind_source_threshold
  @seconds_behind_source_threshold
end

#semaphore_wait_threshold_countFixnum

Optional. Specifies the minimum allowed number of semaphore waits to trigger the performance capture. Valid integers range from 10 to 10000. Enter 0 to disable the check. Corresponds to the JSON property semaphoreWaitThresholdCount

Returns:

  • (Fixnum)


4517
4518
4519
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4517

def semaphore_wait_threshold_count
  @semaphore_wait_threshold_count
end

#transaction_duration_thresholdFixnum

Optional. Specifies the amount of time in seconds that a transaction needs to have been open before the watcher starts recording it. Corresponds to the JSON property transactionDurationThreshold

Returns:

  • (Fixnum)


4523
4524
4525
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4523

def transaction_duration_threshold
  @transaction_duration_threshold
end

#transaction_kill_excluded_user_hostsArray<String>

Optional. Specifies a customer-defined list of users to exclude from transaction termination. Entries can be in the format 'user@host' or just ' user'. A standalone 'user' implies 'user@%', excluding the user from any host. Wildcard '%' is allowed in the host part of the 'user@host' format. Example: [ "app_user", "db_admin@10.1.2.3", "report_user@%"] Corresponds to the JSON property transactionKillExcludedUserHosts

Returns:

  • (Array<String>)


4532
4533
4534
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4532

def transaction_kill_excluded_user_hosts
  @transaction_kill_excluded_user_hosts
end

#transaction_kill_threshold_secondsFixnum

Optional. Specifies the amount of time in seconds that a transaction needs to have been open before the watcher starts terminating it. Valid integers range from 60 to 604800 (7 days). Enter 0 to disable. If enabled (i.e., > 0), this value must be greater than or equal to transaction_duration_threshold. Configurations where 0 < transaction_kill_threshold_seconds < transaction_duration_threshold will be rejected. Corresponds to the JSON property transactionKillThresholdSeconds

Returns:

  • (Fixnum)


4542
4543
4544
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4542

def transaction_kill_threshold_seconds
  @transaction_kill_threshold_seconds
end

#transaction_kill_typeString

Optional. Determines which transactions are allowed to be terminated when they exceed transaction_kill_threshold_seconds. This allows protecting write- heavy transactions from auto-termination if desired. Defaults to READ_ONLY_TRANSACTIONS if unspecified. Corresponds to the JSON property transactionKillType

Returns:

  • (String)


4550
4551
4552
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4550

def transaction_kill_type
  @transaction_kill_type
end

#transaction_lock_wait_threshold_countFixnum

Optional. Specifies the minimum allowed number of transactions in lock wait state to trigger the performance capture. Valid integers range from 10 to 10000. Enter 0 to disable the check. Corresponds to the JSON property transactionLockWaitThresholdCount

Returns:

  • (Fixnum)


4557
4558
4559
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4557

def transaction_lock_wait_threshold_count
  @transaction_lock_wait_threshold_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4564
4565
4566
4567
4568
4569
4570
4571
4572
4573
4574
4575
4576
4577
4578
4579
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4564

def update!(**args)
  @cpu_utilization_threshold_percent = args[:cpu_utilization_threshold_percent] if args.key?(:cpu_utilization_threshold_percent)
  @enabled = args[:enabled] if args.key?(:enabled)
  @history_list_length_threshold_count = args[:history_list_length_threshold_count] if args.key?(:history_list_length_threshold_count)
  @memory_usage_threshold_percent = args[:memory_usage_threshold_percent] if args.key?(:memory_usage_threshold_percent)
  @probe_threshold = args[:probe_threshold] if args.key?(:probe_threshold)
  @probing_interval_seconds = args[:probing_interval_seconds] if args.key?(:probing_interval_seconds)
  @running_threads_threshold = args[:running_threads_threshold] if args.key?(:running_threads_threshold)
  @seconds_behind_source_threshold = args[:seconds_behind_source_threshold] if args.key?(:seconds_behind_source_threshold)
  @semaphore_wait_threshold_count = args[:semaphore_wait_threshold_count] if args.key?(:semaphore_wait_threshold_count)
  @transaction_duration_threshold = args[:transaction_duration_threshold] if args.key?(:transaction_duration_threshold)
  @transaction_kill_excluded_user_hosts = args[:transaction_kill_excluded_user_hosts] if args.key?(:transaction_kill_excluded_user_hosts)
  @transaction_kill_threshold_seconds = args[:transaction_kill_threshold_seconds] if args.key?(:transaction_kill_threshold_seconds)
  @transaction_kill_type = args[:transaction_kill_type] if args.key?(:transaction_kill_type)
  @transaction_lock_wait_threshold_count = args[:transaction_lock_wait_threshold_count] if args.key?(:transaction_lock_wait_threshold_count)
end