Class: Google::Apis::SqladminV1beta4::PointInTimeRestoreContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Context to perform a point-in-time restore of an instance managed by Backup and Disaster Recovery (DR) Service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PointInTimeRestoreContext

Returns a new instance of PointInTimeRestoreContext.



4652
4653
4654
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4652

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allocated_ip_rangeString

Optional. The name of the allocated IP range for the internal IP Cloud SQL instance. For example: "google-managed-services-default". If you set this, then Cloud SQL creates the IP address for the cloned instance in the allocated range. This range must comply with RFC 1035 standards. Specifically, the name must be 1-63 characters long and match the regular expression a-z?. Reserved for future use. Corresponds to the JSON property allocatedIpRange

Returns:

  • (String)


4596
4597
4598
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4596

def allocated_ip_range
  @allocated_ip_range
end

#datasourceString

The Backup and Disaster Recovery (DR) Service Datasource URI. Format: projects/ project/locations/region/backupVaults/backupvault/dataSources/ datasource. Corresponds to the JSON property datasource

Returns:

  • (String)


4603
4604
4605
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4603

def datasource
  @datasource
end

#point_in_timeString

Required. The date and time to which you want to restore the instance. Corresponds to the JSON property pointInTime

Returns:

  • (String)


4608
4609
4610
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4608

def point_in_time
  @point_in_time
end

#preferred_secondary_zoneString

Optional. Point-in-time recovery of a regional instance in the specified zones. If not specified, clone to the same secondary zone as the source instance. This value cannot be the same as the preferred_zone field. Corresponds to the JSON property preferredSecondaryZone

Returns:

  • (String)


4615
4616
4617
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4615

def preferred_secondary_zone
  @preferred_secondary_zone
end

#preferred_zoneString

Optional. Point-in-time recovery of an instance to the specified zone. If no zone is specified, then clone to the same primary zone as the source instance. Corresponds to the JSON property preferredZone

Returns:

  • (String)


4621
4622
4623
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4621

def preferred_zone
  @preferred_zone
end

#private_networkString

Optional. The resource link for the VPC network from which the Cloud SQL instance is accessible for private IP. For example, /projects/myProject/ global/networks/default. Corresponds to the JSON property privateNetwork

Returns:

  • (String)


4628
4629
4630
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4628

def private_network
  @private_network
end

#regionString

Optional. The region of the target instance where the datasource will be restored. For example: "us-central1". Corresponds to the JSON property region

Returns:

  • (String)


4634
4635
4636
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4634

def region
  @region
end

#target_instanceString

Target instance name. Corresponds to the JSON property targetInstance

Returns:

  • (String)


4639
4640
4641
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4639

def target_instance
  @target_instance
end

#target_instance_clear_settings_field_namesArray<String>

Optional. Specifies the instance settings that will be cleared from the source instance. This field is only applicable for cross project PITRs. Corresponds to the JSON property targetInstanceClearSettingsFieldNames

Returns:

  • (Array<String>)


4645
4646
4647
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4645

def target_instance_clear_settings_field_names
  @target_instance_clear_settings_field_names
end

#target_instance_settingsGoogle::Apis::SqladminV1beta4::DatabaseInstance

A Cloud SQL instance resource. Corresponds to the JSON property targetInstanceSettings



4650
4651
4652
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4650

def target_instance_settings
  @target_instance_settings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4657
4658
4659
4660
4661
4662
4663
4664
4665
4666
4667
4668
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4657

def update!(**args)
  @allocated_ip_range = args[:allocated_ip_range] if args.key?(:allocated_ip_range)
  @datasource = args[:datasource] if args.key?(:datasource)
  @point_in_time = args[:point_in_time] if args.key?(:point_in_time)
  @preferred_secondary_zone = args[:preferred_secondary_zone] if args.key?(:preferred_secondary_zone)
  @preferred_zone = args[:preferred_zone] if args.key?(:preferred_zone)
  @private_network = args[:private_network] if args.key?(:private_network)
  @region = args[:region] if args.key?(:region)
  @target_instance = args[:target_instance] if args.key?(:target_instance)
  @target_instance_clear_settings_field_names = args[:target_instance_clear_settings_field_names] if args.key?(:target_instance_clear_settings_field_names)
  @target_instance_settings = args[:target_instance_settings] if args.key?(:target_instance_settings)
end