Class: Google::Apis::SqladminV1beta4::PoolNodeConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Details of a single read pool node of a read pool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PoolNodeConfig

Returns a new instance of PoolNodeConfig.



4720
4721
4722
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4720

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dns_nameString

Output only. The DNS name of the read pool node. Corresponds to the JSON property dnsName

Returns:

  • (String)


4678
4679
4680
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4678

def dns_name
  @dns_name
end

#dns_namesArray<Google::Apis::SqladminV1beta4::DnsNameMapping>

Output only. The list of DNS names used by this read pool node. Corresponds to the JSON property dnsNames



4683
4684
4685
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4683

def dns_names
  @dns_names
end

#gce_zoneString

Output only. The zone of the read pool node. Corresponds to the JSON property gceZone

Returns:

  • (String)


4688
4689
4690
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4688

def gce_zone
  @gce_zone
end

#ip_addressesArray<Google::Apis::SqladminV1beta4::IpMapping>

Output only. Mappings containing IP addresses that can be used to connect to the read pool node. Corresponds to the JSON property ipAddresses



4694
4695
4696
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4694

def ip_addresses
  @ip_addresses
end

#nameString

Output only. The name of the read pool node, to be used for retrieving metrics and logs. Corresponds to the JSON property name

Returns:

  • (String)


4700
4701
4702
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4700

def name
  @name
end

#psc_auto_connectionsArray<Google::Apis::SqladminV1beta4::PscAutoConnectionConfig>

Output only. The list of settings for requested automatically-setup Private Service Connect (PSC) consumer endpoints that can be used to connect to this read pool node. Corresponds to the JSON property pscAutoConnections



4707
4708
4709
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4707

def psc_auto_connections
  @psc_auto_connections
end

Output only. The Private Service Connect (PSC) service attachment of the read pool node. Corresponds to the JSON property pscServiceAttachmentLink

Returns:

  • (String)


4713
4714
4715
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4713

def psc_service_attachment_link
  @psc_service_attachment_link
end

#stateString

Output only. The current state of the read pool node. Corresponds to the JSON property state

Returns:

  • (String)


4718
4719
4720
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4718

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4725
4726
4727
4728
4729
4730
4731
4732
4733
4734
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4725

def update!(**args)
  @dns_name = args[:dns_name] if args.key?(:dns_name)
  @dns_names = args[:dns_names] if args.key?(:dns_names)
  @gce_zone = args[:gce_zone] if args.key?(:gce_zone)
  @ip_addresses = args[:ip_addresses] if args.key?(:ip_addresses)
  @name = args[:name] if args.key?(:name)
  @psc_auto_connections = args[:psc_auto_connections] if args.key?(:psc_auto_connections)
  @psc_service_attachment_link = args[:psc_service_attachment_link] if args.key?(:psc_service_attachment_link)
  @state = args[:state] if args.key?(:state)
end