Class: Google::Apis::SqladminV1beta4::PreCheckResponse
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::PreCheckResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
Structured PreCheckResponse containing message, type, and required actions.
Instance Attribute Summary collapse
-
#actions_required ⇒ Array<String>
The actions that the user needs to take.
-
#message ⇒ String
The message to be displayed to the user.
-
#message_type ⇒ String
The type of message whether it is an info, warning, or error.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PreCheckResponse
constructor
A new instance of PreCheckResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PreCheckResponse
Returns a new instance of PreCheckResponse.
4659 4660 4661 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4659 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actions_required ⇒ Array<String>
The actions that the user needs to take. Use repeated for multiple actions.
Corresponds to the JSON property actionsRequired
4647 4648 4649 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4647 def actions_required @actions_required end |
#message ⇒ String
The message to be displayed to the user.
Corresponds to the JSON property message
4652 4653 4654 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4652 def @message end |
#message_type ⇒ String
The type of message whether it is an info, warning, or error.
Corresponds to the JSON property messageType
4657 4658 4659 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4657 def @message_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4664 4665 4666 4667 4668 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4664 def update!(**args) @actions_required = args[:actions_required] if args.key?(:actions_required) @message = args[:message] if args.key?(:message) @message_type = args[:message_type] if args.key?(:message_type) end |