Class: Google::Apis::SqladminV1beta4::PscAutoConnectionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Settings for an automatically-setup Private Service Connect consumer endpoint that is used to connect to a Cloud SQL instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PscAutoConnectionConfig

Returns a new instance of PscAutoConnectionConfig.



4857
4858
4859
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4857

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consumer_networkString

Optional. The consumer network of this consumer endpoint. This must be a resource path that includes both the host project and the network name. For example, projects/project1/global/networks/network1. The consumer host project of this network might be different from the consumer service project. Corresponds to the JSON property consumerNetwork

Returns:

  • (String)


4810
4811
4812
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4810

def consumer_network
  @consumer_network
end

#consumer_network_statusString

The connection policy status of the consumer network. Corresponds to the JSON property consumerNetworkStatus

Returns:

  • (String)


4815
4816
4817
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4815

def consumer_network_status
  @consumer_network_status
end

#consumer_projectString

Optional. This is the project ID of consumer service project of this consumer endpoint. Optional. This is only applicable if consumer_network is a shared vpc network. Corresponds to the JSON property consumerProject

Returns:

  • (String)


4822
4823
4824
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4822

def consumer_project
  @consumer_project
end

#instance_auto_dns_statusString

Output only. The status of automated DNS provisioning. Corresponds to the JSON property instanceAutoDnsStatus

Returns:

  • (String)


4827
4828
4829
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4827

def instance_auto_dns_status
  @instance_auto_dns_status
end

#ip_addressString

The IP address of the consumer endpoint. Corresponds to the JSON property ipAddress

Returns:

  • (String)


4832
4833
4834
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4832

def ip_address
  @ip_address
end

#service_connection_policyString

Output only. The service connection policy created automatically for the consumer network when psc_auto_connection_policy_enabled is true. It is in the format of: projects/project/regions/region/serviceConnectionPolicies/ policy_id`Thepolicy_idis in format of$NETWORK-$RANDOM. Corresponds to the JSON propertyserviceConnectionPolicy`

Returns:

  • (String)


4840
4841
4842
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4840

def service_connection_policy
  @service_connection_policy
end

#service_connection_policy_creation_resultString

Output only. The status of service connection policy creation. Corresponds to the JSON property serviceConnectionPolicyCreationResult

Returns:

  • (String)


4845
4846
4847
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4845

def service_connection_policy_creation_result
  @service_connection_policy_creation_result
end

#statusString

The connection status of the consumer endpoint. Corresponds to the JSON property status

Returns:

  • (String)


4850
4851
4852
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4850

def status
  @status
end

#write_endpoint_auto_dns_statusString

Output only. The status of automated DNS provisioning for the write endpoint. Corresponds to the JSON property writeEndpointAutoDnsStatus

Returns:

  • (String)


4855
4856
4857
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4855

def write_endpoint_auto_dns_status
  @write_endpoint_auto_dns_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4862
4863
4864
4865
4866
4867
4868
4869
4870
4871
4872
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4862

def update!(**args)
  @consumer_network = args[:consumer_network] if args.key?(:consumer_network)
  @consumer_network_status = args[:consumer_network_status] if args.key?(:consumer_network_status)
  @consumer_project = args[:consumer_project] if args.key?(:consumer_project)
  @instance_auto_dns_status = args[:instance_auto_dns_status] if args.key?(:instance_auto_dns_status)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @service_connection_policy = args[:service_connection_policy] if args.key?(:service_connection_policy)
  @service_connection_policy_creation_result = args[:service_connection_policy_creation_result] if args.key?(:service_connection_policy_creation_result)
  @status = args[:status] if args.key?(:status)
  @write_endpoint_auto_dns_status = args[:write_endpoint_auto_dns_status] if args.key?(:write_endpoint_auto_dns_status)
end