Class: Google::Apis::SqladminV1beta4::ReplicationCluster

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

A primary instance and disaster recovery (DR) replica pair. A DR replica is a cross-region replica that you designate for failover in the event that the primary instance has regional failure. Applicable to MySQL and PostgreSQL.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReplicationCluster

Returns a new instance of ReplicationCluster.



5138
5139
5140
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5138

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dr_replicaBoolean Also known as: dr_replica?

Output only. Read-only field that indicates whether the replica is a DR replica. This field is not set if the instance is a primary instance. Corresponds to the JSON property drReplica

Returns:

  • (Boolean)


5114
5115
5116
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5114

def dr_replica
  @dr_replica
end

#failover_dr_replica_nameString

Optional. If the instance is a primary instance, then this field identifies the disaster recovery (DR) replica. A DR replica is an optional configuration for Enterprise Plus edition instances. If the instance is a read replica, then the field is not set. Set this field to a replica name to designate a DR replica for a primary instance. Remove the replica name to remove the DR replica designation. Corresponds to the JSON property failoverDrReplicaName

Returns:

  • (String)


5125
5126
5127
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5125

def failover_dr_replica_name
  @failover_dr_replica_name
end

#psa_write_endpointString

Output only. If set, this field indicates this instance has a private service access (PSA) DNS endpoint that is pointing to the primary instance of the cluster. If this instance is the primary, then the DNS endpoint points to this instance. After a switchover or replica failover operation, this DNS endpoint points to the promoted instance. This is a read-only field, returned to the user as information. This field can exist even if a standalone instance doesn' t have a DR replica yet or the DR replica is deleted. Corresponds to the JSON property psaWriteEndpoint

Returns:

  • (String)


5136
5137
5138
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5136

def psa_write_endpoint
  @psa_write_endpoint
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5143
5144
5145
5146
5147
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5143

def update!(**args)
  @dr_replica = args[:dr_replica] if args.key?(:dr_replica)
  @failover_dr_replica_name = args[:failover_dr_replica_name] if args.key?(:failover_dr_replica_name)
  @psa_write_endpoint = args[:psa_write_endpoint] if args.key?(:psa_write_endpoint)
end