Class: Google::Apis::SqladminV1beta4::RotateServerCertificateContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Instance rotate server certificate context.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RotateServerCertificateContext

Returns a new instance of RotateServerCertificateContext.



5284
5285
5286
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5284

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

Optional. This is always sql#rotateServerCertificateContext. Corresponds to the JSON property kind

Returns:

  • (String)


5275
5276
5277
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5275

def kind
  @kind
end

#next_versionString

Optional. The fingerprint of the next version to be rotated to. If left unspecified, will be rotated to the most recently added server certificate version. Corresponds to the JSON property nextVersion

Returns:

  • (String)


5282
5283
5284
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5282

def next_version
  @next_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5289
5290
5291
5292
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5289

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @next_version = args[:next_version] if args.key?(:next_version)
end