Class: Google::Apis::SqladminV1beta4::SqlSubOperationType

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

The sub operation type based on the operation type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SqlSubOperationType

Returns a new instance of SqlSubOperationType.



6144
6145
6146
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6144

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#maintenance_typeString

The type of maintenance to be performed on the instance. Corresponds to the JSON property maintenanceType

Returns:

  • (String)


6142
6143
6144
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6142

def maintenance_type
  @maintenance_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6149
6150
6151
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6149

def update!(**args)
  @maintenance_type = args[:maintenance_type] if args.key?(:maintenance_type)
end