Class: Google::Apis::SqladminV1beta4::Status

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Status

Returns a new instance of Status.



6410
6411
6412
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6410

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeFixnum

The status code, which should be an enum value of google.rpc.Code. Corresponds to the JSON property code

Returns:

  • (Fixnum)


6395
6396
6397
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6395

def code
  @code
end

#detailsArray<Hash<String,Object>>

A list of messages that carry the error details. There is a common set of message types for APIs to use. Corresponds to the JSON property details

Returns:

  • (Array<Hash<String,Object>>)


6401
6402
6403
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6401

def details
  @details
end

#messageString

A developer-facing error message, which should be in English. Any user-facing error message should be localized and sent in the google.rpc.Status.details field, or localized by the client. Corresponds to the JSON property message

Returns:

  • (String)


6408
6409
6410
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6408

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6415
6416
6417
6418
6419
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6415

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @details = args[:details] if args.key?(:details)
  @message = args[:message] if args.key?(:message)
end