Class: Google::Apis::SqladminV1beta4::TargetMetric
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::TargetMetric
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
Target metric for read pool auto scaling.
Instance Attribute Summary collapse
-
#metric ⇒ String
The metric name to be used for auto scaling.
-
#target_value ⇒ Float
The target value for the metric.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetMetric
constructor
A new instance of TargetMetric.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetMetric
Returns a new instance of TargetMetric.
6350 6351 6352 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6350 def initialize(**args) update!(**args) end |
Instance Attribute Details
#metric ⇒ String
The metric name to be used for auto scaling.
Corresponds to the JSON property metric
6343 6344 6345 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6343 def metric @metric end |
#target_value ⇒ Float
The target value for the metric.
Corresponds to the JSON property targetValue
6348 6349 6350 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6348 def target_value @target_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6355 6356 6357 6358 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6355 def update!(**args) @metric = args[:metric] if args.key?(:metric) @target_value = args[:target_value] if args.key?(:target_value) end |