Class: Google::Apis::SqladminV1beta4::Tier
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::Tier
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
A Google Cloud SQL service tier resource.
Instance Attribute Summary collapse
-
#disk_quota ⇒ Fixnum
The maximum disk size of this tier in bytes.
-
#kind ⇒ String
This is always
sql#tier. -
#ram ⇒ Fixnum
The maximum RAM usage of this tier in bytes.
-
#region ⇒ Array<String>
The applicable regions for this tier.
-
#tier ⇒ String
An identifier for the machine type, for example,
db-custom-1-3840.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Tier
constructor
A new instance of Tier.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Tier
Returns a new instance of Tier.
6607 6608 6609 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6607 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disk_quota ⇒ Fixnum
The maximum disk size of this tier in bytes.
Corresponds to the JSON property DiskQuota
6584 6585 6586 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6584 def disk_quota @disk_quota end |
#kind ⇒ String
This is always sql#tier.
Corresponds to the JSON property kind
6594 6595 6596 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6594 def kind @kind end |
#ram ⇒ Fixnum
The maximum RAM usage of this tier in bytes.
Corresponds to the JSON property RAM
6589 6590 6591 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6589 def ram @ram end |
#region ⇒ Array<String>
The applicable regions for this tier.
Corresponds to the JSON property region
6599 6600 6601 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6599 def region @region end |
#tier ⇒ String
An identifier for the machine type, for example, db-custom-1-3840. For
related information, see Pricing.
Corresponds to the JSON property tier
6605 6606 6607 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6605 def tier @tier end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6612 6613 6614 6615 6616 6617 6618 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6612 def update!(**args) @disk_quota = args[:disk_quota] if args.key?(:disk_quota) @ram = args[:ram] if args.key?(:ram) @kind = args[:kind] if args.key?(:kind) @region = args[:region] if args.key?(:region) @tier = args[:tier] if args.key?(:tier) end |