Class: Google::Apis::SqladminV1beta4::UserPasswordValidationPolicy
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::UserPasswordValidationPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
User level password validation policy.
Instance Attribute Summary collapse
-
#allowed_failed_attempts ⇒ Fixnum
Number of failed login attempts allowed before user get locked.
-
#enable_failed_attempts_check ⇒ Boolean
(also: #enable_failed_attempts_check?)
If true, failed login attempts check will be enabled.
-
#enable_password_verification ⇒ Boolean
(also: #enable_password_verification?)
If true, the user must specify the current password before changing the password.
-
#password_expiration_duration ⇒ String
Expiration duration after password is updated.
-
#status ⇒ Google::Apis::SqladminV1beta4::PasswordStatus
Read-only password status.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserPasswordValidationPolicy
constructor
A new instance of UserPasswordValidationPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserPasswordValidationPolicy
Returns a new instance of UserPasswordValidationPolicy.
6811 6812 6813 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6811 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_failed_attempts ⇒ Fixnum
Number of failed login attempts allowed before user get locked.
Corresponds to the JSON property allowedFailedAttempts
6786 6787 6788 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6786 def allowed_failed_attempts @allowed_failed_attempts end |
#enable_failed_attempts_check ⇒ Boolean Also known as: enable_failed_attempts_check?
If true, failed login attempts check will be enabled.
Corresponds to the JSON property enableFailedAttemptsCheck
6791 6792 6793 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6791 def enable_failed_attempts_check @enable_failed_attempts_check end |
#enable_password_verification ⇒ Boolean Also known as: enable_password_verification?
If true, the user must specify the current password before changing the
password. This flag is supported only for MySQL.
Corresponds to the JSON property enablePasswordVerification
6798 6799 6800 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6798 def enable_password_verification @enable_password_verification end |
#password_expiration_duration ⇒ String
Expiration duration after password is updated.
Corresponds to the JSON property passwordExpirationDuration
6804 6805 6806 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6804 def password_expiration_duration @password_expiration_duration end |
#status ⇒ Google::Apis::SqladminV1beta4::PasswordStatus
Read-only password status.
Corresponds to the JSON property status
6809 6810 6811 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6809 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6816 6817 6818 6819 6820 6821 6822 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6816 def update!(**args) @allowed_failed_attempts = args[:allowed_failed_attempts] if args.key?(:allowed_failed_attempts) @enable_failed_attempts_check = args[:enable_failed_attempts_check] if args.key?(:enable_failed_attempts_check) @enable_password_verification = args[:enable_password_verification] if args.key?(:enable_password_verification) @password_expiration_duration = args[:password_expiration_duration] if args.key?(:password_expiration_duration) @status = args[:status] if args.key?(:status) end |