Class: Google::Apis::SqladminV1beta4::Value
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::Value
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
The cell value of the table.
Instance Attribute Summary collapse
-
#null_value ⇒ Boolean
(also: #null_value?)
If cell value is null, then this flag will be set to true.
-
#value ⇒ String
The cell value represented in string format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Value
constructor
A new instance of Value.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Value
Returns a new instance of Value.
6655 6656 6657 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6655 def initialize(**args) update!(**args) end |
Instance Attribute Details
#null_value ⇒ Boolean Also known as: null_value?
If cell value is null, then this flag will be set to true.
Corresponds to the JSON property nullValue
6647 6648 6649 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6647 def null_value @null_value end |
#value ⇒ String
The cell value represented in string format.
Corresponds to the JSON property value
6653 6654 6655 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6653 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6660 6661 6662 6663 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6660 def update!(**args) @null_value = args[:null_value] if args.key?(:null_value) @value = args[:value] if args.key?(:value) end |