Class: Google::Apis::SqladminV1beta4::ConnectPoolNodeConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Details of a single read pool node of a read pool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConnectPoolNodeConfig

Returns a new instance of ConnectPoolNodeConfig.



859
860
861
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 859

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dns_nameString

Output only. The DNS name of the read pool node. Corresponds to the JSON property dnsName

Returns:

  • (String)


841
842
843
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 841

def dns_name
  @dns_name
end

#dns_namesArray<Google::Apis::SqladminV1beta4::DnsNameMapping>

Output only. The list of DNS names used by this read pool node. Corresponds to the JSON property dnsNames



846
847
848
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 846

def dns_names
  @dns_names
end

#ip_addressesArray<Google::Apis::SqladminV1beta4::IpMapping>

Output only. Mappings containing IP addresses that can be used to connect to the read pool node. Corresponds to the JSON property ipAddresses



852
853
854
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 852

def ip_addresses
  @ip_addresses
end

#nameString

Output only. The name of the read pool node. Doesn't include the project ID. Corresponds to the JSON property name

Returns:

  • (String)


857
858
859
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 857

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



864
865
866
867
868
869
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 864

def update!(**args)
  @dns_name = args[:dns_name] if args.key?(:dns_name)
  @dns_names = args[:dns_names] if args.key?(:dns_names)
  @ip_addresses = args[:ip_addresses] if args.key?(:ip_addresses)
  @name = args[:name] if args.key?(:name)
end