Class: Google::Apis::SqladminV1beta4::ConnectSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Connect settings retrieval response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConnectSettings

Returns a new instance of ConnectSettings.



962
963
964
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 962

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_typeString

SECOND_GEN: Cloud SQL database instance. EXTERNAL: A database server that is not managed by Google. This property is read-only; use the tier property in the settings object to determine the database type. Corresponds to the JSON property backendType

Returns:

  • (String)


881
882
883
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 881

def backend_type
  @backend_type
end

#custom_subject_alternative_namesArray<String>

Custom subject alternative names for the server certificate. Corresponds to the JSON property customSubjectAlternativeNames

Returns:

  • (Array<String>)


886
887
888
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 886

def custom_subject_alternative_names
  @custom_subject_alternative_names
end

#database_versionString

The database engine type and version. The databaseVersion field cannot be changed after instance creation. MySQL instances: MYSQL_8_0, MYSQL_5_7 ( default), or MYSQL_5_6. PostgreSQL instances: POSTGRES_9_6, POSTGRES_10, POSTGRES_11 or POSTGRES_12 (default), POSTGRES_13, or POSTGRES_14. SQL Server instances: SQLSERVER_2017_STANDARD (default), SQLSERVER_2017_ENTERPRISE, SQLSERVER_2017_EXPRESS, SQLSERVER_2017_WEB, SQLSERVER_2019_STANDARD, SQLSERVER_2019_ENTERPRISE, SQLSERVER_2019_EXPRESS , or SQLSERVER_2019_WEB. Corresponds to the JSON property databaseVersion

Returns:

  • (String)


898
899
900
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 898

def database_version
  @database_version
end

#dns_nameString

The dns name of the instance. Corresponds to the JSON property dnsName

Returns:

  • (String)


903
904
905
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 903

def dns_name
  @dns_name
end

#dns_namesArray<Google::Apis::SqladminV1beta4::DnsNameMapping>

Output only. The list of DNS names used by this instance. Corresponds to the JSON property dnsNames



908
909
910
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 908

def dns_names
  @dns_names
end

#ip_addressesArray<Google::Apis::SqladminV1beta4::IpMapping>

The assigned IP addresses for the instance. Corresponds to the JSON property ipAddresses



913
914
915
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 913

def ip_addresses
  @ip_addresses
end

#kindString

This is always sql#connectSettings. Corresponds to the JSON property kind

Returns:

  • (String)


918
919
920
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 918

def kind
  @kind
end

#mdx_protocol_supportArray<String>

Optional. Output only. mdx_protocol_support controls how the client uses metadata exchange when connecting to the instance. The values in the list representing parts of the MDX protocol that are supported by this instance. When the list is empty, the instance does not support MDX, so the client must not send an MDX request. The default is empty. Corresponds to the JSON property mdxProtocolSupport

Returns:

  • (Array<String>)


927
928
929
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 927

def mdx_protocol_support
  @mdx_protocol_support
end

#node_countFixnum

The number of read pool nodes in a read pool. Corresponds to the JSON property nodeCount

Returns:

  • (Fixnum)


932
933
934
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 932

def node_count
  @node_count
end

#nodesArray<Google::Apis::SqladminV1beta4::ConnectPoolNodeConfig>

Output only. Entries containing information about each read pool node of the read pool. Corresponds to the JSON property nodes



938
939
940
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 938

def nodes
  @nodes
end

#psc_enabledBoolean Also known as: psc_enabled?

Whether PSC connectivity is enabled for this instance. Corresponds to the JSON property pscEnabled

Returns:

  • (Boolean)


943
944
945
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 943

def psc_enabled
  @psc_enabled
end

#regionString

The cloud region for the instance. e.g. us-central1, europe-west1. The region cannot be changed after instance creation. Corresponds to the JSON property region

Returns:

  • (String)


950
951
952
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 950

def region
  @region
end

#server_ca_certGoogle::Apis::SqladminV1beta4::SslCert

SslCerts Resource Corresponds to the JSON property serverCaCert



955
956
957
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 955

def server_ca_cert
  @server_ca_cert
end

#server_ca_modeString

Specify what type of CA is used for the server certificate. Corresponds to the JSON property serverCaMode

Returns:

  • (String)


960
961
962
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 960

def server_ca_mode
  @server_ca_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 967

def update!(**args)
  @backend_type = args[:backend_type] if args.key?(:backend_type)
  @custom_subject_alternative_names = args[:custom_subject_alternative_names] if args.key?(:custom_subject_alternative_names)
  @database_version = args[:database_version] if args.key?(:database_version)
  @dns_name = args[:dns_name] if args.key?(:dns_name)
  @dns_names = args[:dns_names] if args.key?(:dns_names)
  @ip_addresses = args[:ip_addresses] if args.key?(:ip_addresses)
  @kind = args[:kind] if args.key?(:kind)
  @mdx_protocol_support = args[:mdx_protocol_support] if args.key?(:mdx_protocol_support)
  @node_count = args[:node_count] if args.key?(:node_count)
  @nodes = args[:nodes] if args.key?(:nodes)
  @psc_enabled = args[:psc_enabled] if args.key?(:psc_enabled)
  @region = args[:region] if args.key?(:region)
  @server_ca_cert = args[:server_ca_cert] if args.key?(:server_ca_cert)
  @server_ca_mode = args[:server_ca_mode] if args.key?(:server_ca_mode)
end