Class: Google::Apis::SqladminV1beta4::DatabaseFlags
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::DatabaseFlags
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
Database flags for Cloud SQL instances.
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the flag.
-
#value ⇒ String
The value of the flag.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DatabaseFlags
constructor
A new instance of DatabaseFlags.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DatabaseFlags
Returns a new instance of DatabaseFlags.
1168 1169 1170 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1168 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
The name of the flag. These flags are passed at instance startup, so include
both server options and system variables. Flags are specified with underscores,
not hyphens. For more information, see Configuring Database Flags in the Cloud SQL documentation.
Corresponds to the JSON property name
1160 1161 1162 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1160 def name @name end |
#value ⇒ String
The value of the flag. Boolean flags are set to on for true and off for
false. This field must be omitted if the flag doesn't take a value.
Corresponds to the JSON property value
1166 1167 1168 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1166 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1173 1174 1175 1176 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1173 def update!(**args) @name = args[:name] if args.key?(:name) @value = args[:value] if args.key?(:value) end |