Class: Google::Apis::SqladminV1beta4::DatabaseFlags

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Database flags for Cloud SQL instances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DatabaseFlags

Returns a new instance of DatabaseFlags.



1151
1152
1153
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1151

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The name of the flag. These flags are passed at instance startup, so include both server options and system variables. Flags are specified with underscores, not hyphens. For more information, see Configuring Database Flags in the Cloud SQL documentation. Corresponds to the JSON property name

Returns:

  • (String)


1143
1144
1145
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1143

def name
  @name
end

#valueString

The value of the flag. Boolean flags are set to on for true and off for false. This field must be omitted if the flag doesn't take a value. Corresponds to the JSON property value

Returns:

  • (String)


1149
1150
1151
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1149

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1156
1157
1158
1159
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1156

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @value = args[:value] if args.key?(:value)
end