Class: Google::Apis::SqladminV1beta4::DatabaseInstance
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::DatabaseInstance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
A Cloud SQL instance resource.
Defined Under Namespace
Classes: FailoverReplica
Instance Attribute Summary collapse
-
#available_maintenance_versions ⇒ Array<String>
Output only.
-
#backend_type ⇒ String
The backend type.
-
#connection_name ⇒ String
Connection name of the Cloud SQL instance used in connection strings.
-
#create_time ⇒ String
Output only.
-
#current_disk_size ⇒ Fixnum
The current disk usage of the instance in bytes.
-
#database_installed_version ⇒ String
Output only.
-
#database_version ⇒ String
The database engine type and version.
-
#disk_encryption_configuration ⇒ Google::Apis::SqladminV1beta4::DiskEncryptionConfiguration
Disk encryption configuration for an instance.
-
#disk_encryption_status ⇒ Google::Apis::SqladminV1beta4::DiskEncryptionStatus
Disk encryption status for an instance.
-
#dns_name ⇒ String
Output only.
-
#dns_names ⇒ Array<Google::Apis::SqladminV1beta4::DnsNameMapping>
Output only.
-
#etag ⇒ String
This field is deprecated and will be removed from a future version of the API.
-
#failover_replica ⇒ Google::Apis::SqladminV1beta4::DatabaseInstance::FailoverReplica
The name and status of the failover replica.
-
#gce_zone ⇒ String
The Compute Engine zone that the instance is currently serving from.
-
#gemini_config ⇒ Google::Apis::SqladminV1beta4::GeminiInstanceConfig
Gemini instance configuration.
-
#include_replicas_for_major_version_upgrade ⇒ Boolean
(also: #include_replicas_for_major_version_upgrade?)
Input only.
-
#instance_type ⇒ String
The instance type.
-
#ip_addresses ⇒ Array<Google::Apis::SqladminV1beta4::IpMapping>
The assigned IP addresses for the instance.
-
#ipv6_address ⇒ String
The IPv6 address assigned to the instance.
-
#kind ⇒ String
This is always
sql#instance. -
#maintenance_version ⇒ String
The current software version on the instance.
-
#master_instance_name ⇒ String
The name of the instance which will act as primary in the replication setup.
-
#max_disk_size ⇒ Fixnum
The maximum disk size of the instance in bytes.
-
#name ⇒ String
Name of the Cloud SQL instance.
-
#node_count ⇒ Fixnum
The number of read pool nodes in a read pool.
-
#nodes ⇒ Array<Google::Apis::SqladminV1beta4::PoolNodeConfig>
Output only.
-
#on_premises_configuration ⇒ Google::Apis::SqladminV1beta4::OnPremisesConfiguration
On-premises instance configuration.
-
#out_of_disk_report ⇒ Google::Apis::SqladminV1beta4::SqlOutOfDiskReport
This message wraps up the information written by out-of-disk detection job.
-
#primary_dns_name ⇒ String
Output only.
-
#project ⇒ String
The project ID of the project containing the Cloud SQL instance.
-
#psc_service_attachment_link ⇒ String
Output only.
-
#region ⇒ String
The geographical region of the Cloud SQL instance.
-
#replica_configuration ⇒ Google::Apis::SqladminV1beta4::ReplicaConfiguration
Read-replica configuration for connecting to the primary instance.
-
#replica_names ⇒ Array<String>
The replicas of the instance.
-
#replication_cluster ⇒ Google::Apis::SqladminV1beta4::ReplicationCluster
A primary instance and disaster recovery (DR) replica pair.
-
#root_password ⇒ String
Initial root password.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
This status indicates whether the instance satisfies PZS.
-
#scheduled_maintenance ⇒ Google::Apis::SqladminV1beta4::SqlScheduledMaintenance
Any scheduled maintenance for this instance.
-
#secondary_gce_zone ⇒ String
The Compute Engine zone that the failover instance is currently serving from for a regional instance.
-
#self_link ⇒ String
The URI of this resource.
-
#server_ca_cert ⇒ Google::Apis::SqladminV1beta4::SslCert
SslCerts Resource Corresponds to the JSON property
serverCaCert. -
#service_account_email_address ⇒ String
The service account email address assigned to the instance.
-
#settings ⇒ Google::Apis::SqladminV1beta4::Settings
Database instance settings.
-
#sql_network_architecture ⇒ String
The SQL network architecture for the instance.
-
#state ⇒ String
The current serving state of the Cloud SQL instance.
-
#suspension_reason ⇒ Array<String>
If the instance state is SUSPENDED, the reason for the suspension.
-
#switch_transaction_logs_to_cloud_storage_enabled ⇒ Boolean
(also: #switch_transaction_logs_to_cloud_storage_enabled?)
Input only.
-
#tags ⇒ Hash<String,String>
Optional.
-
#upgradable_database_versions ⇒ Array<Google::Apis::SqladminV1beta4::AvailableDatabaseVersion>
Output only.
-
#write_endpoint ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DatabaseInstance
constructor
A new instance of DatabaseInstance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DatabaseInstance
Returns a new instance of DatabaseInstance.
1478 1479 1480 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1478 def initialize(**args) update!(**args) end |
Instance Attribute Details
#available_maintenance_versions ⇒ Array<String>
Output only. List all maintenance versions applicable on the instance
Corresponds to the JSON property availableMaintenanceVersions
1186 1187 1188 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1186 def available_maintenance_versions @available_maintenance_versions end |
#backend_type ⇒ String
The backend type. SECOND_GEN: Cloud SQL database instance. EXTERNAL: A
database server that is not managed by Google. This property is read-only; use
the tier property in the settings object to determine the database type.
Corresponds to the JSON property backendType
1193 1194 1195 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1193 def backend_type @backend_type end |
#connection_name ⇒ String
Connection name of the Cloud SQL instance used in connection strings.
Corresponds to the JSON property connectionName
1198 1199 1200 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1198 def connection_name @connection_name end |
#create_time ⇒ String
Output only. The time when the instance was created in RFC 3339 format, for example 2012-11-15T16:19:00.094Z.
Corresponds to the JSON property createTime
1204 1205 1206 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1204 def create_time @create_time end |
#current_disk_size ⇒ Fixnum
The current disk usage of the instance in bytes. This property has been
deprecated. Use the "cloudsql.googleapis.com/database/disk/bytes_used" metric
in Cloud Monitoring API instead. Please see this announcement for
details.
Corresponds to the JSON property currentDiskSize
1213 1214 1215 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1213 def current_disk_size @current_disk_size end |
#database_installed_version ⇒ String
Output only. Stores the current database version running on the instance
including minor version such as MYSQL_8_0_18.
Corresponds to the JSON property databaseInstalledVersion
1219 1220 1221 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1219 def database_installed_version @database_installed_version end |
#database_version ⇒ String
The database engine type and version. The databaseVersion field cannot be
changed after instance creation.
Corresponds to the JSON property databaseVersion
1225 1226 1227 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1225 def database_version @database_version end |
#disk_encryption_configuration ⇒ Google::Apis::SqladminV1beta4::DiskEncryptionConfiguration
Disk encryption configuration for an instance.
Corresponds to the JSON property diskEncryptionConfiguration
1230 1231 1232 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1230 def disk_encryption_configuration @disk_encryption_configuration end |
#disk_encryption_status ⇒ Google::Apis::SqladminV1beta4::DiskEncryptionStatus
Disk encryption status for an instance.
Corresponds to the JSON property diskEncryptionStatus
1235 1236 1237 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1235 def disk_encryption_status @disk_encryption_status end |
#dns_name ⇒ String
Output only. The dns name of the instance.
Corresponds to the JSON property dnsName
1240 1241 1242 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1240 def dns_name @dns_name end |
#dns_names ⇒ Array<Google::Apis::SqladminV1beta4::DnsNameMapping>
Output only. The list of DNS names used by this instance.
Corresponds to the JSON property dnsNames
1245 1246 1247 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1245 def dns_names @dns_names end |
#etag ⇒ String
This field is deprecated and will be removed from a future version of the API.
Use the settings.settingsVersion field instead.
Corresponds to the JSON property etag
1251 1252 1253 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1251 def etag @etag end |
#failover_replica ⇒ Google::Apis::SqladminV1beta4::DatabaseInstance::FailoverReplica
The name and status of the failover replica.
Corresponds to the JSON property failoverReplica
1256 1257 1258 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1256 def failover_replica @failover_replica end |
#gce_zone ⇒ String
The Compute Engine zone that the instance is currently serving from. This
value could be different from the zone that was specified when the instance
was created if the instance has failed over to its secondary zone. WARNING:
Changing this might restart the instance.
Corresponds to the JSON property gceZone
1264 1265 1266 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1264 def gce_zone @gce_zone end |
#gemini_config ⇒ Google::Apis::SqladminV1beta4::GeminiInstanceConfig
Gemini instance configuration.
Corresponds to the JSON property geminiConfig
1269 1270 1271 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1269 def gemini_config @gemini_config end |
#include_replicas_for_major_version_upgrade ⇒ Boolean Also known as: include_replicas_for_major_version_upgrade?
Input only. Determines whether an in-place major version upgrade of replicas
happens when an in-place major version upgrade of a primary instance is
initiated.
Corresponds to the JSON property includeReplicasForMajorVersionUpgrade
1276 1277 1278 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1276 def include_replicas_for_major_version_upgrade @include_replicas_for_major_version_upgrade end |
#instance_type ⇒ String
The instance type.
Corresponds to the JSON property instanceType
1282 1283 1284 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1282 def instance_type @instance_type end |
#ip_addresses ⇒ Array<Google::Apis::SqladminV1beta4::IpMapping>
The assigned IP addresses for the instance.
Corresponds to the JSON property ipAddresses
1287 1288 1289 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1287 def ip_addresses @ip_addresses end |
#ipv6_address ⇒ String
The IPv6 address assigned to the instance. (Deprecated) This property was
applicable only to First Generation instances.
Corresponds to the JSON property ipv6Address
1293 1294 1295 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1293 def ipv6_address @ipv6_address end |
#kind ⇒ String
This is always sql#instance.
Corresponds to the JSON property kind
1298 1299 1300 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1298 def kind @kind end |
#maintenance_version ⇒ String
The current software version on the instance.
Corresponds to the JSON property maintenanceVersion
1303 1304 1305 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1303 def maintenance_version @maintenance_version end |
#master_instance_name ⇒ String
The name of the instance which will act as primary in the replication setup.
Corresponds to the JSON property masterInstanceName
1308 1309 1310 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1308 def master_instance_name @master_instance_name end |
#max_disk_size ⇒ Fixnum
The maximum disk size of the instance in bytes.
Corresponds to the JSON property maxDiskSize
1313 1314 1315 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1313 def max_disk_size @max_disk_size end |
#name ⇒ String
Name of the Cloud SQL instance. This does not include the project ID.
Corresponds to the JSON property name
1318 1319 1320 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1318 def name @name end |
#node_count ⇒ Fixnum
The number of read pool nodes in a read pool.
Corresponds to the JSON property nodeCount
1323 1324 1325 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1323 def node_count @node_count end |
#nodes ⇒ Array<Google::Apis::SqladminV1beta4::PoolNodeConfig>
Output only. Entries containing information about each read pool node of the
read pool.
Corresponds to the JSON property nodes
1329 1330 1331 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1329 def nodes @nodes end |
#on_premises_configuration ⇒ Google::Apis::SqladminV1beta4::OnPremisesConfiguration
On-premises instance configuration.
Corresponds to the JSON property onPremisesConfiguration
1334 1335 1336 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1334 def on_premises_configuration @on_premises_configuration end |
#out_of_disk_report ⇒ Google::Apis::SqladminV1beta4::SqlOutOfDiskReport
This message wraps up the information written by out-of-disk detection job.
Corresponds to the JSON property outOfDiskReport
1339 1340 1341 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1339 def out_of_disk_report @out_of_disk_report end |
#primary_dns_name ⇒ String
Output only. DEPRECATED: please use write_endpoint instead.
Corresponds to the JSON property primaryDnsName
1344 1345 1346 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1344 def primary_dns_name @primary_dns_name end |
#project ⇒ String
The project ID of the project containing the Cloud SQL instance. The Google
apps domain is prefixed if applicable.
Corresponds to the JSON property project
1350 1351 1352 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1350 def project @project end |
#psc_service_attachment_link ⇒ String
Output only. The link to service attachment of PSC instance.
Corresponds to the JSON property pscServiceAttachmentLink
1355 1356 1357 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1355 def @psc_service_attachment_link end |
#region ⇒ String
The geographical region of the Cloud SQL instance. It can be one of the
regions where
Cloud SQL operates: For example, asia-east1, europe-west1, and us-
central1. The default value is us-central1.
Corresponds to the JSON property region
1363 1364 1365 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1363 def region @region end |
#replica_configuration ⇒ Google::Apis::SqladminV1beta4::ReplicaConfiguration
Read-replica configuration for connecting to the primary instance.
Corresponds to the JSON property replicaConfiguration
1368 1369 1370 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1368 def replica_configuration @replica_configuration end |
#replica_names ⇒ Array<String>
The replicas of the instance.
Corresponds to the JSON property replicaNames
1373 1374 1375 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1373 def replica_names @replica_names end |
#replication_cluster ⇒ Google::Apis::SqladminV1beta4::ReplicationCluster
A primary instance and disaster recovery (DR) replica pair. A DR replica is a
cross-region replica that you designate for failover in the event that the
primary instance has regional failure. Applicable to MySQL and PostgreSQL.
Corresponds to the JSON property replicationCluster
1380 1381 1382 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1380 def replication_cluster @replication_cluster end |
#root_password ⇒ String
Initial root password. Use only on creation. You must set root passwords
before you can connect to PostgreSQL instances.
Corresponds to the JSON property rootPassword
1386 1387 1388 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1386 def root_password @root_password end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. This status indicates whether the instance satisfies PZI. The
status is reserved for future use.
Corresponds to the JSON property satisfiesPzi
1392 1393 1394 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1392 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
This status indicates whether the instance satisfies PZS. The status is
reserved for future use.
Corresponds to the JSON property satisfiesPzs
1399 1400 1401 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1399 def satisfies_pzs @satisfies_pzs end |
#scheduled_maintenance ⇒ Google::Apis::SqladminV1beta4::SqlScheduledMaintenance
Any scheduled maintenance for this instance.
Corresponds to the JSON property scheduledMaintenance
1405 1406 1407 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1405 def scheduled_maintenance @scheduled_maintenance end |
#secondary_gce_zone ⇒ String
The Compute Engine zone that the failover instance is currently serving from
for a regional instance. This value could be different from the zone that was
specified when the instance was created if the instance has failed over to its
secondary/failover zone.
Corresponds to the JSON property secondaryGceZone
1413 1414 1415 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1413 def secondary_gce_zone @secondary_gce_zone end |
#self_link ⇒ String
The URI of this resource.
Corresponds to the JSON property selfLink
1418 1419 1420 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1418 def self_link @self_link end |
#server_ca_cert ⇒ Google::Apis::SqladminV1beta4::SslCert
SslCerts Resource
Corresponds to the JSON property serverCaCert
1423 1424 1425 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1423 def server_ca_cert @server_ca_cert end |
#service_account_email_address ⇒ String
The service account email address assigned to the instance. \This property is
read-only.
Corresponds to the JSON property serviceAccountEmailAddress
1429 1430 1431 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1429 def service_account_email_address @service_account_email_address end |
#settings ⇒ Google::Apis::SqladminV1beta4::Settings
Database instance settings.
Corresponds to the JSON property settings
1434 1435 1436 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1434 def settings @settings end |
#sql_network_architecture ⇒ String
The SQL network architecture for the instance.
Corresponds to the JSON property sqlNetworkArchitecture
1439 1440 1441 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1439 def sql_network_architecture @sql_network_architecture end |
#state ⇒ String
The current serving state of the Cloud SQL instance.
Corresponds to the JSON property state
1444 1445 1446 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1444 def state @state end |
#suspension_reason ⇒ Array<String>
If the instance state is SUSPENDED, the reason for the suspension.
Corresponds to the JSON property suspensionReason
1449 1450 1451 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1449 def suspension_reason @suspension_reason end |
#switch_transaction_logs_to_cloud_storage_enabled ⇒ Boolean Also known as: switch_transaction_logs_to_cloud_storage_enabled?
Input only. Whether Cloud SQL is enabled to switch storing point-in-time
recovery log files from a data disk to Cloud Storage.
Corresponds to the JSON property switchTransactionLogsToCloudStorageEnabled
1455 1456 1457 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1455 def switch_transaction_logs_to_cloud_storage_enabled @switch_transaction_logs_to_cloud_storage_enabled end |
#tags ⇒ Hash<String,String>
Optional. Input only. Immutable. Tag keys and tag values that are bound to
this instance. You must represent each item in the map as: "" : "". For
example, a single resource can have the following tags: "123/environment":
"production", "123/costCenter": "marketing", For more information on tag
creation and management, see https://cloud.google.com/resource-manager/docs/
tags/tags-overview.
Corresponds to the JSON property tags
1466 1467 1468 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1466 def @tags end |
#upgradable_database_versions ⇒ Array<Google::Apis::SqladminV1beta4::AvailableDatabaseVersion>
Output only. All database versions that are available for upgrade.
Corresponds to the JSON property upgradableDatabaseVersions
1471 1472 1473 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1471 def upgradable_database_versions @upgradable_database_versions end |
#write_endpoint ⇒ String
Output only. The dns name of the primary instance in a replication group.
Corresponds to the JSON property writeEndpoint
1476 1477 1478 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1476 def write_endpoint @write_endpoint end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 1522 1523 1524 1525 1526 1527 1528 1529 1530 1531 1532 1533 1534 1535 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1483 def update!(**args) @available_maintenance_versions = args[:available_maintenance_versions] if args.key?(:available_maintenance_versions) @backend_type = args[:backend_type] if args.key?(:backend_type) @connection_name = args[:connection_name] if args.key?(:connection_name) @create_time = args[:create_time] if args.key?(:create_time) @current_disk_size = args[:current_disk_size] if args.key?(:current_disk_size) @database_installed_version = args[:database_installed_version] if args.key?(:database_installed_version) @database_version = args[:database_version] if args.key?(:database_version) @disk_encryption_configuration = args[:disk_encryption_configuration] if args.key?(:disk_encryption_configuration) @disk_encryption_status = args[:disk_encryption_status] if args.key?(:disk_encryption_status) @dns_name = args[:dns_name] if args.key?(:dns_name) @dns_names = args[:dns_names] if args.key?(:dns_names) @etag = args[:etag] if args.key?(:etag) @failover_replica = args[:failover_replica] if args.key?(:failover_replica) @gce_zone = args[:gce_zone] if args.key?(:gce_zone) @gemini_config = args[:gemini_config] if args.key?(:gemini_config) @include_replicas_for_major_version_upgrade = args[:include_replicas_for_major_version_upgrade] if args.key?(:include_replicas_for_major_version_upgrade) @instance_type = args[:instance_type] if args.key?(:instance_type) @ip_addresses = args[:ip_addresses] if args.key?(:ip_addresses) @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address) @kind = args[:kind] if args.key?(:kind) @maintenance_version = args[:maintenance_version] if args.key?(:maintenance_version) @master_instance_name = args[:master_instance_name] if args.key?(:master_instance_name) @max_disk_size = args[:max_disk_size] if args.key?(:max_disk_size) @name = args[:name] if args.key?(:name) @node_count = args[:node_count] if args.key?(:node_count) @nodes = args[:nodes] if args.key?(:nodes) @on_premises_configuration = args[:on_premises_configuration] if args.key?(:on_premises_configuration) @out_of_disk_report = args[:out_of_disk_report] if args.key?(:out_of_disk_report) @primary_dns_name = args[:primary_dns_name] if args.key?(:primary_dns_name) @project = args[:project] if args.key?(:project) @psc_service_attachment_link = args[:psc_service_attachment_link] if args.key?(:psc_service_attachment_link) @region = args[:region] if args.key?(:region) @replica_configuration = args[:replica_configuration] if args.key?(:replica_configuration) @replica_names = args[:replica_names] if args.key?(:replica_names) @replication_cluster = args[:replication_cluster] if args.key?(:replication_cluster) @root_password = args[:root_password] if args.key?(:root_password) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @scheduled_maintenance = args[:scheduled_maintenance] if args.key?(:scheduled_maintenance) @secondary_gce_zone = args[:secondary_gce_zone] if args.key?(:secondary_gce_zone) @self_link = args[:self_link] if args.key?(:self_link) @server_ca_cert = args[:server_ca_cert] if args.key?(:server_ca_cert) @service_account_email_address = args[:service_account_email_address] if args.key?(:service_account_email_address) @settings = args[:settings] if args.key?(:settings) @sql_network_architecture = args[:sql_network_architecture] if args.key?(:sql_network_architecture) @state = args[:state] if args.key?(:state) @suspension_reason = args[:suspension_reason] if args.key?(:suspension_reason) @switch_transaction_logs_to_cloud_storage_enabled = args[:switch_transaction_logs_to_cloud_storage_enabled] if args.key?(:switch_transaction_logs_to_cloud_storage_enabled) @tags = args[:tags] if args.key?(:tags) @upgradable_database_versions = args[:upgradable_database_versions] if args.key?(:upgradable_database_versions) @write_endpoint = args[:write_endpoint] if args.key?(:write_endpoint) end |