Class: Google::Apis::SqladminV1beta4::DatabaseInstance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

A Cloud SQL instance resource.

Defined Under Namespace

Classes: FailoverReplica

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DatabaseInstance

Returns a new instance of DatabaseInstance.



1461
1462
1463
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1461

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#available_maintenance_versionsArray<String>

Output only. List all maintenance versions applicable on the instance Corresponds to the JSON property availableMaintenanceVersions

Returns:

  • (Array<String>)


1169
1170
1171
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1169

def available_maintenance_versions
  @available_maintenance_versions
end

#backend_typeString

The backend type. SECOND_GEN: Cloud SQL database instance. EXTERNAL: A database server that is not managed by Google. This property is read-only; use the tier property in the settings object to determine the database type. Corresponds to the JSON property backendType

Returns:

  • (String)


1176
1177
1178
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1176

def backend_type
  @backend_type
end

#connection_nameString

Connection name of the Cloud SQL instance used in connection strings. Corresponds to the JSON property connectionName

Returns:

  • (String)


1181
1182
1183
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1181

def connection_name
  @connection_name
end

#create_timeString

Output only. The time when the instance was created in RFC 3339 format, for example 2012-11-15T16:19:00.094Z. Corresponds to the JSON property createTime

Returns:

  • (String)


1187
1188
1189
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1187

def create_time
  @create_time
end

#current_disk_sizeFixnum

The current disk usage of the instance in bytes. This property has been deprecated. Use the "cloudsql.googleapis.com/database/disk/bytes_used" metric in Cloud Monitoring API instead. Please see this announcement for details. Corresponds to the JSON property currentDiskSize

Returns:

  • (Fixnum)


1196
1197
1198
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1196

def current_disk_size
  @current_disk_size
end

#database_installed_versionString

Output only. Stores the current database version running on the instance including minor version such as MYSQL_8_0_18. Corresponds to the JSON property databaseInstalledVersion

Returns:

  • (String)


1202
1203
1204
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1202

def database_installed_version
  @database_installed_version
end

#database_versionString

The database engine type and version. The databaseVersion field cannot be changed after instance creation. Corresponds to the JSON property databaseVersion

Returns:

  • (String)


1208
1209
1210
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1208

def database_version
  @database_version
end

#disk_encryption_configurationGoogle::Apis::SqladminV1beta4::DiskEncryptionConfiguration

Disk encryption configuration for an instance. Corresponds to the JSON property diskEncryptionConfiguration



1213
1214
1215
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1213

def disk_encryption_configuration
  @disk_encryption_configuration
end

#disk_encryption_statusGoogle::Apis::SqladminV1beta4::DiskEncryptionStatus

Disk encryption status for an instance. Corresponds to the JSON property diskEncryptionStatus



1218
1219
1220
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1218

def disk_encryption_status
  @disk_encryption_status
end

#dns_nameString

Output only. The dns name of the instance. Corresponds to the JSON property dnsName

Returns:

  • (String)


1223
1224
1225
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1223

def dns_name
  @dns_name
end

#dns_namesArray<Google::Apis::SqladminV1beta4::DnsNameMapping>

Output only. The list of DNS names used by this instance. Corresponds to the JSON property dnsNames



1228
1229
1230
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1228

def dns_names
  @dns_names
end

#etagString

This field is deprecated and will be removed from a future version of the API. Use the settings.settingsVersion field instead. Corresponds to the JSON property etag

Returns:

  • (String)


1234
1235
1236
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1234

def etag
  @etag
end

#failover_replicaGoogle::Apis::SqladminV1beta4::DatabaseInstance::FailoverReplica

The name and status of the failover replica. Corresponds to the JSON property failoverReplica



1239
1240
1241
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1239

def failover_replica
  @failover_replica
end

#gce_zoneString

The Compute Engine zone that the instance is currently serving from. This value could be different from the zone that was specified when the instance was created if the instance has failed over to its secondary zone. WARNING: Changing this might restart the instance. Corresponds to the JSON property gceZone

Returns:

  • (String)


1247
1248
1249
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1247

def gce_zone
  @gce_zone
end

#gemini_configGoogle::Apis::SqladminV1beta4::GeminiInstanceConfig

Gemini instance configuration. Corresponds to the JSON property geminiConfig



1252
1253
1254
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1252

def gemini_config
  @gemini_config
end

#include_replicas_for_major_version_upgradeBoolean Also known as: include_replicas_for_major_version_upgrade?

Input only. Determines whether an in-place major version upgrade of replicas happens when an in-place major version upgrade of a primary instance is initiated. Corresponds to the JSON property includeReplicasForMajorVersionUpgrade

Returns:

  • (Boolean)


1259
1260
1261
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1259

def include_replicas_for_major_version_upgrade
  @include_replicas_for_major_version_upgrade
end

#instance_typeString

The instance type. Corresponds to the JSON property instanceType

Returns:

  • (String)


1265
1266
1267
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1265

def instance_type
  @instance_type
end

#ip_addressesArray<Google::Apis::SqladminV1beta4::IpMapping>

The assigned IP addresses for the instance. Corresponds to the JSON property ipAddresses



1270
1271
1272
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1270

def ip_addresses
  @ip_addresses
end

#ipv6_addressString

The IPv6 address assigned to the instance. (Deprecated) This property was applicable only to First Generation instances. Corresponds to the JSON property ipv6Address

Returns:

  • (String)


1276
1277
1278
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1276

def ipv6_address
  @ipv6_address
end

#kindString

This is always sql#instance. Corresponds to the JSON property kind

Returns:

  • (String)


1281
1282
1283
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1281

def kind
  @kind
end

#maintenance_versionString

The current software version on the instance. Corresponds to the JSON property maintenanceVersion

Returns:

  • (String)


1286
1287
1288
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1286

def maintenance_version
  @maintenance_version
end

#master_instance_nameString

The name of the instance which will act as primary in the replication setup. Corresponds to the JSON property masterInstanceName

Returns:

  • (String)


1291
1292
1293
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1291

def master_instance_name
  @master_instance_name
end

#max_disk_sizeFixnum

The maximum disk size of the instance in bytes. Corresponds to the JSON property maxDiskSize

Returns:

  • (Fixnum)


1296
1297
1298
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1296

def max_disk_size
  @max_disk_size
end

#nameString

Name of the Cloud SQL instance. This does not include the project ID. Corresponds to the JSON property name

Returns:

  • (String)


1301
1302
1303
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1301

def name
  @name
end

#node_countFixnum

The number of read pool nodes in a read pool. Corresponds to the JSON property nodeCount

Returns:

  • (Fixnum)


1306
1307
1308
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1306

def node_count
  @node_count
end

#nodesArray<Google::Apis::SqladminV1beta4::PoolNodeConfig>

Output only. Entries containing information about each read pool node of the read pool. Corresponds to the JSON property nodes



1312
1313
1314
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1312

def nodes
  @nodes
end

#on_premises_configurationGoogle::Apis::SqladminV1beta4::OnPremisesConfiguration

On-premises instance configuration. Corresponds to the JSON property onPremisesConfiguration



1317
1318
1319
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1317

def on_premises_configuration
  @on_premises_configuration
end

#out_of_disk_reportGoogle::Apis::SqladminV1beta4::SqlOutOfDiskReport

This message wraps up the information written by out-of-disk detection job. Corresponds to the JSON property outOfDiskReport



1322
1323
1324
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1322

def out_of_disk_report
  @out_of_disk_report
end

#primary_dns_nameString

Output only. DEPRECATED: please use write_endpoint instead. Corresponds to the JSON property primaryDnsName

Returns:

  • (String)


1327
1328
1329
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1327

def primary_dns_name
  @primary_dns_name
end

#projectString

The project ID of the project containing the Cloud SQL instance. The Google apps domain is prefixed if applicable. Corresponds to the JSON property project

Returns:

  • (String)


1333
1334
1335
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1333

def project
  @project
end

Output only. The link to service attachment of PSC instance. Corresponds to the JSON property pscServiceAttachmentLink

Returns:

  • (String)


1338
1339
1340
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1338

def psc_service_attachment_link
  @psc_service_attachment_link
end

#regionString

The geographical region of the Cloud SQL instance. It can be one of the regions where Cloud SQL operates: For example, asia-east1, europe-west1, and us- central1. The default value is us-central1. Corresponds to the JSON property region

Returns:

  • (String)


1346
1347
1348
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1346

def region
  @region
end

#replica_configurationGoogle::Apis::SqladminV1beta4::ReplicaConfiguration

Read-replica configuration for connecting to the primary instance. Corresponds to the JSON property replicaConfiguration



1351
1352
1353
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1351

def replica_configuration
  @replica_configuration
end

#replica_namesArray<String>

The replicas of the instance. Corresponds to the JSON property replicaNames

Returns:

  • (Array<String>)


1356
1357
1358
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1356

def replica_names
  @replica_names
end

#replication_clusterGoogle::Apis::SqladminV1beta4::ReplicationCluster

A primary instance and disaster recovery (DR) replica pair. A DR replica is a cross-region replica that you designate for failover in the event that the primary instance has regional failure. Applicable to MySQL and PostgreSQL. Corresponds to the JSON property replicationCluster



1363
1364
1365
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1363

def replication_cluster
  @replication_cluster
end

#root_passwordString

Initial root password. Use only on creation. You must set root passwords before you can connect to PostgreSQL instances. Corresponds to the JSON property rootPassword

Returns:

  • (String)


1369
1370
1371
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1369

def root_password
  @root_password
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. This status indicates whether the instance satisfies PZI. The status is reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


1375
1376
1377
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1375

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

This status indicates whether the instance satisfies PZS. The status is reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


1382
1383
1384
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1382

def satisfies_pzs
  @satisfies_pzs
end

#scheduled_maintenanceGoogle::Apis::SqladminV1beta4::SqlScheduledMaintenance

Any scheduled maintenance for this instance. Corresponds to the JSON property scheduledMaintenance



1388
1389
1390
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1388

def scheduled_maintenance
  @scheduled_maintenance
end

#secondary_gce_zoneString

The Compute Engine zone that the failover instance is currently serving from for a regional instance. This value could be different from the zone that was specified when the instance was created if the instance has failed over to its secondary/failover zone. Corresponds to the JSON property secondaryGceZone

Returns:

  • (String)


1396
1397
1398
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1396

def secondary_gce_zone
  @secondary_gce_zone
end

The URI of this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


1401
1402
1403
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1401

def self_link
  @self_link
end

#server_ca_certGoogle::Apis::SqladminV1beta4::SslCert

SslCerts Resource Corresponds to the JSON property serverCaCert



1406
1407
1408
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1406

def server_ca_cert
  @server_ca_cert
end

#service_account_email_addressString

The service account email address assigned to the instance. \This property is read-only. Corresponds to the JSON property serviceAccountEmailAddress

Returns:

  • (String)


1412
1413
1414
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1412

def 
  @service_account_email_address
end

#settingsGoogle::Apis::SqladminV1beta4::Settings

Database instance settings. Corresponds to the JSON property settings



1417
1418
1419
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1417

def settings
  @settings
end

#sql_network_architectureString

The SQL network architecture for the instance. Corresponds to the JSON property sqlNetworkArchitecture

Returns:

  • (String)


1422
1423
1424
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1422

def sql_network_architecture
  @sql_network_architecture
end

#stateString

The current serving state of the Cloud SQL instance. Corresponds to the JSON property state

Returns:

  • (String)


1427
1428
1429
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1427

def state
  @state
end

#suspension_reasonArray<String>

If the instance state is SUSPENDED, the reason for the suspension. Corresponds to the JSON property suspensionReason

Returns:

  • (Array<String>)


1432
1433
1434
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1432

def suspension_reason
  @suspension_reason
end

#switch_transaction_logs_to_cloud_storage_enabledBoolean Also known as: switch_transaction_logs_to_cloud_storage_enabled?

Input only. Whether Cloud SQL is enabled to switch storing point-in-time recovery log files from a data disk to Cloud Storage. Corresponds to the JSON property switchTransactionLogsToCloudStorageEnabled

Returns:

  • (Boolean)


1438
1439
1440
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1438

def switch_transaction_logs_to_cloud_storage_enabled
  @switch_transaction_logs_to_cloud_storage_enabled
end

#tagsHash<String,String>

Optional. Input only. Immutable. Tag keys and tag values that are bound to this instance. You must represent each item in the map as: "" : "". For example, a single resource can have the following tags: "123/environment": "production", "123/costCenter": "marketing", For more information on tag creation and management, see https://cloud.google.com/resource-manager/docs/ tags/tags-overview. Corresponds to the JSON property tags

Returns:

  • (Hash<String,String>)


1449
1450
1451
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1449

def tags
  @tags
end

#upgradable_database_versionsArray<Google::Apis::SqladminV1beta4::AvailableDatabaseVersion>

Output only. All database versions that are available for upgrade. Corresponds to the JSON property upgradableDatabaseVersions



1454
1455
1456
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1454

def upgradable_database_versions
  @upgradable_database_versions
end

#write_endpointString

Output only. The dns name of the primary instance in a replication group. Corresponds to the JSON property writeEndpoint

Returns:

  • (String)


1459
1460
1461
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1459

def write_endpoint
  @write_endpoint
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
1516
1517
1518
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1466

def update!(**args)
  @available_maintenance_versions = args[:available_maintenance_versions] if args.key?(:available_maintenance_versions)
  @backend_type = args[:backend_type] if args.key?(:backend_type)
  @connection_name = args[:connection_name] if args.key?(:connection_name)
  @create_time = args[:create_time] if args.key?(:create_time)
  @current_disk_size = args[:current_disk_size] if args.key?(:current_disk_size)
  @database_installed_version = args[:database_installed_version] if args.key?(:database_installed_version)
  @database_version = args[:database_version] if args.key?(:database_version)
  @disk_encryption_configuration = args[:disk_encryption_configuration] if args.key?(:disk_encryption_configuration)
  @disk_encryption_status = args[:disk_encryption_status] if args.key?(:disk_encryption_status)
  @dns_name = args[:dns_name] if args.key?(:dns_name)
  @dns_names = args[:dns_names] if args.key?(:dns_names)
  @etag = args[:etag] if args.key?(:etag)
  @failover_replica = args[:failover_replica] if args.key?(:failover_replica)
  @gce_zone = args[:gce_zone] if args.key?(:gce_zone)
  @gemini_config = args[:gemini_config] if args.key?(:gemini_config)
  @include_replicas_for_major_version_upgrade = args[:include_replicas_for_major_version_upgrade] if args.key?(:include_replicas_for_major_version_upgrade)
  @instance_type = args[:instance_type] if args.key?(:instance_type)
  @ip_addresses = args[:ip_addresses] if args.key?(:ip_addresses)
  @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address)
  @kind = args[:kind] if args.key?(:kind)
  @maintenance_version = args[:maintenance_version] if args.key?(:maintenance_version)
  @master_instance_name = args[:master_instance_name] if args.key?(:master_instance_name)
  @max_disk_size = args[:max_disk_size] if args.key?(:max_disk_size)
  @name = args[:name] if args.key?(:name)
  @node_count = args[:node_count] if args.key?(:node_count)
  @nodes = args[:nodes] if args.key?(:nodes)
  @on_premises_configuration = args[:on_premises_configuration] if args.key?(:on_premises_configuration)
  @out_of_disk_report = args[:out_of_disk_report] if args.key?(:out_of_disk_report)
  @primary_dns_name = args[:primary_dns_name] if args.key?(:primary_dns_name)
  @project = args[:project] if args.key?(:project)
  @psc_service_attachment_link = args[:psc_service_attachment_link] if args.key?(:psc_service_attachment_link)
  @region = args[:region] if args.key?(:region)
  @replica_configuration = args[:replica_configuration] if args.key?(:replica_configuration)
  @replica_names = args[:replica_names] if args.key?(:replica_names)
  @replication_cluster = args[:replication_cluster] if args.key?(:replication_cluster)
  @root_password = args[:root_password] if args.key?(:root_password)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @scheduled_maintenance = args[:scheduled_maintenance] if args.key?(:scheduled_maintenance)
  @secondary_gce_zone = args[:secondary_gce_zone] if args.key?(:secondary_gce_zone)
  @self_link = args[:self_link] if args.key?(:self_link)
  @server_ca_cert = args[:server_ca_cert] if args.key?(:server_ca_cert)
  @service_account_email_address = args[:service_account_email_address] if args.key?(:service_account_email_address)
  @settings = args[:settings] if args.key?(:settings)
  @sql_network_architecture = args[:sql_network_architecture] if args.key?(:sql_network_architecture)
  @state = args[:state] if args.key?(:state)
  @suspension_reason = args[:suspension_reason] if args.key?(:suspension_reason)
  @switch_transaction_logs_to_cloud_storage_enabled = args[:switch_transaction_logs_to_cloud_storage_enabled] if args.key?(:switch_transaction_logs_to_cloud_storage_enabled)
  @tags = args[:tags] if args.key?(:tags)
  @upgradable_database_versions = args[:upgradable_database_versions] if args.key?(:upgradable_database_versions)
  @write_endpoint = args[:write_endpoint] if args.key?(:write_endpoint)
end