Class: Google::Apis::SqladminV1beta4::DatabaseInstance::FailoverReplica

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

The name and status of the failover replica.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FailoverReplica

Returns a new instance of FailoverReplica.



1565
1566
1567
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1565

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#availableBoolean Also known as: available?

The availability status of the failover replica. A false status indicates that the failover replica is out of sync. The primary instance can only failover to the failover replica when the status is true. Corresponds to the JSON property available

Returns:

  • (Boolean)


1555
1556
1557
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1555

def available
  @available
end

#nameString

The name of the failover replica. If specified at instance creation, a failover replica is created for the instance. The name doesn't include the project ID. Corresponds to the JSON property name

Returns:

  • (String)


1563
1564
1565
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1563

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1570
1571
1572
1573
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1570

def update!(**args)
  @available = args[:available] if args.key?(:available)
  @name = args[:name] if args.key?(:name)
end