Class: Google::Apis::SqladminV1beta4::DenyMaintenancePeriod
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::DenyMaintenancePeriod
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
Deny Maintenance Periods. This specifies a date range during when all CSA rollout will be denied.
Instance Attribute Summary collapse
-
#end_date ⇒ String
"deny maintenance period" end date.
-
#start_date ⇒ String
"deny maintenance period" start date.
-
#time ⇒ String
Time in UTC when the "deny maintenance period" starts on start_date and ends on end_date.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DenyMaintenancePeriod
constructor
A new instance of DenyMaintenancePeriod.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DenyMaintenancePeriod
Returns a new instance of DenyMaintenancePeriod.
1783 1784 1785 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1783 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_date ⇒ String
"deny maintenance period" end date. If the year of the end date is empty, the
year of the start date also must be empty. In this case, it means the deny
maintenance period recurs every year. The date is in format yyyy-mm-dd i.e.,
2020-11-01, or mm-dd, i.e., 11-01
Corresponds to the JSON property endDate
1767 1768 1769 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1767 def end_date @end_date end |
#start_date ⇒ String
"deny maintenance period" start date. If the year of the start date is empty,
the year of the end date also must be empty. In this case, it means the deny
maintenance period recurs every year. The date is in format yyyy-mm-dd i.e.,
2020-11-01, or mm-dd, i.e., 11-01
Corresponds to the JSON property startDate
1775 1776 1777 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1775 def start_date @start_date end |
#time ⇒ String
Time in UTC when the "deny maintenance period" starts on start_date and ends
on end_date. The time is in format: HH:mm:SS, i.e., 00:00:00
Corresponds to the JSON property time
1781 1782 1783 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1781 def time @time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1788 1789 1790 1791 1792 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1788 def update!(**args) @end_date = args[:end_date] if args.key?(:end_date) @start_date = args[:start_date] if args.key?(:start_date) @time = args[:time] if args.key?(:time) end |