Class: Google::Apis::SqladminV1beta4::DenyMaintenancePeriod

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Deny Maintenance Periods. This specifies a date range during when all CSA rollout will be denied.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DenyMaintenancePeriod

Returns a new instance of DenyMaintenancePeriod.



1774
1775
1776
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1774

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_dateString

"deny maintenance period" end date. If the year of the end date is empty, the year of the start date also must be empty. In this case, it means the deny maintenance period recurs every year. The date is in format yyyy-mm-dd i.e., 2020-11-01, or mm-dd, i.e., 11-01 Corresponds to the JSON property endDate

Returns:

  • (String)


1758
1759
1760
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1758

def end_date
  @end_date
end

#start_dateString

"deny maintenance period" start date. If the year of the start date is empty, the year of the end date also must be empty. In this case, it means the deny maintenance period recurs every year. The date is in format yyyy-mm-dd i.e., 2020-11-01, or mm-dd, i.e., 11-01 Corresponds to the JSON property startDate

Returns:

  • (String)


1766
1767
1768
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1766

def start_date
  @start_date
end

#timeString

Time in UTC when the "deny maintenance period" starts on start_date and ends on end_date. The time is in format: HH:mm:SS, i.e., 00:00:00 Corresponds to the JSON property time

Returns:

  • (String)


1772
1773
1774
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1772

def time
  @time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1779
1780
1781
1782
1783
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1779

def update!(**args)
  @end_date = args[:end_date] if args.key?(:end_date)
  @start_date = args[:start_date] if args.key?(:start_date)
  @time = args[:time] if args.key?(:time)
end