Class: Google::Apis::SqladminV1beta4::ExportContext
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::ExportContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
Database instance export context.
Defined Under Namespace
Classes: BakExportOptions, CsvExportOptions, SqlExportOptions, TdeExportOptions
Instance Attribute Summary collapse
-
#bak_export_options ⇒ Google::Apis::SqladminV1beta4::ExportContext::BakExportOptions
Options for exporting BAK files (SQL Server-only) Corresponds to the JSON property
bakExportOptions. -
#csv_export_options ⇒ Google::Apis::SqladminV1beta4::ExportContext::CsvExportOptions
Options for exporting data as CSV.
-
#databases ⇒ Array<String>
Databases to be exported.
-
#file_type ⇒ String
The file type for the specified uri.
-
#kind ⇒ String
This is always
sql#exportContext. -
#offload ⇒ Boolean
(also: #offload?)
Whether to perform a serverless export.
-
#sql_export_options ⇒ Google::Apis::SqladminV1beta4::ExportContext::SqlExportOptions
Options for exporting data as SQL statements.
-
#tde_export_options ⇒ Google::Apis::SqladminV1beta4::ExportContext::TdeExportOptions
Optional.
-
#uri ⇒ String
The path to the file in Google Cloud Storage where the export will be stored.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExportContext
constructor
A new instance of ExportContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExportContext
Returns a new instance of ExportContext.
1987 1988 1989 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1987 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bak_export_options ⇒ Google::Apis::SqladminV1beta4::ExportContext::BakExportOptions
Options for exporting BAK files (SQL Server-only)
Corresponds to the JSON property bakExportOptions
1930 1931 1932 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1930 def @bak_export_options end |
#csv_export_options ⇒ Google::Apis::SqladminV1beta4::ExportContext::CsvExportOptions
Options for exporting data as CSV. MySQL and PostgreSQL instances only.
Corresponds to the JSON property csvExportOptions
1935 1936 1937 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1935 def @csv_export_options end |
#databases ⇒ Array<String>
Databases to be exported. MySQL instances: If fileType is SQL and no
database is specified, all databases are exported, except for the mysql
system database. If fileType is CSV, you can specify one database, either
by using this property or by using the csvExportOptions.selectQuery property,
which takes precedence over this property. PostgreSQL instances: If you don'
t specify a database by name, all user databases in the instance are exported.
This excludes system databases and Cloud SQL databases used to manage internal
operations. Exporting all user databases is only available for directory-
formatted parallel export. If fileType is CSV, this database must match
the one specified in the csvExportOptions.selectQuery property. SQL Server
instances: You must specify one database to be exported, and the fileType
must be BAK.
Corresponds to the JSON property databases
1951 1952 1953 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1951 def databases @databases end |
#file_type ⇒ String
The file type for the specified uri.
Corresponds to the JSON property fileType
1956 1957 1958 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1956 def file_type @file_type end |
#kind ⇒ String
This is always sql#exportContext.
Corresponds to the JSON property kind
1961 1962 1963 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1961 def kind @kind end |
#offload ⇒ Boolean Also known as: offload?
Whether to perform a serverless export.
Corresponds to the JSON property offload
1966 1967 1968 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1966 def offload @offload end |
#sql_export_options ⇒ Google::Apis::SqladminV1beta4::ExportContext::SqlExportOptions
Options for exporting data as SQL statements.
Corresponds to the JSON property sqlExportOptions
1972 1973 1974 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1972 def @sql_export_options end |
#tde_export_options ⇒ Google::Apis::SqladminV1beta4::ExportContext::TdeExportOptions
Optional. Export parameters specific to SQL Server TDE certificates
Corresponds to the JSON property tdeExportOptions
1977 1978 1979 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1977 def @tde_export_options end |
#uri ⇒ String
The path to the file in Google Cloud Storage where the export will be stored.
The URI is in the form gs://bucketName/fileName. If the file already exists,
the request succeeds, but the operation fails. If fileType is SQL and the
filename ends with .gz, the contents are compressed.
Corresponds to the JSON property uri
1985 1986 1987 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1985 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 1992 def update!(**args) @bak_export_options = args[:bak_export_options] if args.key?(:bak_export_options) @csv_export_options = args[:csv_export_options] if args.key?(:csv_export_options) @databases = args[:databases] if args.key?(:databases) @file_type = args[:file_type] if args.key?(:file_type) @kind = args[:kind] if args.key?(:kind) @offload = args[:offload] if args.key?(:offload) @sql_export_options = args[:sql_export_options] if args.key?(:sql_export_options) @tde_export_options = args[:tde_export_options] if args.key?(:tde_export_options) @uri = args[:uri] if args.key?(:uri) end |