Class: Google::Apis::SqladminV1beta4::ExportContext::BakExportOptions
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::ExportContext::BakExportOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
Options for exporting BAK files (SQL Server-only)
Instance Attribute Summary collapse
-
#bak_type ⇒ String
Type of this bak file will be export, FULL or DIFF, SQL Server only Corresponds to the JSON property
bakType. -
#copy_only ⇒ Boolean
(also: #copy_only?)
Deprecated: copy_only is deprecated.
-
#differential_base ⇒ Boolean
(also: #differential_base?)
Whether or not the backup can be used as a differential base copy_only backup can not be served as differential base Corresponds to the JSON property
differentialBase. -
#export_log_end_time ⇒ String
Optional.
-
#export_log_start_time ⇒ String
Optional.
-
#stripe_count ⇒ Fixnum
Option for specifying how many stripes to use for the export.
-
#striped ⇒ Boolean
(also: #striped?)
Whether or not the export should be striped.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BakExportOptions
constructor
A new instance of BakExportOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BakExportOptions
Returns a new instance of BakExportOptions.
2056 2057 2058 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2056 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bak_type ⇒ String
Type of this bak file will be export, FULL or DIFF, SQL Server only
Corresponds to the JSON property bakType
2011 2012 2013 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2011 def bak_type @bak_type end |
#copy_only ⇒ Boolean Also known as: copy_only?
Deprecated: copy_only is deprecated. Use differential_base instead
Corresponds to the JSON property copyOnly
2016 2017 2018 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2016 def copy_only @copy_only end |
#differential_base ⇒ Boolean Also known as: differential_base?
Whether or not the backup can be used as a differential base copy_only backup
can not be served as differential base
Corresponds to the JSON property differentialBase
2023 2024 2025 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2023 def differential_base @differential_base end |
#export_log_end_time ⇒ String
Optional. The end timestamp when transaction log will be included in the
export operation. RFC 3339 format (for
example, 2023-10-01T16:19:00.094) in UTC. When omitted, all available logs
until current time will be included. Only applied to Cloud SQL for SQL Server.
Corresponds to the JSON property exportLogEndTime
2032 2033 2034 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2032 def export_log_end_time @export_log_end_time end |
#export_log_start_time ⇒ String
Optional. The begin timestamp when transaction log will be included in the
export operation. RFC 3339 format (for
example, 2023-10-01T16:19:00.094) in UTC. When omitted, all available logs
from the beginning of retention period will be included. Only applied to Cloud
SQL for SQL Server.
Corresponds to the JSON property exportLogStartTime
2041 2042 2043 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2041 def export_log_start_time @export_log_start_time end |
#stripe_count ⇒ Fixnum
Option for specifying how many stripes to use for the export. If blank, and
the value of the striped field is true, the number of stripes is automatically
chosen.
Corresponds to the JSON property stripeCount
2048 2049 2050 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2048 def stripe_count @stripe_count end |
#striped ⇒ Boolean Also known as: striped?
Whether or not the export should be striped.
Corresponds to the JSON property striped
2053 2054 2055 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2053 def striped @striped end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2061 2062 2063 2064 2065 2066 2067 2068 2069 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2061 def update!(**args) @bak_type = args[:bak_type] if args.key?(:bak_type) @copy_only = args[:copy_only] if args.key?(:copy_only) @differential_base = args[:differential_base] if args.key?(:differential_base) @export_log_end_time = args[:export_log_end_time] if args.key?(:export_log_end_time) @export_log_start_time = args[:export_log_start_time] if args.key?(:export_log_start_time) @stripe_count = args[:stripe_count] if args.key?(:stripe_count) @striped = args[:striped] if args.key?(:striped) end |