Class: Google::Apis::SqladminV1beta4::ExportContext::SqlExportOptions
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::ExportContext::SqlExportOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
Options for exporting data as SQL statements.
Defined Under Namespace
Classes: MysqlExportOptions, PostgresExportOptions
Instance Attribute Summary collapse
-
#mysql_export_options ⇒ Google::Apis::SqladminV1beta4::ExportContext::SqlExportOptions::MysqlExportOptions
Options for exporting from MySQL.
-
#parallel ⇒ Boolean
(also: #parallel?)
Optional.
-
#postgres_export_options ⇒ Google::Apis::SqladminV1beta4::ExportContext::SqlExportOptions::PostgresExportOptions
Options for exporting from a Cloud SQL for PostgreSQL instance.
-
#schema_only ⇒ Boolean
(also: #schema_only?)
Export only schemas.
-
#tables ⇒ Array<String>
Tables to export, or that were exported, from the specified database.
-
#threads ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SqlExportOptions
constructor
A new instance of SqlExportOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SqlExportOptions
Returns a new instance of SqlExportOptions.
2216 2217 2218 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2216 def initialize(**args) update!(**args) end |
Instance Attribute Details
#mysql_export_options ⇒ Google::Apis::SqladminV1beta4::ExportContext::SqlExportOptions::MysqlExportOptions
Options for exporting from MySQL.
Corresponds to the JSON property mysqlExportOptions
2185 2186 2187 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2185 def @mysql_export_options end |
#parallel ⇒ Boolean Also known as: parallel?
Optional. Whether or not the export should be parallel.
Corresponds to the JSON property parallel
2190 2191 2192 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2190 def parallel @parallel end |
#postgres_export_options ⇒ Google::Apis::SqladminV1beta4::ExportContext::SqlExportOptions::PostgresExportOptions
Options for exporting from a Cloud SQL for PostgreSQL instance.
Corresponds to the JSON property postgresExportOptions
2196 2197 2198 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2196 def @postgres_export_options end |
#schema_only ⇒ Boolean Also known as: schema_only?
Export only schemas.
Corresponds to the JSON property schemaOnly
2201 2202 2203 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2201 def schema_only @schema_only end |
#tables ⇒ Array<String>
Tables to export, or that were exported, from the specified database. If you
specify tables, specify one and only one database. For PostgreSQL instances,
you can specify only one table.
Corresponds to the JSON property tables
2209 2210 2211 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2209 def tables @tables end |
#threads ⇒ Fixnum
Optional. The number of threads to use for parallel export.
Corresponds to the JSON property threads
2214 2215 2216 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2214 def threads @threads end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2221 2222 2223 2224 2225 2226 2227 2228 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2221 def update!(**args) @mysql_export_options = args[:mysql_export_options] if args.key?(:mysql_export_options) @parallel = args[:parallel] if args.key?(:parallel) @postgres_export_options = args[:postgres_export_options] if args.key?(:postgres_export_options) @schema_only = args[:schema_only] if args.key?(:schema_only) @tables = args[:tables] if args.key?(:tables) @threads = args[:threads] if args.key?(:threads) end |