Class: Google::Apis::SqladminV1beta4::ExportContext::TdeExportOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Optional. Export parameters specific to SQL Server TDE certificates

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TdeExportOptions

Returns a new instance of TdeExportOptions.



2251
2252
2253
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2251

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#certificate_pathString

Required. Path to the TDE certificate public key in the form gs://bucketName/ fileName. The instance must have write access to the location. Applicable only for SQL Server instances. Corresponds to the JSON property certificatePath

Returns:

  • (String)


2232
2233
2234
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2232

def certificate_path
  @certificate_path
end

#nameString

Required. Certificate name. Applicable only for SQL Server instances. Corresponds to the JSON property name

Returns:

  • (String)


2237
2238
2239
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2237

def name
  @name
end

#private_key_passwordString

Required. Password that encrypts the private key. Corresponds to the JSON property privateKeyPassword

Returns:

  • (String)


2242
2243
2244
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2242

def private_key_password
  @private_key_password
end

#private_key_pathString

Required. Path to the TDE certificate private key in the form gs://bucketName/ fileName. The instance must have write access to the location. Applicable only for SQL Server instances. Corresponds to the JSON property privateKeyPath

Returns:

  • (String)


2249
2250
2251
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2249

def private_key_path
  @private_key_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2256
2257
2258
2259
2260
2261
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2256

def update!(**args)
  @certificate_path = args[:certificate_path] if args.key?(:certificate_path)
  @name = args[:name] if args.key?(:name)
  @private_key_password = args[:private_key_password] if args.key?(:private_key_password)
  @private_key_path = args[:private_key_path] if args.key?(:private_key_path)
end