Class: Google::Apis::SqladminV1beta4::FinalBackupConfig
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::FinalBackupConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
Config used to determine the final backup settings for the instance.
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
Whether the final backup is enabled for the instance.
-
#retention_days ⇒ Fixnum
The number of days to retain the final backup after the instance deletion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FinalBackupConfig
constructor
A new instance of FinalBackupConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FinalBackupConfig
Returns a new instance of FinalBackupConfig.
2357 2358 2359 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2357 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
Whether the final backup is enabled for the instance.
Corresponds to the JSON property enabled
2348 2349 2350 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2348 def enabled @enabled end |
#retention_days ⇒ Fixnum
The number of days to retain the final backup after the instance deletion. The
final backup will be purged at (time_of_instance_deletion + retention_days).
Corresponds to the JSON property retentionDays
2355 2356 2357 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2355 def retention_days @retention_days end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2362 2363 2364 2365 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2362 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) @retention_days = args[:retention_days] if args.key?(:retention_days) end |