Class: Google::Apis::SqladminV1beta4::FinalBackupConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Config used to determine the final backup settings for the instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FinalBackupConfig

Returns a new instance of FinalBackupConfig.



2326
2327
2328
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2326

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

Whether the final backup is enabled for the instance. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


2317
2318
2319
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2317

def enabled
  @enabled
end

#retention_daysFixnum

The number of days to retain the final backup after the instance deletion. The final backup will be purged at (time_of_instance_deletion + retention_days). Corresponds to the JSON property retentionDays

Returns:

  • (Fixnum)


2324
2325
2326
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2324

def retention_days
  @retention_days
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2331
2332
2333
2334
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2331

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
  @retention_days = args[:retention_days] if args.key?(:retention_days)
end