Class: Google::Apis::SqladminV1beta4::Flag
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::Flag
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
A flag resource.
Instance Attribute Summary collapse
-
#allowed_int_values ⇒ Array<Fixnum>
Use this field if only certain integers are accepted.
-
#allowed_string_values ⇒ Array<String>
For
STRINGflags, a list of strings that the value can be set to. -
#applies_to ⇒ Array<String>
The database version this flag applies to.
-
#flag_scope ⇒ String
Scope of flag.
-
#in_beta ⇒ Boolean
(also: #in_beta?)
Whether or not the flag is considered in beta.
-
#kind ⇒ String
This is always
sql#flag. -
#max_value ⇒ Fixnum
For
INTEGERflags, the maximum allowed value. -
#min_value ⇒ Fixnum
For
INTEGERflags, the minimum allowed value. -
#name ⇒ String
This is the name of the flag.
-
#recommended_int_value ⇒ Fixnum
Recommended flag value in integer format for UI display.
-
#recommended_string_value ⇒ String
Recommended flag value in string format for UI display.
-
#requires_restart ⇒ Boolean
(also: #requires_restart?)
Indicates whether changing this flag will trigger a database restart.
-
#type ⇒ String
The type of the flag.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Flag
constructor
A new instance of Flag.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Flag
Returns a new instance of Flag.
2419 2420 2421 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2419 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_int_values ⇒ Array<Fixnum>
Use this field if only certain integers are accepted. Can be combined with
min_value and max_value to add additional values.
Corresponds to the JSON property allowedIntValues
2345 2346 2347 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2345 def allowed_int_values @allowed_int_values end |
#allowed_string_values ⇒ Array<String>
For STRING flags, a list of strings that the value can be set to.
Corresponds to the JSON property allowedStringValues
2350 2351 2352 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2350 def allowed_string_values @allowed_string_values end |
#applies_to ⇒ Array<String>
The database version this flag applies to. Can be MySQL instances: MYSQL_8_0,
MYSQL_8_0_18, MYSQL_8_0_26, MYSQL_5_7, or MYSQL_5_6. PostgreSQL
instances: POSTGRES_9_6, POSTGRES_10, POSTGRES_11 or POSTGRES_12. SQL
Server instances: SQLSERVER_2017_STANDARD, SQLSERVER_2017_ENTERPRISE,
SQLSERVER_2017_EXPRESS, SQLSERVER_2017_WEB, SQLSERVER_2019_STANDARD,
SQLSERVER_2019_ENTERPRISE, SQLSERVER_2019_EXPRESS, or SQLSERVER_2019_WEB.
See the complete list.
Corresponds to the JSON property appliesTo
2361 2362 2363 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2361 def applies_to @applies_to end |
#flag_scope ⇒ String
Scope of flag.
Corresponds to the JSON property flagScope
2366 2367 2368 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2366 def flag_scope @flag_scope end |
#in_beta ⇒ Boolean Also known as: in_beta?
Whether or not the flag is considered in beta.
Corresponds to the JSON property inBeta
2371 2372 2373 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2371 def in_beta @in_beta end |
#kind ⇒ String
This is always sql#flag.
Corresponds to the JSON property kind
2377 2378 2379 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2377 def kind @kind end |
#max_value ⇒ Fixnum
For INTEGER flags, the maximum allowed value.
Corresponds to the JSON property maxValue
2382 2383 2384 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2382 def max_value @max_value end |
#min_value ⇒ Fixnum
For INTEGER flags, the minimum allowed value.
Corresponds to the JSON property minValue
2387 2388 2389 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2387 def min_value @min_value end |
#name ⇒ String
This is the name of the flag. Flag names always use underscores, not hyphens,
for example: max_allowed_packet
Corresponds to the JSON property name
2393 2394 2395 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2393 def name @name end |
#recommended_int_value ⇒ Fixnum
Recommended flag value in integer format for UI display.
Corresponds to the JSON property recommendedIntValue
2398 2399 2400 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2398 def recommended_int_value @recommended_int_value end |
#recommended_string_value ⇒ String
Recommended flag value in string format for UI display.
Corresponds to the JSON property recommendedStringValue
2403 2404 2405 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2403 def recommended_string_value @recommended_string_value end |
#requires_restart ⇒ Boolean Also known as: requires_restart?
Indicates whether changing this flag will trigger a database restart. Only
applicable to Second Generation instances.
Corresponds to the JSON property requiresRestart
2409 2410 2411 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2409 def requires_restart @requires_restart end |
#type ⇒ String
The type of the flag. Flags are typed to being BOOLEAN, STRING, INTEGER
or NONE. NONE is used for flags which do not take a value, such as
skip_grant_tables.
Corresponds to the JSON property type
2417 2418 2419 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2417 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2424 2425 2426 2427 2428 2429 2430 2431 2432 2433 2434 2435 2436 2437 2438 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2424 def update!(**args) @allowed_int_values = args[:allowed_int_values] if args.key?(:allowed_int_values) @allowed_string_values = args[:allowed_string_values] if args.key?(:allowed_string_values) @applies_to = args[:applies_to] if args.key?(:applies_to) @flag_scope = args[:flag_scope] if args.key?(:flag_scope) @in_beta = args[:in_beta] if args.key?(:in_beta) @kind = args[:kind] if args.key?(:kind) @max_value = args[:max_value] if args.key?(:max_value) @min_value = args[:min_value] if args.key?(:min_value) @name = args[:name] if args.key?(:name) @recommended_int_value = args[:recommended_int_value] if args.key?(:recommended_int_value) @recommended_string_value = args[:recommended_string_value] if args.key?(:recommended_string_value) @requires_restart = args[:requires_restart] if args.key?(:requires_restart) @type = args[:type] if args.key?(:type) end |