Class: Google::Apis::SqladminV1beta4::ImportContext::CsvImportOptions
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::ImportContext::CsvImportOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
Options for importing data as CSV.
Instance Attribute Summary collapse
-
#columns ⇒ Array<String>
The columns to which CSV data is imported.
-
#escape_character ⇒ String
Specifies the character that should appear before a data character that needs to be escaped.
-
#fields_terminated_by ⇒ String
Specifies the character that separates columns within each row (line) of the file.
-
#lines_terminated_by ⇒ String
This is used to separate lines.
-
#quote_character ⇒ String
Specifies the quoting character to be used when a data value is quoted.
-
#table ⇒ String
The table to which CSV data is imported.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CsvImportOptions
constructor
A new instance of CsvImportOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CsvImportOptions
Returns a new instance of CsvImportOptions.
2854 2855 2856 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2854 def initialize(**args) update!(**args) end |
Instance Attribute Details
#columns ⇒ Array<String>
The columns to which CSV data is imported. If not specified, all columns of
the database table are loaded with CSV data.
Corresponds to the JSON property columns
2824 2825 2826 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2824 def columns @columns end |
#escape_character ⇒ String
Specifies the character that should appear before a data character that needs
to be escaped.
Corresponds to the JSON property escapeCharacter
2830 2831 2832 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2830 def escape_character @escape_character end |
#fields_terminated_by ⇒ String
Specifies the character that separates columns within each row (line) of the
file.
Corresponds to the JSON property fieldsTerminatedBy
2836 2837 2838 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2836 def fields_terminated_by @fields_terminated_by end |
#lines_terminated_by ⇒ String
This is used to separate lines. If a line does not contain all fields, the
rest of the columns are set to their default values.
Corresponds to the JSON property linesTerminatedBy
2842 2843 2844 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2842 def lines_terminated_by @lines_terminated_by end |
#quote_character ⇒ String
Specifies the quoting character to be used when a data value is quoted.
Corresponds to the JSON property quoteCharacter
2847 2848 2849 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2847 def quote_character @quote_character end |
#table ⇒ String
The table to which CSV data is imported.
Corresponds to the JSON property table
2852 2853 2854 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2852 def table @table end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2859 2860 2861 2862 2863 2864 2865 2866 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2859 def update!(**args) @columns = args[:columns] if args.key?(:columns) @escape_character = args[:escape_character] if args.key?(:escape_character) @fields_terminated_by = args[:fields_terminated_by] if args.key?(:fields_terminated_by) @lines_terminated_by = args[:lines_terminated_by] if args.key?(:lines_terminated_by) @quote_character = args[:quote_character] if args.key?(:quote_character) @table = args[:table] if args.key?(:table) end |