Class: Google::Apis::SqladminV1beta4::ImportContext::TdeImportOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Optional. Import parameters specific to SQL Server .TDE files Import parameters specific to SQL Server TDE certificates

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TdeImportOptions

Returns a new instance of TdeImportOptions.



2907
2908
2909
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2907

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#certificate_pathString

Required. Path to the TDE certificate public key in the form gs://bucketName/ fileName. The instance must have read access to the file. Applicable only for SQL Server instances. Corresponds to the JSON property certificatePath

Returns:

  • (String)


2888
2889
2890
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2888

def certificate_path
  @certificate_path
end

#nameString

Required. Certificate name. Applicable only for SQL Server instances. Corresponds to the JSON property name

Returns:

  • (String)


2893
2894
2895
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2893

def name
  @name
end

#private_key_passwordString

Required. Password that encrypts the private key. Corresponds to the JSON property privateKeyPassword

Returns:

  • (String)


2898
2899
2900
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2898

def private_key_password
  @private_key_password
end

#private_key_pathString

Required. Path to the TDE certificate private key in the form gs://bucketName/ fileName. The instance must have read access to the file. Applicable only for SQL Server instances. Corresponds to the JSON property privateKeyPath

Returns:

  • (String)


2905
2906
2907
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2905

def private_key_path
  @private_key_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2912
2913
2914
2915
2916
2917
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2912

def update!(**args)
  @certificate_path = args[:certificate_path] if args.key?(:certificate_path)
  @name = args[:name] if args.key?(:name)
  @private_key_password = args[:private_key_password] if args.key?(:private_key_password)
  @private_key_path = args[:private_key_path] if args.key?(:private_key_path)
end