Class: Google::Apis::SqladminV1beta4::InsertSslCertsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

SslCert insert response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InsertSslCertsResponse

Returns a new instance of InsertSslCertsResponse.



6270
6271
6272
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6270

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_certGoogle::Apis::SqladminV1beta4::SslCertDetail

SslCertDetail. Corresponds to the JSON property clientCert



6251
6252
6253
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6251

def client_cert
  @client_cert
end

#kindString

This is always sql#sslCertsInsert. Corresponds to the JSON property kind

Returns:

  • (String)


6256
6257
6258
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6256

def kind
  @kind
end

#operationGoogle::Apis::SqladminV1beta4::Operation

An Operation resource. For successful operations that return an Operation resource, only the fields relevant to the operation are populated in the resource. Corresponds to the JSON property operation



6263
6264
6265
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6263

def operation
  @operation
end

#server_ca_certGoogle::Apis::SqladminV1beta4::SslCert

SslCerts Resource Corresponds to the JSON property serverCaCert



6268
6269
6270
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6268

def server_ca_cert
  @server_ca_cert
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6275
6276
6277
6278
6279
6280
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6275

def update!(**args)
  @client_cert = args[:client_cert] if args.key?(:client_cert)
  @kind = args[:kind] if args.key?(:kind)
  @operation = args[:operation] if args.key?(:operation)
  @server_ca_cert = args[:server_ca_cert] if args.key?(:server_ca_cert)
end