Class: Google::Apis::SqladminV1beta4::InsertSslCertsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

SslCert insert response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InsertSslCertsResponse

Returns a new instance of InsertSslCertsResponse.



6232
6233
6234
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6232

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_certGoogle::Apis::SqladminV1beta4::SslCertDetail

SslCertDetail. Corresponds to the JSON property clientCert



6213
6214
6215
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6213

def client_cert
  @client_cert
end

#kindString

This is always sql#sslCertsInsert. Corresponds to the JSON property kind

Returns:

  • (String)


6218
6219
6220
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6218

def kind
  @kind
end

#operationGoogle::Apis::SqladminV1beta4::Operation

An Operation resource. For successful operations that return an Operation resource, only the fields relevant to the operation are populated in the resource. Corresponds to the JSON property operation



6225
6226
6227
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6225

def operation
  @operation
end

#server_ca_certGoogle::Apis::SqladminV1beta4::SslCert

SslCerts Resource Corresponds to the JSON property serverCaCert



6230
6231
6232
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6230

def server_ca_cert
  @server_ca_cert
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6237
6238
6239
6240
6241
6242
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6237

def update!(**args)
  @client_cert = args[:client_cert] if args.key?(:client_cert)
  @kind = args[:kind] if args.key?(:kind)
  @operation = args[:operation] if args.key?(:operation)
  @server_ca_cert = args[:server_ca_cert] if args.key?(:server_ca_cert)
end