Class: Google::Apis::SqladminV1beta4::InsightsConfig
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::InsightsConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
Insights configuration. This specifies when Cloud SQL Insights feature is enabled and optional configuration.
Instance Attribute Summary collapse
-
#enhanced_query_insights_enabled ⇒ Boolean
(also: #enhanced_query_insights_enabled?)
Optional.
-
#query_insights_enabled ⇒ Boolean
(also: #query_insights_enabled?)
Whether Query Insights feature is enabled.
-
#query_plans_per_minute ⇒ Fixnum
Number of query execution plans captured by Insights per minute for all queries combined.
-
#query_string_length ⇒ Fixnum
Maximum query length stored in bytes.
-
#record_application_tags ⇒ Boolean
(also: #record_application_tags?)
Whether Query Insights will record application tags from query when enabled.
-
#record_client_address ⇒ Boolean
(also: #record_client_address?)
Whether Query Insights will record client address when enabled.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InsightsConfig
constructor
A new instance of InsightsConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InsightsConfig
Returns a new instance of InsightsConfig.
3024 3025 3026 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3024 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enhanced_query_insights_enabled ⇒ Boolean Also known as: enhanced_query_insights_enabled?
Optional. Whether enhanced query insights feature is enabled.
Corresponds to the JSON property enhancedQueryInsightsEnabled
2989 2990 2991 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2989 def enhanced_query_insights_enabled @enhanced_query_insights_enabled end |
#query_insights_enabled ⇒ Boolean Also known as: query_insights_enabled?
Whether Query Insights feature is enabled.
Corresponds to the JSON property queryInsightsEnabled
2995 2996 2997 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2995 def query_insights_enabled @query_insights_enabled end |
#query_plans_per_minute ⇒ Fixnum
Number of query execution plans captured by Insights per minute for all
queries combined. Default is 5.
Corresponds to the JSON property queryPlansPerMinute
3002 3003 3004 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3002 def query_plans_per_minute @query_plans_per_minute end |
#query_string_length ⇒ Fixnum
Maximum query length stored in bytes. Default value: 1024 bytes. Range: 256-
4500 bytes. Query lengths greater than this field value will be truncated to
this value. When unset, query length will be the default value. Changing query
length will restart the database.
Corresponds to the JSON property queryStringLength
3010 3011 3012 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3010 def query_string_length @query_string_length end |
#record_application_tags ⇒ Boolean Also known as:
Whether Query Insights will record application tags from query when enabled.
Corresponds to the JSON property recordApplicationTags
3015 3016 3017 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3015 def @record_application_tags end |
#record_client_address ⇒ Boolean Also known as: record_client_address?
Whether Query Insights will record client address when enabled.
Corresponds to the JSON property recordClientAddress
3021 3022 3023 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3021 def record_client_address @record_client_address end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3029 3030 3031 3032 3033 3034 3035 3036 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3029 def update!(**args) @enhanced_query_insights_enabled = args[:enhanced_query_insights_enabled] if args.key?(:enhanced_query_insights_enabled) @query_insights_enabled = args[:query_insights_enabled] if args.key?(:query_insights_enabled) @query_plans_per_minute = args[:query_plans_per_minute] if args.key?(:query_plans_per_minute) @query_string_length = args[:query_string_length] if args.key?(:query_string_length) @record_application_tags = args[:record_application_tags] if args.key?(:record_application_tags) @record_client_address = args[:record_client_address] if args.key?(:record_client_address) end |