Class: Google::Apis::SqladminV1beta4::InsightsConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Insights configuration. This specifies when Cloud SQL Insights feature is enabled and optional configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InsightsConfig

Returns a new instance of InsightsConfig.



3016
3017
3018
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3016

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enhanced_query_insights_enabledBoolean Also known as: enhanced_query_insights_enabled?

Optional. Whether enhanced query insights feature is enabled. Corresponds to the JSON property enhancedQueryInsightsEnabled

Returns:

  • (Boolean)


2981
2982
2983
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2981

def enhanced_query_insights_enabled
  @enhanced_query_insights_enabled
end

#query_insights_enabledBoolean Also known as: query_insights_enabled?

Whether Query Insights feature is enabled. Corresponds to the JSON property queryInsightsEnabled

Returns:

  • (Boolean)


2987
2988
2989
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2987

def query_insights_enabled
  @query_insights_enabled
end

#query_plans_per_minuteFixnum

Number of query execution plans captured by Insights per minute for all queries combined. Default is 5. Corresponds to the JSON property queryPlansPerMinute

Returns:

  • (Fixnum)


2994
2995
2996
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 2994

def query_plans_per_minute
  @query_plans_per_minute
end

#query_string_lengthFixnum

Maximum query length stored in bytes. Default value: 1024 bytes. Range: 256- 4500 bytes. Query lengths greater than this field value will be truncated to this value. When unset, query length will be the default value. Changing query length will restart the database. Corresponds to the JSON property queryStringLength

Returns:

  • (Fixnum)


3002
3003
3004
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3002

def query_string_length
  @query_string_length
end

#record_application_tagsBoolean Also known as: record_application_tags?

Whether Query Insights will record application tags from query when enabled. Corresponds to the JSON property recordApplicationTags

Returns:

  • (Boolean)


3007
3008
3009
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3007

def record_application_tags
  @record_application_tags
end

#record_client_addressBoolean Also known as: record_client_address?

Whether Query Insights will record client address when enabled. Corresponds to the JSON property recordClientAddress

Returns:

  • (Boolean)


3013
3014
3015
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3013

def record_client_address
  @record_client_address
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3021
3022
3023
3024
3025
3026
3027
3028
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3021

def update!(**args)
  @enhanced_query_insights_enabled = args[:enhanced_query_insights_enabled] if args.key?(:enhanced_query_insights_enabled)
  @query_insights_enabled = args[:query_insights_enabled] if args.key?(:query_insights_enabled)
  @query_plans_per_minute = args[:query_plans_per_minute] if args.key?(:query_plans_per_minute)
  @query_string_length = args[:query_string_length] if args.key?(:query_string_length)
  @record_application_tags = args[:record_application_tags] if args.key?(:record_application_tags)
  @record_client_address = args[:record_client_address] if args.key?(:record_client_address)
end