Class: Google::Apis::SqladminV1beta4::ListBackupsResponse
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::ListBackupsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
The response payload containing a list of the backups.
Instance Attribute Summary collapse
-
#backups ⇒ Array<Google::Apis::SqladminV1beta4::Backup>
A list of backups.
-
#next_page_token ⇒ String
A token, which can be sent as
page_tokento retrieve the next page. -
#warnings ⇒ Array<Google::Apis::SqladminV1beta4::ApiWarning>
If a region isn't unavailable or if an unknown error occurs, then a warning message is returned.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListBackupsResponse
constructor
A new instance of ListBackupsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListBackupsResponse
Returns a new instance of ListBackupsResponse.
3653 3654 3655 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3653 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backups ⇒ Array<Google::Apis::SqladminV1beta4::Backup>
A list of backups.
Corresponds to the JSON property backups
3639 3640 3641 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3639 def backups @backups end |
#next_page_token ⇒ String
A token, which can be sent as page_token to retrieve the next page. If this
field is omitted, then there aren't subsequent pages.
Corresponds to the JSON property nextPageToken
3645 3646 3647 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3645 def next_page_token @next_page_token end |
#warnings ⇒ Array<Google::Apis::SqladminV1beta4::ApiWarning>
If a region isn't unavailable or if an unknown error occurs, then a warning
message is returned.
Corresponds to the JSON property warnings
3651 3652 3653 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3651 def warnings @warnings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3658 3659 3660 3661 3662 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3658 def update!(**args) @backups = args[:backups] if args.key?(:backups) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @warnings = args[:warnings] if args.key?(:warnings) end |