Class: Google::Apis::SqladminV1beta4::ListInstancesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Database instances list response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListInstancesResponse

Returns a new instance of ListInstancesResponse.



3196
3197
3198
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3196

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#itemsArray<Google::Apis::SqladminV1beta4::DatabaseInstance>

List of database instance resources. Corresponds to the JSON property items



3178
3179
3180
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3178

def items
  @items
end

#kindString

This is always sql#instancesList. Corresponds to the JSON property kind

Returns:

  • (String)


3183
3184
3185
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3183

def kind
  @kind
end

#next_page_tokenString

The continuation token, used to page through large result sets. Provide this value in a subsequent request to return the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3189
3190
3191
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3189

def next_page_token
  @next_page_token
end

#warningsArray<Google::Apis::SqladminV1beta4::ApiWarning>

List of warnings that occurred while handling the request. Corresponds to the JSON property warnings



3194
3195
3196
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3194

def warnings
  @warnings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3201
3202
3203
3204
3205
3206
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3201

def update!(**args)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warnings = args[:warnings] if args.key?(:warnings)
end