Class: Google::Apis::SqladminV1beta4::LocationPreference

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Preferred location. This specifies where a Cloud SQL instance is located. Note that if the preferred location is not available, the instance will be located as close as possible within the region. Only one location may be specified.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LocationPreference

Returns a new instance of LocationPreference.



3754
3755
3756
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3754

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#follow_gae_applicationString

The App Engine application to follow, it must be in the same region as the Cloud SQL instance. WARNING: Changing this might restart the instance. Corresponds to the JSON property followGaeApplication

Returns:

  • (String)


3734
3735
3736
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3734

def follow_gae_application
  @follow_gae_application
end

#kindString

This is always sql#locationPreference. Corresponds to the JSON property kind

Returns:

  • (String)


3739
3740
3741
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3739

def kind
  @kind
end

#secondary_zoneString

The preferred Compute Engine zone for the secondary/failover (for example: us- central1-a, us-central1-b, etc.). To disable this field, set it to ' no_secondary_zone'. Corresponds to the JSON property secondaryZone

Returns:

  • (String)


3746
3747
3748
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3746

def secondary_zone
  @secondary_zone
end

#zoneString

The preferred Compute Engine zone (for example: us-central1-a, us-central1-b, etc.). WARNING: Changing this might restart the instance. Corresponds to the JSON property zone

Returns:

  • (String)


3752
3753
3754
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3752

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3759
3760
3761
3762
3763
3764
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3759

def update!(**args)
  @follow_gae_application = args[:follow_gae_application] if args.key?(:follow_gae_application)
  @kind = args[:kind] if args.key?(:kind)
  @secondary_zone = args[:secondary_zone] if args.key?(:secondary_zone)
  @zone = args[:zone] if args.key?(:zone)
end