Class: Google::Apis::SqladminV1beta4::LocationPreference
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::LocationPreference
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
Preferred location. This specifies where a Cloud SQL instance is located. Note that if the preferred location is not available, the instance will be located as close as possible within the region. Only one location may be specified.
Instance Attribute Summary collapse
-
#follow_gae_application ⇒ String
The App Engine application to follow, it must be in the same region as the Cloud SQL instance.
-
#kind ⇒ String
This is always
sql#locationPreference. -
#secondary_zone ⇒ String
The preferred Compute Engine zone for the secondary/failover (for example: us- central1-a, us-central1-b, etc.).
-
#zone ⇒ String
The preferred Compute Engine zone (for example: us-central1-a, us-central1-b, etc.).
Instance Method Summary collapse
-
#initialize(**args) ⇒ LocationPreference
constructor
A new instance of LocationPreference.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LocationPreference
Returns a new instance of LocationPreference.
3733 3734 3735 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3733 def initialize(**args) update!(**args) end |
Instance Attribute Details
#follow_gae_application ⇒ String
The App Engine application to follow, it must be in the same region as the
Cloud SQL instance. WARNING: Changing this might restart the instance.
Corresponds to the JSON property followGaeApplication
3713 3714 3715 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3713 def follow_gae_application @follow_gae_application end |
#kind ⇒ String
This is always sql#locationPreference.
Corresponds to the JSON property kind
3718 3719 3720 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3718 def kind @kind end |
#secondary_zone ⇒ String
The preferred Compute Engine zone for the secondary/failover (for example: us-
central1-a, us-central1-b, etc.). To disable this field, set it to '
no_secondary_zone'.
Corresponds to the JSON property secondaryZone
3725 3726 3727 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3725 def secondary_zone @secondary_zone end |
#zone ⇒ String
The preferred Compute Engine zone (for example: us-central1-a, us-central1-b,
etc.). WARNING: Changing this might restart the instance.
Corresponds to the JSON property zone
3731 3732 3733 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3731 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3738 3739 3740 3741 3742 3743 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3738 def update!(**args) @follow_gae_application = args[:follow_gae_application] if args.key?(:follow_gae_application) @kind = args[:kind] if args.key?(:kind) @secondary_zone = args[:secondary_zone] if args.key?(:secondary_zone) @zone = args[:zone] if args.key?(:zone) end |