Class: Google::Apis::SqladminV1beta4::Operation
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::Operation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
An Operation resource. For successful operations that return an Operation resource, only the fields relevant to the operation are populated in the resource.
Instance Attribute Summary collapse
-
#acquire_ssrs_lease_context ⇒ Google::Apis::SqladminV1beta4::AcquireSsrsLeaseContext
Acquire SSRS lease context.
-
#api_warning ⇒ Google::Apis::SqladminV1beta4::ApiWarning
An Admin API warning message.
-
#backup_context ⇒ Google::Apis::SqladminV1beta4::BackupContext
Backup context.
-
#end_time ⇒ String
The time this operation finished in UTC timezone in RFC 3339 format, for example
2012-11-15T16:19:00.094Z. -
#error ⇒ Google::Apis::SqladminV1beta4::OperationErrors
Database instance operation errors list wrapper.
-
#export_context ⇒ Google::Apis::SqladminV1beta4::ExportContext
Database instance export context.
-
#import_context ⇒ Google::Apis::SqladminV1beta4::ImportContext
Database instance import context.
-
#insert_time ⇒ String
The time this operation was enqueued in UTC timezone in RFC 3339 format, for example
2012-11-15T16:19:00.094Z. -
#kind ⇒ String
This is always
sql#operation. -
#name ⇒ String
An identifier that uniquely identifies the operation.
-
#operation_type ⇒ String
The type of the operation.
-
#pre_check_major_version_upgrade_context ⇒ Google::Apis::SqladminV1beta4::PreCheckMajorVersionUpgradeContext
Pre-check major version upgrade context.
-
#self_link ⇒ String
The URI of this resource.
-
#start_time ⇒ String
The time this operation actually started in UTC timezone in RFC 3339 format, for example
2012-11-15T16:19:00.094Z. -
#status ⇒ String
The status of an operation.
-
#sub_operation_type ⇒ Google::Apis::SqladminV1beta4::SqlSubOperationType
The sub operation type based on the operation type.
-
#target_id ⇒ String
Name of the resource on which this operation runs.
-
#target_link ⇒ String
Corresponds to the JSON property
targetLink. -
#target_project ⇒ String
The project ID of the target instance related to this operation.
-
#user ⇒ String
The email address of the user who initiated this operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Operation
constructor
A new instance of Operation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Operation
Returns a new instance of Operation.
4097 4098 4099 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4097 def initialize(**args) update!(**args) end |
Instance Attribute Details
#acquire_ssrs_lease_context ⇒ Google::Apis::SqladminV1beta4::AcquireSsrsLeaseContext
Acquire SSRS lease context.
Corresponds to the JSON property acquireSsrsLeaseContext
3993 3994 3995 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3993 def acquire_ssrs_lease_context @acquire_ssrs_lease_context end |
#api_warning ⇒ Google::Apis::SqladminV1beta4::ApiWarning
An Admin API warning message.
Corresponds to the JSON property apiWarning
3998 3999 4000 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 3998 def api_warning @api_warning end |
#backup_context ⇒ Google::Apis::SqladminV1beta4::BackupContext
Backup context.
Corresponds to the JSON property backupContext
4003 4004 4005 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4003 def backup_context @backup_context end |
#end_time ⇒ String
The time this operation finished in UTC timezone in RFC 3339 format, for example 2012-11-15T16:19:00.094Z.
Corresponds to the JSON property endTime
4009 4010 4011 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4009 def end_time @end_time end |
#error ⇒ Google::Apis::SqladminV1beta4::OperationErrors
Database instance operation errors list wrapper.
Corresponds to the JSON property error
4014 4015 4016 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4014 def error @error end |
#export_context ⇒ Google::Apis::SqladminV1beta4::ExportContext
Database instance export context.
Corresponds to the JSON property exportContext
4019 4020 4021 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4019 def export_context @export_context end |
#import_context ⇒ Google::Apis::SqladminV1beta4::ImportContext
Database instance import context.
Corresponds to the JSON property importContext
4024 4025 4026 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4024 def import_context @import_context end |
#insert_time ⇒ String
The time this operation was enqueued in UTC timezone in RFC 3339 format, for example 2012-11-15T16:19:00.094Z.
Corresponds to the JSON property insertTime
4030 4031 4032 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4030 def insert_time @insert_time end |
#kind ⇒ String
This is always sql#operation.
Corresponds to the JSON property kind
4035 4036 4037 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4035 def kind @kind end |
#name ⇒ String
An identifier that uniquely identifies the operation. You can use this
identifier to retrieve the Operations resource that has information about the
operation.
Corresponds to the JSON property name
4042 4043 4044 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4042 def name @name end |
#operation_type ⇒ String
The type of the operation. Valid values are: * CREATE * DELETE * UPDATE *
RESTART * IMPORT * EXPORT * BACKUP_VOLUME * RESTORE_VOLUME *
CREATE_USER * DELETE_USER * CREATE_DATABASE * DELETE_DATABASE
Corresponds to the JSON property operationType
4049 4050 4051 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4049 def operation_type @operation_type end |
#pre_check_major_version_upgrade_context ⇒ Google::Apis::SqladminV1beta4::PreCheckMajorVersionUpgradeContext
Pre-check major version upgrade context.
Corresponds to the JSON property preCheckMajorVersionUpgradeContext
4054 4055 4056 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4054 def pre_check_major_version_upgrade_context @pre_check_major_version_upgrade_context end |
#self_link ⇒ String
The URI of this resource.
Corresponds to the JSON property selfLink
4059 4060 4061 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4059 def self_link @self_link end |
#start_time ⇒ String
The time this operation actually started in UTC timezone in RFC 3339 format, for example 2012-11-15T16:19:00.094Z.
Corresponds to the JSON property startTime
4065 4066 4067 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4065 def start_time @start_time end |
#status ⇒ String
The status of an operation.
Corresponds to the JSON property status
4070 4071 4072 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4070 def status @status end |
#sub_operation_type ⇒ Google::Apis::SqladminV1beta4::SqlSubOperationType
The sub operation type based on the operation type.
Corresponds to the JSON property subOperationType
4075 4076 4077 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4075 def sub_operation_type @sub_operation_type end |
#target_id ⇒ String
Name of the resource on which this operation runs.
Corresponds to the JSON property targetId
4080 4081 4082 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4080 def target_id @target_id end |
#target_link ⇒ String
Corresponds to the JSON property targetLink
4085 4086 4087 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4085 def target_link @target_link end |
#target_project ⇒ String
The project ID of the target instance related to this operation.
Corresponds to the JSON property targetProject
4090 4091 4092 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4090 def target_project @target_project end |
#user ⇒ String
The email address of the user who initiated this operation.
Corresponds to the JSON property user
4095 4096 4097 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4095 def user @user end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 4118 4119 4120 4121 4122 4123 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4102 def update!(**args) @acquire_ssrs_lease_context = args[:acquire_ssrs_lease_context] if args.key?(:acquire_ssrs_lease_context) @api_warning = args[:api_warning] if args.key?(:api_warning) @backup_context = args[:backup_context] if args.key?(:backup_context) @end_time = args[:end_time] if args.key?(:end_time) @error = args[:error] if args.key?(:error) @export_context = args[:export_context] if args.key?(:export_context) @import_context = args[:import_context] if args.key?(:import_context) @insert_time = args[:insert_time] if args.key?(:insert_time) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @operation_type = args[:operation_type] if args.key?(:operation_type) @pre_check_major_version_upgrade_context = args[:pre_check_major_version_upgrade_context] if args.key?(:pre_check_major_version_upgrade_context) @self_link = args[:self_link] if args.key?(:self_link) @start_time = args[:start_time] if args.key?(:start_time) @status = args[:status] if args.key?(:status) @sub_operation_type = args[:sub_operation_type] if args.key?(:sub_operation_type) @target_id = args[:target_id] if args.key?(:target_id) @target_link = args[:target_link] if args.key?(:target_link) @target_project = args[:target_project] if args.key?(:target_project) @user = args[:user] if args.key?(:user) end |