Class: Google::Apis::SqladminV1beta4::OperationErrors
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::OperationErrors
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
Database instance operation errors list wrapper.
Instance Attribute Summary collapse
-
#errors ⇒ Array<Google::Apis::SqladminV1beta4::OperationError>
The list of errors encountered while processing this operation.
-
#kind ⇒ String
This is always
sql#operationErrors.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationErrors
constructor
A new instance of OperationErrors.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationErrors
Returns a new instance of OperationErrors.
4171 4172 4173 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4171 def initialize(**args) update!(**args) end |
Instance Attribute Details
#errors ⇒ Array<Google::Apis::SqladminV1beta4::OperationError>
The list of errors encountered while processing this operation.
Corresponds to the JSON property errors
4164 4165 4166 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4164 def errors @errors end |
#kind ⇒ String
This is always sql#operationErrors.
Corresponds to the JSON property kind
4169 4170 4171 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4169 def kind @kind end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4176 4177 4178 4179 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4176 def update!(**args) @errors = args[:errors] if args.key?(:errors) @kind = args[:kind] if args.key?(:kind) end |