Class: Google::Apis::SqladminV1beta4::PerformanceCaptureConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Performance Capture configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PerformanceCaptureConfig

Returns a new instance of PerformanceCaptureConfig.



4421
4422
4423
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4421

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

Optional. Enable or disable the Performance Capture. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


4389
4390
4391
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4389

def enabled
  @enabled
end

#probe_thresholdFixnum

Optional. The minimum number of consecutive readings above threshold that triggers instance state capture. Corresponds to the JSON property probeThreshold

Returns:

  • (Fixnum)


4396
4397
4398
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4396

def probe_threshold
  @probe_threshold
end

#probing_interval_secondsFixnum

Optional. The time interval in seconds between any two probes. Corresponds to the JSON property probingIntervalSeconds

Returns:

  • (Fixnum)


4401
4402
4403
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4401

def probing_interval_seconds
  @probing_interval_seconds
end

#running_threads_thresholdFixnum

Optional. The minimum number of server threads running to trigger the capture on primary. Corresponds to the JSON property runningThreadsThreshold

Returns:

  • (Fixnum)


4407
4408
4409
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4407

def running_threads_threshold
  @running_threads_threshold
end

#seconds_behind_source_thresholdFixnum

Optional. The minimum number of seconds replica must be lagging behind primary to trigger capture on replica. Corresponds to the JSON property secondsBehindSourceThreshold

Returns:

  • (Fixnum)


4413
4414
4415
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4413

def seconds_behind_source_threshold
  @seconds_behind_source_threshold
end

#transaction_duration_thresholdFixnum

Optional. The amount of time in seconds that a transaction needs to have been open before the watcher starts recording it. Corresponds to the JSON property transactionDurationThreshold

Returns:

  • (Fixnum)


4419
4420
4421
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4419

def transaction_duration_threshold
  @transaction_duration_threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4426
4427
4428
4429
4430
4431
4432
4433
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4426

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
  @probe_threshold = args[:probe_threshold] if args.key?(:probe_threshold)
  @probing_interval_seconds = args[:probing_interval_seconds] if args.key?(:probing_interval_seconds)
  @running_threads_threshold = args[:running_threads_threshold] if args.key?(:running_threads_threshold)
  @seconds_behind_source_threshold = args[:seconds_behind_source_threshold] if args.key?(:seconds_behind_source_threshold)
  @transaction_duration_threshold = args[:transaction_duration_threshold] if args.key?(:transaction_duration_threshold)
end