Class: Google::Apis::SqladminV1beta4::PointInTimeRestoreContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Context to perform a point-in-time restore of an instance managed by Backup and Disaster Recovery (DR) Service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PointInTimeRestoreContext

Returns a new instance of PointInTimeRestoreContext.



4527
4528
4529
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4527

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allocated_ip_rangeString

Optional. The name of the allocated IP range for the internal IP Cloud SQL instance. For example: "google-managed-services-default". If you set this, then Cloud SQL creates the IP address for the cloned instance in the allocated range. This range must comply with RFC 1035 standards. Specifically, the name must be 1-63 characters long and match the regular expression a-z?. Reserved for future use. Corresponds to the JSON property allocatedIpRange

Returns:

  • (String)


4488
4489
4490
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4488

def allocated_ip_range
  @allocated_ip_range
end

#datasourceString

The Backup and Disaster Recovery (DR) Service Datasource URI. Format: projects/ project/locations/region/backupVaults/backupvault/dataSources/ datasource. Corresponds to the JSON property datasource

Returns:

  • (String)


4495
4496
4497
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4495

def datasource
  @datasource
end

#point_in_timeString

Required. The date and time to which you want to restore the instance. Corresponds to the JSON property pointInTime

Returns:

  • (String)


4500
4501
4502
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4500

def point_in_time
  @point_in_time
end

#preferred_secondary_zoneString

Optional. Point-in-time recovery of a regional instance in the specified zones. If not specified, clone to the same secondary zone as the source instance. This value cannot be the same as the preferred_zone field. Corresponds to the JSON property preferredSecondaryZone

Returns:

  • (String)


4507
4508
4509
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4507

def preferred_secondary_zone
  @preferred_secondary_zone
end

#preferred_zoneString

Optional. Point-in-time recovery of an instance to the specified zone. If no zone is specified, then clone to the same primary zone as the source instance. Corresponds to the JSON property preferredZone

Returns:

  • (String)


4513
4514
4515
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4513

def preferred_zone
  @preferred_zone
end

#private_networkString

Optional. The resource link for the VPC network from which the Cloud SQL instance is accessible for private IP. For example, /projects/myProject/ global/networks/default. Corresponds to the JSON property privateNetwork

Returns:

  • (String)


4520
4521
4522
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4520

def private_network
  @private_network
end

#target_instanceString

Target instance name. Corresponds to the JSON property targetInstance

Returns:

  • (String)


4525
4526
4527
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4525

def target_instance
  @target_instance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4532
4533
4534
4535
4536
4537
4538
4539
4540
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4532

def update!(**args)
  @allocated_ip_range = args[:allocated_ip_range] if args.key?(:allocated_ip_range)
  @datasource = args[:datasource] if args.key?(:datasource)
  @point_in_time = args[:point_in_time] if args.key?(:point_in_time)
  @preferred_secondary_zone = args[:preferred_secondary_zone] if args.key?(:preferred_secondary_zone)
  @preferred_zone = args[:preferred_zone] if args.key?(:preferred_zone)
  @private_network = args[:private_network] if args.key?(:private_network)
  @target_instance = args[:target_instance] if args.key?(:target_instance)
end