Class: Google::Apis::SqladminV1beta4::PoolNodeConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Details of a single read pool node of a read pool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PoolNodeConfig

Returns a new instance of PoolNodeConfig.



4554
4555
4556
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4554

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dns_nameString

Output only. The DNS name of the read pool node. Corresponds to the JSON property dnsName

Returns:

  • (String)


4512
4513
4514
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4512

def dns_name
  @dns_name
end

#dns_namesArray<Google::Apis::SqladminV1beta4::DnsNameMapping>

Output only. The list of DNS names used by this read pool node. Corresponds to the JSON property dnsNames



4517
4518
4519
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4517

def dns_names
  @dns_names
end

#gce_zoneString

Output only. The zone of the read pool node. Corresponds to the JSON property gceZone

Returns:

  • (String)


4522
4523
4524
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4522

def gce_zone
  @gce_zone
end

#ip_addressesArray<Google::Apis::SqladminV1beta4::IpMapping>

Output only. Mappings containing IP addresses that can be used to connect to the read pool node. Corresponds to the JSON property ipAddresses



4528
4529
4530
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4528

def ip_addresses
  @ip_addresses
end

#nameString

Output only. The name of the read pool node, to be used for retrieving metrics and logs. Corresponds to the JSON property name

Returns:

  • (String)


4534
4535
4536
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4534

def name
  @name
end

#psc_auto_connectionsArray<Google::Apis::SqladminV1beta4::PscAutoConnectionConfig>

Output only. The list of settings for requested automatically-setup Private Service Connect (PSC) consumer endpoints that can be used to connect to this read pool node. Corresponds to the JSON property pscAutoConnections



4541
4542
4543
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4541

def psc_auto_connections
  @psc_auto_connections
end

Output only. The Private Service Connect (PSC) service attachment of the read pool node. Corresponds to the JSON property pscServiceAttachmentLink

Returns:

  • (String)


4547
4548
4549
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4547

def psc_service_attachment_link
  @psc_service_attachment_link
end

#stateString

Output only. The current state of the read pool node. Corresponds to the JSON property state

Returns:

  • (String)


4552
4553
4554
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4552

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4559
4560
4561
4562
4563
4564
4565
4566
4567
4568
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4559

def update!(**args)
  @dns_name = args[:dns_name] if args.key?(:dns_name)
  @dns_names = args[:dns_names] if args.key?(:dns_names)
  @gce_zone = args[:gce_zone] if args.key?(:gce_zone)
  @ip_addresses = args[:ip_addresses] if args.key?(:ip_addresses)
  @name = args[:name] if args.key?(:name)
  @psc_auto_connections = args[:psc_auto_connections] if args.key?(:psc_auto_connections)
  @psc_service_attachment_link = args[:psc_service_attachment_link] if args.key?(:psc_service_attachment_link)
  @state = args[:state] if args.key?(:state)
end