Class: Google::Apis::SqladminV1beta4::PreCheckResponse
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::PreCheckResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
Structured PreCheckResponse containing message, type, and required actions.
Instance Attribute Summary collapse
-
#actions_required ⇒ Array<String>
The actions that the user needs to take.
-
#message ⇒ String
The message to be displayed to the user.
-
#message_type ⇒ String
The type of message whether it is an info, warning, or error.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PreCheckResponse
constructor
A new instance of PreCheckResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PreCheckResponse
Returns a new instance of PreCheckResponse.
4621 4622 4623 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4621 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actions_required ⇒ Array<String>
The actions that the user needs to take. Use repeated for multiple actions.
Corresponds to the JSON property actionsRequired
4609 4610 4611 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4609 def actions_required @actions_required end |
#message ⇒ String
The message to be displayed to the user.
Corresponds to the JSON property message
4614 4615 4616 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4614 def @message end |
#message_type ⇒ String
The type of message whether it is an info, warning, or error.
Corresponds to the JSON property messageType
4619 4620 4621 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4619 def @message_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4626 4627 4628 4629 4630 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4626 def update!(**args) @actions_required = args[:actions_required] if args.key?(:actions_required) @message = args[:message] if args.key?(:message) @message_type = args[:message_type] if args.key?(:message_type) end |