Class: Google::Apis::SqladminV1beta4::PscAutoConnectionConfig
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::PscAutoConnectionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
Settings for an automatically-setup Private Service Connect consumer endpoint that is used to connect to a Cloud SQL instance.
Instance Attribute Summary collapse
-
#consumer_network ⇒ String
Optional.
-
#consumer_network_status ⇒ String
The connection policy status of the consumer network.
-
#consumer_project ⇒ String
Optional.
-
#instance_auto_dns_status ⇒ String
Output only.
-
#ip_address ⇒ String
The IP address of the consumer endpoint.
-
#service_connection_policy ⇒ String
Output only.
-
#service_connection_policy_creation_result ⇒ String
Output only.
-
#status ⇒ String
The connection status of the consumer endpoint.
-
#write_endpoint_auto_dns_status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PscAutoConnectionConfig
constructor
A new instance of PscAutoConnectionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PscAutoConnectionConfig
Returns a new instance of PscAutoConnectionConfig.
4841 4842 4843 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4841 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consumer_network ⇒ String
Optional. The consumer network of this consumer endpoint. This must be a
resource path that includes both the host project and the network name. For
example, projects/project1/global/networks/network1. The consumer host
project of this network might be different from the consumer service project.
Corresponds to the JSON property consumerNetwork
4794 4795 4796 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4794 def consumer_network @consumer_network end |
#consumer_network_status ⇒ String
The connection policy status of the consumer network.
Corresponds to the JSON property consumerNetworkStatus
4799 4800 4801 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4799 def consumer_network_status @consumer_network_status end |
#consumer_project ⇒ String
Optional. This is the project ID of consumer service project of this consumer
endpoint. Optional. This is only applicable if consumer_network is a shared
vpc network.
Corresponds to the JSON property consumerProject
4806 4807 4808 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4806 def consumer_project @consumer_project end |
#instance_auto_dns_status ⇒ String
Output only. The status of automated DNS provisioning.
Corresponds to the JSON property instanceAutoDnsStatus
4811 4812 4813 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4811 def instance_auto_dns_status @instance_auto_dns_status end |
#ip_address ⇒ String
The IP address of the consumer endpoint.
Corresponds to the JSON property ipAddress
4816 4817 4818 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4816 def ip_address @ip_address end |
#service_connection_policy ⇒ String
Output only. The service connection policy created automatically for the
consumer network when psc_auto_connection_policy_enabled is true. It is in
the format of: projects/project/regions/region/serviceConnectionPolicies/
policy_id`Thepolicy_idis in format of$NETWORK-$RANDOM.
Corresponds to the JSON propertyserviceConnectionPolicy`
4824 4825 4826 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4824 def service_connection_policy @service_connection_policy end |
#service_connection_policy_creation_result ⇒ String
Output only. The status of service connection policy creation.
Corresponds to the JSON property serviceConnectionPolicyCreationResult
4829 4830 4831 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4829 def service_connection_policy_creation_result @service_connection_policy_creation_result end |
#status ⇒ String
The connection status of the consumer endpoint.
Corresponds to the JSON property status
4834 4835 4836 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4834 def status @status end |
#write_endpoint_auto_dns_status ⇒ String
Output only. The status of automated DNS provisioning for the write endpoint.
Corresponds to the JSON property writeEndpointAutoDnsStatus
4839 4840 4841 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4839 def write_endpoint_auto_dns_status @write_endpoint_auto_dns_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4846 4847 4848 4849 4850 4851 4852 4853 4854 4855 4856 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4846 def update!(**args) @consumer_network = args[:consumer_network] if args.key?(:consumer_network) @consumer_network_status = args[:consumer_network_status] if args.key?(:consumer_network_status) @consumer_project = args[:consumer_project] if args.key?(:consumer_project) @instance_auto_dns_status = args[:instance_auto_dns_status] if args.key?(:instance_auto_dns_status) @ip_address = args[:ip_address] if args.key?(:ip_address) @service_connection_policy = args[:service_connection_policy] if args.key?(:service_connection_policy) @service_connection_policy_creation_result = args[:service_connection_policy_creation_result] if args.key?(:service_connection_policy_creation_result) @status = args[:status] if args.key?(:status) @write_endpoint_auto_dns_status = args[:write_endpoint_auto_dns_status] if args.key?(:write_endpoint_auto_dns_status) end |