Class: Google::Apis::SqladminV1beta4::PscConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

PSC settings for a Cloud SQL instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PscConfig

Returns a new instance of PscConfig.



4815
4816
4817
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4815

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_consumer_projectsArray<String>

Optional. The list of consumer projects that are allow-listed for PSC connections to this instance. This instance can be connected to with PSC from any network in these projects. Each consumer project in this list may be represented by a project number (numeric) or by a project id (alphanumeric). Corresponds to the JSON property allowedConsumerProjects

Returns:

  • (Array<String>)


4766
4767
4768
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4766

def allowed_consumer_projects
  @allowed_consumer_projects
end

#network_attachment_uriString

Optional. The network attachment of the consumer network that the Private Service Connect enabled Cloud SQL instance is authorized to connect via PSC interface. format: projects/PROJECT/regions/REGION/networkAttachments/ID Corresponds to the JSON property networkAttachmentUri

Returns:

  • (String)


4773
4774
4775
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4773

def network_attachment_uri
  @network_attachment_uri
end

#psc_auto_connection_policy_enabledBoolean Also known as: psc_auto_connection_policy_enabled?

Optional. Whether to set up the PSC service connection policy automatically. Corresponds to the JSON property pscAutoConnectionPolicyEnabled

Returns:

  • (Boolean)


4778
4779
4780
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4778

def psc_auto_connection_policy_enabled
  @psc_auto_connection_policy_enabled
end

#psc_auto_connectionsArray<Google::Apis::SqladminV1beta4::PscAutoConnectionConfig>

Optional. The list of settings for requested Private Service Connect consumer endpoints that can be used to connect to this Cloud SQL instance. Corresponds to the JSON property pscAutoConnections



4785
4786
4787
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4785

def psc_auto_connections
  @psc_auto_connections
end

#psc_auto_dns_enabledBoolean Also known as: psc_auto_dns_enabled?

Optional. Indicates whether Private Service Connect DNS automation is enabled for this instance. When enabled, Cloud SQL provisions a universal DNS record across all networks configured with Private Service Connect auto-connections. This will default to true for new instances when Private Service Connect is enabled. Corresponds to the JSON property pscAutoDnsEnabled

Returns:

  • (Boolean)


4794
4795
4796
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4794

def psc_auto_dns_enabled
  @psc_auto_dns_enabled
end

#psc_enabledBoolean Also known as: psc_enabled?

Whether PSC connectivity is enabled for this instance. Corresponds to the JSON property pscEnabled

Returns:

  • (Boolean)


4800
4801
4802
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4800

def psc_enabled
  @psc_enabled
end

#psc_write_endpoint_dns_enabledBoolean Also known as: psc_write_endpoint_dns_enabled?

Optional. Indicates whether Private Service Connect write endpoint DNS automation is enabled for this instance. When enabled, Cloud SQL provisions a universal global DNS record across all networks configured with Private Service Connect auto-connections that points to the cluster primary instance. This feature is only supported for Enterprise Plus edition. This will default to true for new enterprise plus instances when psc_auto_dns_enabled is enabled. Corresponds to the JSON property pscWriteEndpointDnsEnabled

Returns:

  • (Boolean)


4812
4813
4814
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4812

def psc_write_endpoint_dns_enabled
  @psc_write_endpoint_dns_enabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4820
4821
4822
4823
4824
4825
4826
4827
4828
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4820

def update!(**args)
  @allowed_consumer_projects = args[:allowed_consumer_projects] if args.key?(:allowed_consumer_projects)
  @network_attachment_uri = args[:network_attachment_uri] if args.key?(:network_attachment_uri)
  @psc_auto_connection_policy_enabled = args[:psc_auto_connection_policy_enabled] if args.key?(:psc_auto_connection_policy_enabled)
  @psc_auto_connections = args[:psc_auto_connections] if args.key?(:psc_auto_connections)
  @psc_auto_dns_enabled = args[:psc_auto_dns_enabled] if args.key?(:psc_auto_dns_enabled)
  @psc_enabled = args[:psc_enabled] if args.key?(:psc_enabled)
  @psc_write_endpoint_dns_enabled = args[:psc_write_endpoint_dns_enabled] if args.key?(:psc_write_endpoint_dns_enabled)
end