Class: Google::Apis::SqladminV1beta4::PscConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

PSC settings for a Cloud SQL instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PscConfig

Returns a new instance of PscConfig.



4791
4792
4793
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4791

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_consumer_projectsArray<String>

Optional. The list of consumer projects that are allow-listed for PSC connections to this instance. This instance can be connected to with PSC from any network in these projects. Each consumer project in this list may be represented by a project number (numeric) or by a project id (alphanumeric). Corresponds to the JSON property allowedConsumerProjects

Returns:

  • (Array<String>)


4750
4751
4752
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4750

def allowed_consumer_projects
  @allowed_consumer_projects
end

#network_attachment_uriString

Optional. The network attachment of the consumer network that the Private Service Connect enabled Cloud SQL instance is authorized to connect via PSC interface. format: projects/PROJECT/regions/REGION/networkAttachments/ID Corresponds to the JSON property networkAttachmentUri

Returns:

  • (String)


4757
4758
4759
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4757

def network_attachment_uri
  @network_attachment_uri
end

#psc_auto_connectionsArray<Google::Apis::SqladminV1beta4::PscAutoConnectionConfig>

Optional. The list of settings for requested Private Service Connect consumer endpoints that can be used to connect to this Cloud SQL instance. Corresponds to the JSON property pscAutoConnections



4763
4764
4765
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4763

def psc_auto_connections
  @psc_auto_connections
end

#psc_auto_dns_enabledBoolean Also known as: psc_auto_dns_enabled?

Optional. Indicates whether PSC DNS automation is enabled for this instance. When enabled, Cloud SQL provisions a universal DNS record across all networks configured with Private Service Connect (PSC) auto-connections. This will default to true for new instances when Private Service Connect is enabled. Corresponds to the JSON property pscAutoDnsEnabled

Returns:

  • (Boolean)


4771
4772
4773
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4771

def psc_auto_dns_enabled
  @psc_auto_dns_enabled
end

#psc_enabledBoolean Also known as: psc_enabled?

Whether PSC connectivity is enabled for this instance. Corresponds to the JSON property pscEnabled

Returns:

  • (Boolean)


4777
4778
4779
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4777

def psc_enabled
  @psc_enabled
end

#psc_write_endpoint_dns_enabledBoolean Also known as: psc_write_endpoint_dns_enabled?

Optional. Indicates whether PSC write endpoint DNS automation is enabled for this instance. When enabled, Cloud SQL provisions a universal global DNS record across all networks configured with Private Service Connect (PSC) auto- connections that always points to the cluster primary instance. This feature is only supported for Enterprise Plus edition. This will default to true for new enterprise plus instances when psc_auto_dns_enabled is enabled. Corresponds to the JSON property pscWriteEndpointDnsEnabled

Returns:

  • (Boolean)


4788
4789
4790
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4788

def psc_write_endpoint_dns_enabled
  @psc_write_endpoint_dns_enabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4796
4797
4798
4799
4800
4801
4802
4803
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4796

def update!(**args)
  @allowed_consumer_projects = args[:allowed_consumer_projects] if args.key?(:allowed_consumer_projects)
  @network_attachment_uri = args[:network_attachment_uri] if args.key?(:network_attachment_uri)
  @psc_auto_connections = args[:psc_auto_connections] if args.key?(:psc_auto_connections)
  @psc_auto_dns_enabled = args[:psc_auto_dns_enabled] if args.key?(:psc_auto_dns_enabled)
  @psc_enabled = args[:psc_enabled] if args.key?(:psc_enabled)
  @psc_write_endpoint_dns_enabled = args[:psc_write_endpoint_dns_enabled] if args.key?(:psc_write_endpoint_dns_enabled)
end