Class: Google::Apis::SqladminV1beta4::PscConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

PSC settings for a Cloud SQL instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PscConfig

Returns a new instance of PscConfig.



4713
4714
4715
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4713

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_consumer_projectsArray<String>

Optional. The list of consumer projects that are allow-listed for PSC connections to this instance. This instance can be connected to with PSC from any network in these projects. Each consumer project in this list may be represented by a project number (numeric) or by a project id (alphanumeric). Corresponds to the JSON property allowedConsumerProjects

Returns:

  • (Array<String>)


4692
4693
4694
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4692

def allowed_consumer_projects
  @allowed_consumer_projects
end

#network_attachment_uriString

Optional. The network attachment of the consumer network that the Private Service Connect enabled Cloud SQL instance is authorized to connect via PSC interface. format: projects/PROJECT/regions/REGION/networkAttachments/ID Corresponds to the JSON property networkAttachmentUri

Returns:

  • (String)


4699
4700
4701
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4699

def network_attachment_uri
  @network_attachment_uri
end

#psc_auto_connectionsArray<Google::Apis::SqladminV1beta4::PscAutoConnectionConfig>

Optional. The list of settings for requested Private Service Connect consumer endpoints that can be used to connect to this Cloud SQL instance. Corresponds to the JSON property pscAutoConnections



4705
4706
4707
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4705

def psc_auto_connections
  @psc_auto_connections
end

#psc_enabledBoolean Also known as: psc_enabled?

Whether PSC connectivity is enabled for this instance. Corresponds to the JSON property pscEnabled

Returns:

  • (Boolean)


4710
4711
4712
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4710

def psc_enabled
  @psc_enabled
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4718
4719
4720
4721
4722
4723
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4718

def update!(**args)
  @allowed_consumer_projects = args[:allowed_consumer_projects] if args.key?(:allowed_consumer_projects)
  @network_attachment_uri = args[:network_attachment_uri] if args.key?(:network_attachment_uri)
  @psc_auto_connections = args[:psc_auto_connections] if args.key?(:psc_auto_connections)
  @psc_enabled = args[:psc_enabled] if args.key?(:psc_enabled)
end