Class: Google::Apis::SqladminV1beta4::QueryResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

QueryResult contains the result of executing a single SQL statement.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueryResult

Returns a new instance of QueryResult.



4971
4972
4973
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4971

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnsArray<Google::Apis::SqladminV1beta4::Column>

List of columns included in the result. This also includes the data type of the column. Corresponds to the JSON property columns



4942
4943
4944
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4942

def columns
  @columns
end

#messageString

Message related to the SQL execution result. Corresponds to the JSON property message

Returns:

  • (String)


4947
4948
4949
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4947

def message
  @message
end

#partial_resultBoolean Also known as: partial_result?

Set to true if the SQL execution's result is truncated due to size limits or an error retrieving results. Corresponds to the JSON property partialResult

Returns:

  • (Boolean)


4953
4954
4955
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4953

def partial_result
  @partial_result
end

#rowsArray<Google::Apis::SqladminV1beta4::Row>

Rows returned by the SQL statement. Corresponds to the JSON property rows



4959
4960
4961
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4959

def rows
  @rows
end

#statusGoogle::Apis::SqladminV1beta4::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



4969
4970
4971
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4969

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4976
4977
4978
4979
4980
4981
4982
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4976

def update!(**args)
  @columns = args[:columns] if args.key?(:columns)
  @message = args[:message] if args.key?(:message)
  @partial_result = args[:partial_result] if args.key?(:partial_result)
  @rows = args[:rows] if args.key?(:rows)
  @status = args[:status] if args.key?(:status)
end