Class: Google::Apis::SqladminV1beta4::QueryResult
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::QueryResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
QueryResult contains the result of executing a single SQL statement.
Instance Attribute Summary collapse
-
#columns ⇒ Array<Google::Apis::SqladminV1beta4::Column>
List of columns included in the result.
-
#message ⇒ String
Message related to the SQL execution result.
-
#partial_result ⇒ Boolean
(also: #partial_result?)
Set to true if the SQL execution's result is truncated due to size limits or an error retrieving results.
-
#rows ⇒ Array<Google::Apis::SqladminV1beta4::Row>
Rows returned by the SQL statement.
-
#status ⇒ Google::Apis::SqladminV1beta4::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueryResult
constructor
A new instance of QueryResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueryResult
Returns a new instance of QueryResult.
4843 4844 4845 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4843 def initialize(**args) update!(**args) end |
Instance Attribute Details
#columns ⇒ Array<Google::Apis::SqladminV1beta4::Column>
List of columns included in the result. This also includes the data type of
the column.
Corresponds to the JSON property columns
4814 4815 4816 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4814 def columns @columns end |
#message ⇒ String
Message related to the SQL execution result.
Corresponds to the JSON property message
4819 4820 4821 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4819 def @message end |
#partial_result ⇒ Boolean Also known as: partial_result?
Set to true if the SQL execution's result is truncated due to size limits or
an error retrieving results.
Corresponds to the JSON property partialResult
4825 4826 4827 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4825 def partial_result @partial_result end |
#rows ⇒ Array<Google::Apis::SqladminV1beta4::Row>
Rows returned by the SQL statement.
Corresponds to the JSON property rows
4831 4832 4833 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4831 def rows @rows end |
#status ⇒ Google::Apis::SqladminV1beta4::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
4841 4842 4843 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4841 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4848 4849 4850 4851 4852 4853 4854 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4848 def update!(**args) @columns = args[:columns] if args.key?(:columns) @message = args[:message] if args.key?(:message) @partial_result = args[:partial_result] if args.key?(:partial_result) @rows = args[:rows] if args.key?(:rows) @status = args[:status] if args.key?(:status) end |