Class: Google::Apis::SqladminV1beta4::QueryResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

QueryResult contains the result of executing a single SQL statement.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueryResult

Returns a new instance of QueryResult.



4763
4764
4765
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4763

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnsArray<Google::Apis::SqladminV1beta4::Column>

List of columns included in the result. This also includes the data type of the column. Corresponds to the JSON property columns



4734
4735
4736
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4734

def columns
  @columns
end

#messageString

Message related to the SQL execution result. Corresponds to the JSON property message

Returns:

  • (String)


4739
4740
4741
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4739

def message
  @message
end

#partial_resultBoolean Also known as: partial_result?

Set to true if the SQL execution's result is truncated due to size limits or an error retrieving results. Corresponds to the JSON property partialResult

Returns:

  • (Boolean)


4745
4746
4747
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4745

def partial_result
  @partial_result
end

#rowsArray<Google::Apis::SqladminV1beta4::Row>

Rows returned by the SQL statement. Corresponds to the JSON property rows



4751
4752
4753
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4751

def rows
  @rows
end

#statusGoogle::Apis::SqladminV1beta4::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



4761
4762
4763
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4761

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4768
4769
4770
4771
4772
4773
4774
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4768

def update!(**args)
  @columns = args[:columns] if args.key?(:columns)
  @message = args[:message] if args.key?(:message)
  @partial_result = args[:partial_result] if args.key?(:partial_result)
  @rows = args[:rows] if args.key?(:rows)
  @status = args[:status] if args.key?(:status)
end