Class: Google::Apis::SqladminV1beta4::ReplicaConfiguration

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Read-replica configuration for connecting to the primary instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReplicaConfiguration

Returns a new instance of ReplicaConfiguration.



4905
4906
4907
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4905

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cascadable_replicaBoolean Also known as: cascadable_replica?

Optional. Specifies if a SQL Server replica is a cascadable replica. A cascadable replica is a SQL Server cross region replica that supports replica( s) under it. Corresponds to the JSON property cascadableReplica

Returns:

  • (Boolean)


4882
4883
4884
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4882

def cascadable_replica
  @cascadable_replica
end

#failover_targetBoolean Also known as: failover_target?

Specifies if the replica is the failover target. If the field is set to true the replica will be designated as a failover replica. In case the primary instance fails, the replica instance will be promoted as the new primary instance. Only one replica can be specified as failover target, and the replica has to be in different zone with the primary instance. Corresponds to the JSON property failoverTarget

Returns:

  • (Boolean)


4892
4893
4894
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4892

def failover_target
  @failover_target
end

#kindString

This is always sql#replicaConfiguration. Corresponds to the JSON property kind

Returns:

  • (String)


4898
4899
4900
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4898

def kind
  @kind
end

#mysql_replica_configurationGoogle::Apis::SqladminV1beta4::MySqlReplicaConfiguration

Read-replica configuration specific to MySQL databases. Corresponds to the JSON property mysqlReplicaConfiguration



4903
4904
4905
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4903

def mysql_replica_configuration
  @mysql_replica_configuration
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4910
4911
4912
4913
4914
4915
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4910

def update!(**args)
  @cascadable_replica = args[:cascadable_replica] if args.key?(:cascadable_replica)
  @failover_target = args[:failover_target] if args.key?(:failover_target)
  @kind = args[:kind] if args.key?(:kind)
  @mysql_replica_configuration = args[:mysql_replica_configuration] if args.key?(:mysql_replica_configuration)
end