Class: Google::Apis::SqladminV1beta4::ReplicaConfiguration
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::ReplicaConfiguration
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
Read-replica configuration for connecting to the primary instance.
Instance Attribute Summary collapse
-
#cascadable_replica ⇒ Boolean
(also: #cascadable_replica?)
Optional.
-
#failover_target ⇒ Boolean
(also: #failover_target?)
Specifies if the replica is the failover target.
-
#kind ⇒ String
This is always
sql#replicaConfiguration. -
#mysql_replica_configuration ⇒ Google::Apis::SqladminV1beta4::MySqlReplicaConfiguration
Read-replica configuration specific to MySQL databases.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReplicaConfiguration
constructor
A new instance of ReplicaConfiguration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReplicaConfiguration
Returns a new instance of ReplicaConfiguration.
4867 4868 4869 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4867 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cascadable_replica ⇒ Boolean Also known as: cascadable_replica?
Optional. Specifies if a SQL Server replica is a cascadable replica. A
cascadable replica is a SQL Server cross region replica that supports replica(
s) under it.
Corresponds to the JSON property cascadableReplica
4844 4845 4846 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4844 def cascadable_replica @cascadable_replica end |
#failover_target ⇒ Boolean Also known as: failover_target?
Specifies if the replica is the failover target. If the field is set to true
the replica will be designated as a failover replica. In case the primary
instance fails, the replica instance will be promoted as the new primary
instance. Only one replica can be specified as failover target, and the
replica has to be in different zone with the primary instance.
Corresponds to the JSON property failoverTarget
4854 4855 4856 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4854 def failover_target @failover_target end |
#kind ⇒ String
This is always sql#replicaConfiguration.
Corresponds to the JSON property kind
4860 4861 4862 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4860 def kind @kind end |
#mysql_replica_configuration ⇒ Google::Apis::SqladminV1beta4::MySqlReplicaConfiguration
Read-replica configuration specific to MySQL databases.
Corresponds to the JSON property mysqlReplicaConfiguration
4865 4866 4867 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4865 def mysql_replica_configuration @mysql_replica_configuration end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4872 4873 4874 4875 4876 4877 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4872 def update!(**args) @cascadable_replica = args[:cascadable_replica] if args.key?(:cascadable_replica) @failover_target = args[:failover_target] if args.key?(:failover_target) @kind = args[:kind] if args.key?(:kind) @mysql_replica_configuration = args[:mysql_replica_configuration] if args.key?(:mysql_replica_configuration) end |