Class: Google::Apis::SqladminV1beta4::RestoreBackupContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Database instance restore from backup context. Backup context contains source instance id and project id.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RestoreBackupContext

Returns a new instance of RestoreBackupContext.



5083
5084
5085
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5083

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_run_idFixnum

The ID of the backup run to restore from. Corresponds to the JSON property backupRunId

Returns:

  • (Fixnum)


5066
5067
5068
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5066

def backup_run_id
  @backup_run_id
end

#instance_idString

The ID of the instance that the backup was taken from. Corresponds to the JSON property instanceId

Returns:

  • (String)


5071
5072
5073
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5071

def instance_id
  @instance_id
end

#kindString

This is always sql#restoreBackupContext. Corresponds to the JSON property kind

Returns:

  • (String)


5076
5077
5078
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5076

def kind
  @kind
end

#projectString

The full project ID of the source instance. Corresponds to the JSON property project

Returns:

  • (String)


5081
5082
5083
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5081

def project
  @project
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5088
5089
5090
5091
5092
5093
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5088

def update!(**args)
  @backup_run_id = args[:backup_run_id] if args.key?(:backup_run_id)
  @instance_id = args[:instance_id] if args.key?(:instance_id)
  @kind = args[:kind] if args.key?(:kind)
  @project = args[:project] if args.key?(:project)
end