Class: Google::Apis::SqladminV1beta4::RestoreBackupContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Database instance restore from backup context. Backup context contains source instance id and project id.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RestoreBackupContext

Returns a new instance of RestoreBackupContext.



5058
5059
5060
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5058

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_run_idFixnum

The ID of the backup run to restore from. Corresponds to the JSON property backupRunId

Returns:

  • (Fixnum)


5041
5042
5043
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5041

def backup_run_id
  @backup_run_id
end

#instance_idString

The ID of the instance that the backup was taken from. Corresponds to the JSON property instanceId

Returns:

  • (String)


5046
5047
5048
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5046

def instance_id
  @instance_id
end

#kindString

This is always sql#restoreBackupContext. Corresponds to the JSON property kind

Returns:

  • (String)


5051
5052
5053
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5051

def kind
  @kind
end

#projectString

The full project ID of the source instance. Corresponds to the JSON property project

Returns:

  • (String)


5056
5057
5058
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5056

def project
  @project
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5063
5064
5065
5066
5067
5068
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5063

def update!(**args)
  @backup_run_id = args[:backup_run_id] if args.key?(:backup_run_id)
  @instance_id = args[:instance_id] if args.key?(:instance_id)
  @kind = args[:kind] if args.key?(:kind)
  @project = args[:project] if args.key?(:project)
end