Class: Google::Apis::SqladminV1beta4::RotateEntraIdCertificateContext
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::RotateEntraIdCertificateContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
Instance rotate Entra ID certificate context.
Instance Attribute Summary collapse
-
#kind ⇒ String
Optional.
-
#next_version ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RotateEntraIdCertificateContext
constructor
A new instance of RotateEntraIdCertificateContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RotateEntraIdCertificateContext
Returns a new instance of RotateEntraIdCertificateContext.
5231 5232 5233 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5231 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Optional. This is always sql#rotateEntraIdCertificateContext.
Corresponds to the JSON property kind
5222 5223 5224 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5222 def kind @kind end |
#next_version ⇒ String
Optional. The fingerprint of the next version to be rotated to. If left
unspecified, will be rotated to the most recently added Entra ID certificate
version.
Corresponds to the JSON property nextVersion
5229 5230 5231 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5229 def next_version @next_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5236 5237 5238 5239 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5236 def update!(**args) @kind = args[:kind] if args.key?(:kind) @next_version = args[:next_version] if args.key?(:next_version) end |