Class: Google::Apis::SqladminV1beta4::RotateEntraIdCertificateContext
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::RotateEntraIdCertificateContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
Instance rotate Entra ID certificate context.
Instance Attribute Summary collapse
-
#kind ⇒ String
Optional.
-
#next_version ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RotateEntraIdCertificateContext
constructor
A new instance of RotateEntraIdCertificateContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RotateEntraIdCertificateContext
Returns a new instance of RotateEntraIdCertificateContext.
5215 5216 5217 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5215 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Optional. This is always sql#rotateEntraIdCertificateContext.
Corresponds to the JSON property kind
5206 5207 5208 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5206 def kind @kind end |
#next_version ⇒ String
Optional. The fingerprint of the next version to be rotated to. If left
unspecified, will be rotated to the most recently added Entra ID certificate
version.
Corresponds to the JSON property nextVersion
5213 5214 5215 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5213 def next_version @next_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5220 5221 5222 5223 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5220 def update!(**args) @kind = args[:kind] if args.key?(:kind) @next_version = args[:next_version] if args.key?(:next_version) end |