Class: Google::Apis::SqladminV1beta4::RotateEntraIdCertificateContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Instance rotate Entra ID certificate context.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RotateEntraIdCertificateContext

Returns a new instance of RotateEntraIdCertificateContext.



5088
5089
5090
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5088

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

Optional. This is always sql#rotateEntraIdCertificateContext. Corresponds to the JSON property kind

Returns:

  • (String)


5079
5080
5081
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5079

def kind
  @kind
end

#next_versionString

Optional. The fingerprint of the next version to be rotated to. If left unspecified, will be rotated to the most recently added Entra ID certificate version. Corresponds to the JSON property nextVersion

Returns:

  • (String)


5086
5087
5088
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5086

def next_version
  @next_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5093
5094
5095
5096
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5093

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @next_version = args[:next_version] if args.key?(:next_version)
end