Class: Google::Apis::SqladminV1beta4::RotateEntraIdCertificateContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Instance rotate Entra ID certificate context.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RotateEntraIdCertificateContext

Returns a new instance of RotateEntraIdCertificateContext.



5087
5088
5089
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5087

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

Optional. This is always sql#rotateEntraIdCertificateContext. Corresponds to the JSON property kind

Returns:

  • (String)


5078
5079
5080
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5078

def kind
  @kind
end

#next_versionString

Optional. The fingerprint of the next version to be rotated to. If left unspecified, will be rotated to the most recently added Entra ID certificate version. Corresponds to the JSON property nextVersion

Returns:

  • (String)


5085
5086
5087
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5085

def next_version
  @next_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5092
5093
5094
5095
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5092

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @next_version = args[:next_version] if args.key?(:next_version)
end