Class: Google::Apis::SqladminV1beta4::RotateEntraIdCertificateContext
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::RotateEntraIdCertificateContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
Instance rotate Entra ID certificate context.
Instance Attribute Summary collapse
-
#kind ⇒ String
Optional.
-
#next_version ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RotateEntraIdCertificateContext
constructor
A new instance of RotateEntraIdCertificateContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RotateEntraIdCertificateContext
Returns a new instance of RotateEntraIdCertificateContext.
5007 5008 5009 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5007 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Optional. This is always sql#rotateEntraIdCertificateContext.
Corresponds to the JSON property kind
4998 4999 5000 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 4998 def kind @kind end |
#next_version ⇒ String
Optional. The fingerprint of the next version to be rotated to. If left
unspecified, will be rotated to the most recently added Entra ID certificate
version.
Corresponds to the JSON property nextVersion
5005 5006 5007 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5005 def next_version @next_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5012 5013 5014 5015 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5012 def update!(**args) @kind = args[:kind] if args.key?(:kind) @next_version = args[:next_version] if args.key?(:next_version) end |