Class: Google::Apis::SqladminV1beta4::RotateServerCaContext
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::RotateServerCaContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
Instance rotate server CA context.
Instance Attribute Summary collapse
-
#kind ⇒ String
This is always
sql#rotateServerCaContext. -
#next_version ⇒ String
The fingerprint of the next version to be rotated to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RotateServerCaContext
constructor
A new instance of RotateServerCaContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RotateServerCaContext
Returns a new instance of RotateServerCaContext.
5257 5258 5259 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5257 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
This is always sql#rotateServerCaContext.
Corresponds to the JSON property kind
5249 5250 5251 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5249 def kind @kind end |
#next_version ⇒ String
The fingerprint of the next version to be rotated to. If left unspecified,
will be rotated to the most recently added server CA version.
Corresponds to the JSON property nextVersion
5255 5256 5257 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5255 def next_version @next_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5262 5263 5264 5265 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5262 def update!(**args) @kind = args[:kind] if args.key?(:kind) @next_version = args[:next_version] if args.key?(:next_version) end |