Class: Google::Apis::SqladminV1beta4::RotateServerCaContext
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::RotateServerCaContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
Instance rotate server CA context.
Instance Attribute Summary collapse
-
#kind ⇒ String
This is always
sql#rotateServerCaContext. -
#next_version ⇒ String
The fingerprint of the next version to be rotated to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RotateServerCaContext
constructor
A new instance of RotateServerCaContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RotateServerCaContext
Returns a new instance of RotateServerCaContext.
5241 5242 5243 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5241 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
This is always sql#rotateServerCaContext.
Corresponds to the JSON property kind
5233 5234 5235 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5233 def kind @kind end |
#next_version ⇒ String
The fingerprint of the next version to be rotated to. If left unspecified,
will be rotated to the most recently added server CA version.
Corresponds to the JSON property nextVersion
5239 5240 5241 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5239 def next_version @next_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5246 5247 5248 5249 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5246 def update!(**args) @kind = args[:kind] if args.key?(:kind) @next_version = args[:next_version] if args.key?(:next_version) end |