Class: Google::Apis::SqladminV1beta4::RotateServerCaContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Instance rotate server CA context.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RotateServerCaContext

Returns a new instance of RotateServerCaContext.



5113
5114
5115
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5113

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

This is always sql#rotateServerCaContext. Corresponds to the JSON property kind

Returns:

  • (String)


5105
5106
5107
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5105

def kind
  @kind
end

#next_versionString

The fingerprint of the next version to be rotated to. If left unspecified, will be rotated to the most recently added server CA version. Corresponds to the JSON property nextVersion

Returns:

  • (String)


5111
5112
5113
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5111

def next_version
  @next_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5118
5119
5120
5121
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5118

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @next_version = args[:next_version] if args.key?(:next_version)
end