Class: Google::Apis::SqladminV1beta4::RotateServerCertificateContext
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::RotateServerCertificateContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
Instance rotate server certificate context.
Instance Attribute Summary collapse
-
#kind ⇒ String
Optional.
-
#next_version ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RotateServerCertificateContext
constructor
A new instance of RotateServerCertificateContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RotateServerCertificateContext
Returns a new instance of RotateServerCertificateContext.
5165 5166 5167 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5165 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Optional. This is always sql#rotateServerCertificateContext.
Corresponds to the JSON property kind
5156 5157 5158 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5156 def kind @kind end |
#next_version ⇒ String
Optional. The fingerprint of the next version to be rotated to. If left
unspecified, will be rotated to the most recently added server certificate
version.
Corresponds to the JSON property nextVersion
5163 5164 5165 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5163 def next_version @next_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5170 5171 5172 5173 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5170 def update!(**args) @kind = args[:kind] if args.key?(:kind) @next_version = args[:next_version] if args.key?(:next_version) end |