Class: Google::Apis::SqladminV1beta4::RotateServerCertificateContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Instance rotate server certificate context.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RotateServerCertificateContext

Returns a new instance of RotateServerCertificateContext.



5098
5099
5100
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5098

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

Optional. This is always sql#rotateServerCertificateContext. Corresponds to the JSON property kind

Returns:

  • (String)


5089
5090
5091
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5089

def kind
  @kind
end

#next_versionString

Optional. The fingerprint of the next version to be rotated to. If left unspecified, will be rotated to the most recently added server certificate version. Corresponds to the JSON property nextVersion

Returns:

  • (String)


5096
5097
5098
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5096

def next_version
  @next_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5103
5104
5105
5106
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5103

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @next_version = args[:next_version] if args.key?(:next_version)
end