Class: Google::Apis::SqladminV1beta4::RotateServerCertificateContext
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::RotateServerCertificateContext
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
Instance rotate server certificate context.
Instance Attribute Summary collapse
-
#kind ⇒ String
Optional.
-
#next_version ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RotateServerCertificateContext
constructor
A new instance of RotateServerCertificateContext.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RotateServerCertificateContext
Returns a new instance of RotateServerCertificateContext.
5060 5061 5062 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5060 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Optional. This is always sql#rotateServerCertificateContext.
Corresponds to the JSON property kind
5051 5052 5053 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5051 def kind @kind end |
#next_version ⇒ String
Optional. The fingerprint of the next version to be rotated to. If left
unspecified, will be rotated to the most recently added server certificate
version.
Corresponds to the JSON property nextVersion
5058 5059 5060 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5058 def next_version @next_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5065 5066 5067 5068 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5065 def update!(**args) @kind = args[:kind] if args.key?(:kind) @next_version = args[:next_version] if args.key?(:next_version) end |