Class: Google::Apis::SqladminV1beta4::Settings
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::Settings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
Database instance settings.
Instance Attribute Summary collapse
-
#accelerated_replica_mode ⇒ Boolean
(also: #accelerated_replica_mode?)
Optional.
-
#activation_policy ⇒ String
The activation policy specifies when the instance is activated; it is applicable only when the instance state is RUNNABLE.
-
#active_directory_config ⇒ Google::Apis::SqladminV1beta4::SqlActiveDirectoryConfig
Active Directory configuration, relevant only for Cloud SQL for SQL Server.
-
#advanced_machine_features ⇒ Google::Apis::SqladminV1beta4::AdvancedMachineFeatures
Specifies options for controlling advanced machine features.
-
#authorized_gae_applications ⇒ Array<String>
The App Engine app IDs that can access this instance.
-
#auto_upgrade_enabled ⇒ Boolean
(also: #auto_upgrade_enabled?)
Optional.
-
#availability_type ⇒ String
Availability type.
-
#backup_configuration ⇒ Google::Apis::SqladminV1beta4::BackupConfiguration
Database instance backup configuration.
-
#collation ⇒ String
The name of server Instance collation.
-
#connection_pool_config ⇒ Google::Apis::SqladminV1beta4::ConnectionPoolConfig
The managed connection pooling configuration.
-
#connector_enforcement ⇒ String
Specifies if connections must use Cloud SQL connectors.
-
#crash_safe_replication_enabled ⇒ Boolean
(also: #crash_safe_replication_enabled?)
Configuration specific to read replica instances.
-
#data_api_access ⇒ String
This parameter controls whether to allow using ExecuteSql API to connect to the instance.
-
#data_cache_config ⇒ Google::Apis::SqladminV1beta4::DataCacheConfig
Data cache configurations.
-
#data_disk_provisioned_iops ⇒ Fixnum
Optional.
-
#data_disk_provisioned_throughput ⇒ Fixnum
Optional.
-
#data_disk_size_gb ⇒ Fixnum
The size of data disk, in GB.
-
#data_disk_type ⇒ String
The type of data disk:
PD_SSD(default) orPD_HDD. -
#database_flags ⇒ Array<Google::Apis::SqladminV1beta4::DatabaseFlags>
The database flags passed to the instance at startup.
-
#database_replication_enabled ⇒ Boolean
(also: #database_replication_enabled?)
Configuration specific to read replica instances.
-
#deletion_protection_enabled ⇒ Boolean
(also: #deletion_protection_enabled?)
Configuration to protect against accidental instance deletion.
-
#deny_maintenance_periods ⇒ Array<Google::Apis::SqladminV1beta4::DenyMaintenancePeriod>
Deny maintenance periods Corresponds to the JSON property
denyMaintenancePeriods. -
#edition ⇒ String
Optional.
-
#enable_dataplex_integration ⇒ Boolean
(also: #enable_dataplex_integration?)
Optional.
-
#enable_google_ml_integration ⇒ Boolean
(also: #enable_google_ml_integration?)
Optional.
-
#entraid_config ⇒ Google::Apis::SqladminV1beta4::SqlServerEntraIdConfig
SQL Server Entra ID configuration.
-
#final_backup_config ⇒ Google::Apis::SqladminV1beta4::FinalBackupConfig
Config used to determine the final backup settings for the instance.
-
#insights_config ⇒ Google::Apis::SqladminV1beta4::InsightsConfig
Insights configuration.
-
#ip_configuration ⇒ Google::Apis::SqladminV1beta4::IpConfiguration
IP Management configuration.
-
#kind ⇒ String
This is always
sql#settings. -
#location_preference ⇒ Google::Apis::SqladminV1beta4::LocationPreference
Preferred location.
-
#maintenance_window ⇒ Google::Apis::SqladminV1beta4::MaintenanceWindow
Maintenance window.
-
#password_validation_policy ⇒ Google::Apis::SqladminV1beta4::PasswordValidationPolicy
Database instance local user password validation policy.
-
#performance_capture_config ⇒ Google::Apis::SqladminV1beta4::PerformanceCaptureConfig
Performance capture configuration.
-
#pricing_plan ⇒ String
The pricing plan for this instance.
-
#read_pool_auto_scale_config ⇒ Google::Apis::SqladminV1beta4::ReadPoolAutoScaleConfig
The read pool auto-scale configuration.
-
#replication_lag_max_seconds ⇒ Fixnum
Optional.
-
#replication_type ⇒ String
The type of replication this instance uses.
-
#retain_backups_on_delete ⇒ Boolean
(also: #retain_backups_on_delete?)
Optional.
-
#settings_version ⇒ Fixnum
The version of instance settings.
-
#sql_server_audit_config ⇒ Google::Apis::SqladminV1beta4::SqlServerAuditConfig
SQL Server specific audit configuration.
-
#storage_auto_resize ⇒ Boolean
(also: #storage_auto_resize?)
Configuration to increase storage size automatically.
-
#storage_auto_resize_limit ⇒ Fixnum
The maximum size to which storage capacity can be automatically increased.
-
#tier ⇒ String
The tier (or machine type) for this instance, for example
db-custom-1-3840. -
#time_zone ⇒ String
Server timezone, relevant only for Cloud SQL for SQL Server.
-
#user_labels ⇒ Hash<String,String>
User-provided labels, represented as a dictionary where each label is a single key value pair.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Settings
constructor
A new instance of Settings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Settings
Returns a new instance of Settings.
5485 5486 5487 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5485 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerated_replica_mode ⇒ Boolean Also known as: accelerated_replica_mode?
Optional. Configures whether the replica is in accelerated mode. This feature
is in private preview and requires allowlisting to take effect.
Corresponds to the JSON property acceleratedReplicaMode
5199 5200 5201 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5199 def accelerated_replica_mode @accelerated_replica_mode end |
#activation_policy ⇒ String
The activation policy specifies when the instance is activated; it is
applicable only when the instance state is RUNNABLE. Valid values: * ALWAYS:
The instance is on, and remains so even in the absence of connection requests.
NEVER: The instance is off; it is not activated, even if a connection request arrives. Corresponds to the JSON propertyactivationPolicy
5209 5210 5211 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5209 def activation_policy @activation_policy end |
#active_directory_config ⇒ Google::Apis::SqladminV1beta4::SqlActiveDirectoryConfig
Active Directory configuration, relevant only for Cloud SQL for SQL Server.
Corresponds to the JSON property activeDirectoryConfig
5214 5215 5216 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5214 def active_directory_config @active_directory_config end |
#advanced_machine_features ⇒ Google::Apis::SqladminV1beta4::AdvancedMachineFeatures
Specifies options for controlling advanced machine features.
Corresponds to the JSON property advancedMachineFeatures
5219 5220 5221 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5219 def advanced_machine_features @advanced_machine_features end |
#authorized_gae_applications ⇒ Array<String>
The App Engine app IDs that can access this instance. (Deprecated) Applied to
First Generation instances only.
Corresponds to the JSON property authorizedGaeApplications
5225 5226 5227 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5225 def @authorized_gae_applications end |
#auto_upgrade_enabled ⇒ Boolean Also known as: auto_upgrade_enabled?
Optional. Cloud SQL for MySQL auto-upgrade configuration. When this parameter
is set to true, auto-upgrade is enabled for MySQL 8.0 minor versions. The
MySQL version must be 8.0.35 or higher.
Corresponds to the JSON property autoUpgradeEnabled
5232 5233 5234 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5232 def auto_upgrade_enabled @auto_upgrade_enabled end |
#availability_type ⇒ String
Availability type. Potential values: * ZONAL: The instance serves data from
only one zone. Outages in that zone affect data accessibility. * REGIONAL:
The instance can serve data from more than one zone in a region (it is highly
available)./ For more information, see Overview of the High Availability
Configuration.
Corresponds to the JSON property availabilityType
5242 5243 5244 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5242 def availability_type @availability_type end |
#backup_configuration ⇒ Google::Apis::SqladminV1beta4::BackupConfiguration
Database instance backup configuration.
Corresponds to the JSON property backupConfiguration
5247 5248 5249 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5247 def backup_configuration @backup_configuration end |
#collation ⇒ String
The name of server Instance collation.
Corresponds to the JSON property collation
5252 5253 5254 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5252 def collation @collation end |
#connection_pool_config ⇒ Google::Apis::SqladminV1beta4::ConnectionPoolConfig
The managed connection pooling configuration.
Corresponds to the JSON property connectionPoolConfig
5257 5258 5259 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5257 def connection_pool_config @connection_pool_config end |
#connector_enforcement ⇒ String
Specifies if connections must use Cloud SQL connectors. Option values include
the following: NOT_REQUIRED (Cloud SQL instances can be connected without
Cloud SQL Connectors) and REQUIRED (Only allow connections that use Cloud
SQL Connectors) Note that using REQUIRED disables all existing authorized
networks. If this field is not specified when creating a new instance,
NOT_REQUIRED is used. If this field is not specified when patching or updating
an existing instance, it is left unchanged in the instance.
Corresponds to the JSON property connectorEnforcement
5268 5269 5270 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5268 def connector_enforcement @connector_enforcement end |
#crash_safe_replication_enabled ⇒ Boolean Also known as: crash_safe_replication_enabled?
Configuration specific to read replica instances. Indicates whether database
flags for crash-safe replication are enabled. This property was only
applicable to First Generation instances.
Corresponds to the JSON property crashSafeReplicationEnabled
5275 5276 5277 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5275 def crash_safe_replication_enabled @crash_safe_replication_enabled end |
#data_api_access ⇒ String
This parameter controls whether to allow using ExecuteSql API to connect to
the instance. Not allowed by default.
Corresponds to the JSON property dataApiAccess
5282 5283 5284 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5282 def data_api_access @data_api_access end |
#data_cache_config ⇒ Google::Apis::SqladminV1beta4::DataCacheConfig
Data cache configurations.
Corresponds to the JSON property dataCacheConfig
5287 5288 5289 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5287 def data_cache_config @data_cache_config end |
#data_disk_provisioned_iops ⇒ Fixnum
Optional. Provisioned number of I/O operations per second for the data disk.
This field is only used for hyperdisk-balanced disk types.
Corresponds to the JSON property dataDiskProvisionedIops
5293 5294 5295 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5293 def data_disk_provisioned_iops @data_disk_provisioned_iops end |
#data_disk_provisioned_throughput ⇒ Fixnum
Optional. Provisioned throughput measured in MiB per second for the data disk.
This field is only used for hyperdisk-balanced disk types.
Corresponds to the JSON property dataDiskProvisionedThroughput
5299 5300 5301 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5299 def data_disk_provisioned_throughput @data_disk_provisioned_throughput end |
#data_disk_size_gb ⇒ Fixnum
The size of data disk, in GB. The data disk size minimum is 10GB.
Corresponds to the JSON property dataDiskSizeGb
5304 5305 5306 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5304 def data_disk_size_gb @data_disk_size_gb end |
#data_disk_type ⇒ String
The type of data disk: PD_SSD (default) or PD_HDD. Not used for First
Generation instances.
Corresponds to the JSON property dataDiskType
5310 5311 5312 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5310 def data_disk_type @data_disk_type end |
#database_flags ⇒ Array<Google::Apis::SqladminV1beta4::DatabaseFlags>
The database flags passed to the instance at startup.
Corresponds to the JSON property databaseFlags
5315 5316 5317 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5315 def database_flags @database_flags end |
#database_replication_enabled ⇒ Boolean Also known as: database_replication_enabled?
Configuration specific to read replica instances. Indicates whether
replication is enabled or not. WARNING: Changing this restarts the instance.
Corresponds to the JSON property databaseReplicationEnabled
5321 5322 5323 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5321 def database_replication_enabled @database_replication_enabled end |
#deletion_protection_enabled ⇒ Boolean Also known as: deletion_protection_enabled?
Configuration to protect against accidental instance deletion.
Corresponds to the JSON property deletionProtectionEnabled
5327 5328 5329 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5327 def deletion_protection_enabled @deletion_protection_enabled end |
#deny_maintenance_periods ⇒ Array<Google::Apis::SqladminV1beta4::DenyMaintenancePeriod>
Deny maintenance periods
Corresponds to the JSON property denyMaintenancePeriods
5333 5334 5335 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5333 def deny_maintenance_periods @deny_maintenance_periods end |
#edition ⇒ String
Optional. The edition of the instance.
Corresponds to the JSON property edition
5338 5339 5340 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5338 def edition @edition end |
#enable_dataplex_integration ⇒ Boolean Also known as: enable_dataplex_integration?
Optional. By default, Cloud SQL instances have schema extraction disabled for
Dataplex. When this parameter is set to true, schema extraction for Dataplex
on Cloud SQL instances is activated.
Corresponds to the JSON property enableDataplexIntegration
5345 5346 5347 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5345 def enable_dataplex_integration @enable_dataplex_integration end |
#enable_google_ml_integration ⇒ Boolean Also known as: enable_google_ml_integration?
Optional. When this parameter is set to true, Cloud SQL instances can connect
to Vertex AI to pass requests for real-time predictions and insights to the AI.
The default value is false. This applies only to Cloud SQL for MySQL and
Cloud SQL for PostgreSQL instances.
Corresponds to the JSON property enableGoogleMlIntegration
5354 5355 5356 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5354 def enable_google_ml_integration @enable_google_ml_integration end |
#entraid_config ⇒ Google::Apis::SqladminV1beta4::SqlServerEntraIdConfig
SQL Server Entra ID configuration.
Corresponds to the JSON property entraidConfig
5360 5361 5362 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5360 def entraid_config @entraid_config end |
#final_backup_config ⇒ Google::Apis::SqladminV1beta4::FinalBackupConfig
Config used to determine the final backup settings for the instance.
Corresponds to the JSON property finalBackupConfig
5365 5366 5367 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5365 def final_backup_config @final_backup_config end |
#insights_config ⇒ Google::Apis::SqladminV1beta4::InsightsConfig
Insights configuration. This specifies when Cloud SQL Insights feature is
enabled and optional configuration.
Corresponds to the JSON property insightsConfig
5371 5372 5373 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5371 def insights_config @insights_config end |
#ip_configuration ⇒ Google::Apis::SqladminV1beta4::IpConfiguration
IP Management configuration.
Corresponds to the JSON property ipConfiguration
5376 5377 5378 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5376 def ip_configuration @ip_configuration end |
#kind ⇒ String
This is always sql#settings.
Corresponds to the JSON property kind
5381 5382 5383 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5381 def kind @kind end |
#location_preference ⇒ Google::Apis::SqladminV1beta4::LocationPreference
Preferred location. This specifies where a Cloud SQL instance is located. Note
that if the preferred location is not available, the instance will be located
as close as possible within the region. Only one location may be specified.
Corresponds to the JSON property locationPreference
5388 5389 5390 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5388 def location_preference @location_preference end |
#maintenance_window ⇒ Google::Apis::SqladminV1beta4::MaintenanceWindow
Maintenance window. This specifies when a Cloud SQL instance is restarted for
system maintenance purposes.
Corresponds to the JSON property maintenanceWindow
5394 5395 5396 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5394 def maintenance_window @maintenance_window end |
#password_validation_policy ⇒ Google::Apis::SqladminV1beta4::PasswordValidationPolicy
Database instance local user password validation policy. This message defines
the password policy for local database users. When enabled, it enforces
constraints on password complexity, length, and reuse. Keep this policy
enabled to help prevent unauthorized access.
Corresponds to the JSON property passwordValidationPolicy
5402 5403 5404 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5402 def password_validation_policy @password_validation_policy end |
#performance_capture_config ⇒ Google::Apis::SqladminV1beta4::PerformanceCaptureConfig
Performance capture configuration.
Corresponds to the JSON property performanceCaptureConfig
5407 5408 5409 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5407 def performance_capture_config @performance_capture_config end |
#pricing_plan ⇒ String
The pricing plan for this instance. This can be either PER_USE or PACKAGE.
Only PER_USE is supported for Second Generation instances.
Corresponds to the JSON property pricingPlan
5413 5414 5415 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5413 def pricing_plan @pricing_plan end |
#read_pool_auto_scale_config ⇒ Google::Apis::SqladminV1beta4::ReadPoolAutoScaleConfig
The read pool auto-scale configuration.
Corresponds to the JSON property readPoolAutoScaleConfig
5418 5419 5420 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5418 def read_pool_auto_scale_config @read_pool_auto_scale_config end |
#replication_lag_max_seconds ⇒ Fixnum
Optional. Configuration value for recreation of replica after certain
replication lag.
Corresponds to the JSON property replicationLagMaxSeconds
5424 5425 5426 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5424 def replication_lag_max_seconds @replication_lag_max_seconds end |
#replication_type ⇒ String
The type of replication this instance uses. This can be either ASYNCHRONOUS
or SYNCHRONOUS. (Deprecated) This property was only applicable to First
Generation instances.
Corresponds to the JSON property replicationType
5431 5432 5433 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5431 def replication_type @replication_type end |
#retain_backups_on_delete ⇒ Boolean Also known as: retain_backups_on_delete?
Optional. When this parameter is set to true, Cloud SQL retains backups of the
instance even after the instance is deleted. The ON_DEMAND backup will be
retained until customer deletes the backup or the project. The AUTOMATED
backup will be retained based on the backups retention setting.
Corresponds to the JSON property retainBackupsOnDelete
5439 5440 5441 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5439 def retain_backups_on_delete @retain_backups_on_delete end |
#settings_version ⇒ Fixnum
The version of instance settings. This is a required field for update method
to make sure concurrent updates are handled properly. During update, use the
most recent settingsVersion value for this instance and do not try to update
this value.
Corresponds to the JSON property settingsVersion
5448 5449 5450 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5448 def settings_version @settings_version end |
#sql_server_audit_config ⇒ Google::Apis::SqladminV1beta4::SqlServerAuditConfig
SQL Server specific audit configuration.
Corresponds to the JSON property sqlServerAuditConfig
5453 5454 5455 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5453 def sql_server_audit_config @sql_server_audit_config end |
#storage_auto_resize ⇒ Boolean Also known as: storage_auto_resize?
Configuration to increase storage size automatically. The default value is
true.
Corresponds to the JSON property storageAutoResize
5459 5460 5461 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5459 def storage_auto_resize @storage_auto_resize end |
#storage_auto_resize_limit ⇒ Fixnum
The maximum size to which storage capacity can be automatically increased. The
default value is 0, which specifies that there is no limit.
Corresponds to the JSON property storageAutoResizeLimit
5466 5467 5468 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5466 def storage_auto_resize_limit @storage_auto_resize_limit end |
#tier ⇒ String
The tier (or machine type) for this instance, for example db-custom-1-3840.
WARNING: Changing this restarts the instance.
Corresponds to the JSON property tier
5472 5473 5474 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5472 def tier @tier end |
#time_zone ⇒ String
Server timezone, relevant only for Cloud SQL for SQL Server.
Corresponds to the JSON property timeZone
5477 5478 5479 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5477 def time_zone @time_zone end |
#user_labels ⇒ Hash<String,String>
User-provided labels, represented as a dictionary where each label is a single
key value pair.
Corresponds to the JSON property userLabels
5483 5484 5485 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5483 def user_labels @user_labels end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5490 5491 5492 5493 5494 5495 5496 5497 5498 5499 5500 5501 5502 5503 5504 5505 5506 5507 5508 5509 5510 5511 5512 5513 5514 5515 5516 5517 5518 5519 5520 5521 5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 5532 5533 5534 5535 5536 5537 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5490 def update!(**args) @accelerated_replica_mode = args[:accelerated_replica_mode] if args.key?(:accelerated_replica_mode) @activation_policy = args[:activation_policy] if args.key?(:activation_policy) @active_directory_config = args[:active_directory_config] if args.key?(:active_directory_config) @advanced_machine_features = args[:advanced_machine_features] if args.key?(:advanced_machine_features) @authorized_gae_applications = args[:authorized_gae_applications] if args.key?(:authorized_gae_applications) @auto_upgrade_enabled = args[:auto_upgrade_enabled] if args.key?(:auto_upgrade_enabled) @availability_type = args[:availability_type] if args.key?(:availability_type) @backup_configuration = args[:backup_configuration] if args.key?(:backup_configuration) @collation = args[:collation] if args.key?(:collation) @connection_pool_config = args[:connection_pool_config] if args.key?(:connection_pool_config) @connector_enforcement = args[:connector_enforcement] if args.key?(:connector_enforcement) @crash_safe_replication_enabled = args[:crash_safe_replication_enabled] if args.key?(:crash_safe_replication_enabled) @data_api_access = args[:data_api_access] if args.key?(:data_api_access) @data_cache_config = args[:data_cache_config] if args.key?(:data_cache_config) @data_disk_provisioned_iops = args[:data_disk_provisioned_iops] if args.key?(:data_disk_provisioned_iops) @data_disk_provisioned_throughput = args[:data_disk_provisioned_throughput] if args.key?(:data_disk_provisioned_throughput) @data_disk_size_gb = args[:data_disk_size_gb] if args.key?(:data_disk_size_gb) @data_disk_type = args[:data_disk_type] if args.key?(:data_disk_type) @database_flags = args[:database_flags] if args.key?(:database_flags) @database_replication_enabled = args[:database_replication_enabled] if args.key?(:database_replication_enabled) @deletion_protection_enabled = args[:deletion_protection_enabled] if args.key?(:deletion_protection_enabled) @deny_maintenance_periods = args[:deny_maintenance_periods] if args.key?(:deny_maintenance_periods) @edition = args[:edition] if args.key?(:edition) @enable_dataplex_integration = args[:enable_dataplex_integration] if args.key?(:enable_dataplex_integration) @enable_google_ml_integration = args[:enable_google_ml_integration] if args.key?(:enable_google_ml_integration) @entraid_config = args[:entraid_config] if args.key?(:entraid_config) @final_backup_config = args[:final_backup_config] if args.key?(:final_backup_config) @insights_config = args[:insights_config] if args.key?(:insights_config) @ip_configuration = args[:ip_configuration] if args.key?(:ip_configuration) @kind = args[:kind] if args.key?(:kind) @location_preference = args[:location_preference] if args.key?(:location_preference) @maintenance_window = args[:maintenance_window] if args.key?(:maintenance_window) @password_validation_policy = args[:password_validation_policy] if args.key?(:password_validation_policy) @performance_capture_config = args[:performance_capture_config] if args.key?(:performance_capture_config) @pricing_plan = args[:pricing_plan] if args.key?(:pricing_plan) @read_pool_auto_scale_config = args[:read_pool_auto_scale_config] if args.key?(:read_pool_auto_scale_config) @replication_lag_max_seconds = args[:replication_lag_max_seconds] if args.key?(:replication_lag_max_seconds) @replication_type = args[:replication_type] if args.key?(:replication_type) @retain_backups_on_delete = args[:retain_backups_on_delete] if args.key?(:retain_backups_on_delete) @settings_version = args[:settings_version] if args.key?(:settings_version) @sql_server_audit_config = args[:sql_server_audit_config] if args.key?(:sql_server_audit_config) @storage_auto_resize = args[:storage_auto_resize] if args.key?(:storage_auto_resize) @storage_auto_resize_limit = args[:storage_auto_resize_limit] if args.key?(:storage_auto_resize_limit) @tier = args[:tier] if args.key?(:tier) @time_zone = args[:time_zone] if args.key?(:time_zone) @user_labels = args[:user_labels] if args.key?(:user_labels) end |