Class: Google::Apis::SqladminV1beta4::Settings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Database instance settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Settings

Returns a new instance of Settings.



5397
5398
5399
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5397

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activation_policyString

The activation policy specifies when the instance is activated; it is applicable only when the instance state is RUNNABLE. Valid values: * ALWAYS: The instance is on, and remains so even in the absence of connection requests.

  • NEVER: The instance is off; it is not activated, even if a connection request arrives. Corresponds to the JSON property activationPolicy

Returns:

  • (String)


5121
5122
5123
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5121

def activation_policy
  @activation_policy
end

#active_directory_configGoogle::Apis::SqladminV1beta4::SqlActiveDirectoryConfig

Active Directory configuration, relevant only for Cloud SQL for SQL Server. Corresponds to the JSON property activeDirectoryConfig



5126
5127
5128
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5126

def active_directory_config
  @active_directory_config
end

#advanced_machine_featuresGoogle::Apis::SqladminV1beta4::AdvancedMachineFeatures

Specifies options for controlling advanced machine features. Corresponds to the JSON property advancedMachineFeatures



5131
5132
5133
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5131

def advanced_machine_features
  @advanced_machine_features
end

#authorized_gae_applicationsArray<String>

The App Engine app IDs that can access this instance. (Deprecated) Applied to First Generation instances only. Corresponds to the JSON property authorizedGaeApplications

Returns:

  • (Array<String>)


5137
5138
5139
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5137

def authorized_gae_applications
  @authorized_gae_applications
end

#auto_upgrade_enabledBoolean Also known as: auto_upgrade_enabled?

Optional. Cloud SQL for MySQL auto-upgrade configuration. When this parameter is set to true, auto-upgrade is enabled for MySQL 8.0 minor versions. The MySQL version must be 8.0.35 or higher. Corresponds to the JSON property autoUpgradeEnabled

Returns:

  • (Boolean)


5144
5145
5146
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5144

def auto_upgrade_enabled
  @auto_upgrade_enabled
end

#availability_typeString

Availability type. Potential values: * ZONAL: The instance serves data from only one zone. Outages in that zone affect data accessibility. * REGIONAL: The instance can serve data from more than one zone in a region (it is highly available)./ For more information, see Overview of the High Availability Configuration. Corresponds to the JSON property availabilityType

Returns:

  • (String)


5154
5155
5156
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5154

def availability_type
  @availability_type
end

#backup_configurationGoogle::Apis::SqladminV1beta4::BackupConfiguration

Database instance backup configuration. Corresponds to the JSON property backupConfiguration



5159
5160
5161
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5159

def backup_configuration
  @backup_configuration
end

#collationString

The name of server Instance collation. Corresponds to the JSON property collation

Returns:

  • (String)


5164
5165
5166
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5164

def collation
  @collation
end

#connection_pool_configGoogle::Apis::SqladminV1beta4::ConnectionPoolConfig

The managed connection pooling configuration. Corresponds to the JSON property connectionPoolConfig



5169
5170
5171
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5169

def connection_pool_config
  @connection_pool_config
end

#connector_enforcementString

Specifies if connections must use Cloud SQL connectors. Option values include the following: NOT_REQUIRED (Cloud SQL instances can be connected without Cloud SQL Connectors) and REQUIRED (Only allow connections that use Cloud SQL Connectors) Note that using REQUIRED disables all existing authorized networks. If this field is not specified when creating a new instance, NOT_REQUIRED is used. If this field is not specified when patching or updating an existing instance, it is left unchanged in the instance. Corresponds to the JSON property connectorEnforcement

Returns:

  • (String)


5180
5181
5182
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5180

def connector_enforcement
  @connector_enforcement
end

#crash_safe_replication_enabledBoolean Also known as: crash_safe_replication_enabled?

Configuration specific to read replica instances. Indicates whether database flags for crash-safe replication are enabled. This property was only applicable to First Generation instances. Corresponds to the JSON property crashSafeReplicationEnabled

Returns:

  • (Boolean)


5187
5188
5189
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5187

def crash_safe_replication_enabled
  @crash_safe_replication_enabled
end

#data_api_accessString

This parameter controls whether to allow using ExecuteSql API to connect to the instance. Not allowed by default. Corresponds to the JSON property dataApiAccess

Returns:

  • (String)


5194
5195
5196
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5194

def data_api_access
  @data_api_access
end

#data_cache_configGoogle::Apis::SqladminV1beta4::DataCacheConfig

Data cache configurations. Corresponds to the JSON property dataCacheConfig



5199
5200
5201
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5199

def data_cache_config
  @data_cache_config
end

#data_disk_provisioned_iopsFixnum

Optional. Provisioned number of I/O operations per second for the data disk. This field is only used for hyperdisk-balanced disk types. Corresponds to the JSON property dataDiskProvisionedIops

Returns:

  • (Fixnum)


5205
5206
5207
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5205

def data_disk_provisioned_iops
  @data_disk_provisioned_iops
end

#data_disk_provisioned_throughputFixnum

Optional. Provisioned throughput measured in MiB per second for the data disk. This field is only used for hyperdisk-balanced disk types. Corresponds to the JSON property dataDiskProvisionedThroughput

Returns:

  • (Fixnum)


5211
5212
5213
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5211

def data_disk_provisioned_throughput
  @data_disk_provisioned_throughput
end

#data_disk_size_gbFixnum

The size of data disk, in GB. The data disk size minimum is 10GB. Corresponds to the JSON property dataDiskSizeGb

Returns:

  • (Fixnum)


5216
5217
5218
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5216

def data_disk_size_gb
  @data_disk_size_gb
end

#data_disk_typeString

The type of data disk: PD_SSD (default) or PD_HDD. Not used for First Generation instances. Corresponds to the JSON property dataDiskType

Returns:

  • (String)


5222
5223
5224
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5222

def data_disk_type
  @data_disk_type
end

#database_flagsArray<Google::Apis::SqladminV1beta4::DatabaseFlags>

The database flags passed to the instance at startup. Corresponds to the JSON property databaseFlags



5227
5228
5229
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5227

def database_flags
  @database_flags
end

#database_replication_enabledBoolean Also known as: database_replication_enabled?

Configuration specific to read replica instances. Indicates whether replication is enabled or not. WARNING: Changing this restarts the instance. Corresponds to the JSON property databaseReplicationEnabled

Returns:

  • (Boolean)


5233
5234
5235
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5233

def database_replication_enabled
  @database_replication_enabled
end

#deletion_protection_enabledBoolean Also known as: deletion_protection_enabled?

Configuration to protect against accidental instance deletion. Corresponds to the JSON property deletionProtectionEnabled

Returns:

  • (Boolean)


5239
5240
5241
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5239

def deletion_protection_enabled
  @deletion_protection_enabled
end

#deny_maintenance_periodsArray<Google::Apis::SqladminV1beta4::DenyMaintenancePeriod>

Deny maintenance periods Corresponds to the JSON property denyMaintenancePeriods



5245
5246
5247
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5245

def deny_maintenance_periods
  @deny_maintenance_periods
end

#editionString

Optional. The edition of the instance. Corresponds to the JSON property edition

Returns:

  • (String)


5250
5251
5252
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5250

def edition
  @edition
end

#enable_dataplex_integrationBoolean Also known as: enable_dataplex_integration?

Optional. By default, Cloud SQL instances have schema extraction disabled for Dataplex. When this parameter is set to true, schema extraction for Dataplex on Cloud SQL instances is activated. Corresponds to the JSON property enableDataplexIntegration

Returns:

  • (Boolean)


5257
5258
5259
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5257

def enable_dataplex_integration
  @enable_dataplex_integration
end

#enable_google_ml_integrationBoolean Also known as: enable_google_ml_integration?

Optional. When this parameter is set to true, Cloud SQL instances can connect to Vertex AI to pass requests for real-time predictions and insights to the AI. The default value is false. This applies only to Cloud SQL for MySQL and Cloud SQL for PostgreSQL instances. Corresponds to the JSON property enableGoogleMlIntegration

Returns:

  • (Boolean)


5266
5267
5268
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5266

def enable_google_ml_integration
  @enable_google_ml_integration
end

#entraid_configGoogle::Apis::SqladminV1beta4::SqlServerEntraIdConfig

SQL Server Entra ID configuration. Corresponds to the JSON property entraidConfig



5272
5273
5274
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5272

def entraid_config
  @entraid_config
end

#final_backup_configGoogle::Apis::SqladminV1beta4::FinalBackupConfig

Config used to determine the final backup settings for the instance. Corresponds to the JSON property finalBackupConfig



5277
5278
5279
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5277

def final_backup_config
  @final_backup_config
end

#insights_configGoogle::Apis::SqladminV1beta4::InsightsConfig

Insights configuration. This specifies when Cloud SQL Insights feature is enabled and optional configuration. Corresponds to the JSON property insightsConfig



5283
5284
5285
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5283

def insights_config
  @insights_config
end

#ip_configurationGoogle::Apis::SqladminV1beta4::IpConfiguration

IP Management configuration. Corresponds to the JSON property ipConfiguration



5288
5289
5290
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5288

def ip_configuration
  @ip_configuration
end

#kindString

This is always sql#settings. Corresponds to the JSON property kind

Returns:

  • (String)


5293
5294
5295
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5293

def kind
  @kind
end

#location_preferenceGoogle::Apis::SqladminV1beta4::LocationPreference

Preferred location. This specifies where a Cloud SQL instance is located. Note that if the preferred location is not available, the instance will be located as close as possible within the region. Only one location may be specified. Corresponds to the JSON property locationPreference



5300
5301
5302
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5300

def location_preference
  @location_preference
end

#maintenance_windowGoogle::Apis::SqladminV1beta4::MaintenanceWindow

Maintenance window. This specifies when a Cloud SQL instance is restarted for system maintenance purposes. Corresponds to the JSON property maintenanceWindow



5306
5307
5308
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5306

def maintenance_window
  @maintenance_window
end

#password_validation_policyGoogle::Apis::SqladminV1beta4::PasswordValidationPolicy

Database instance local user password validation policy. This message defines the password policy for local database users. When enabled, it enforces constraints on password complexity, length, and reuse. Keep this policy enabled to help prevent unauthorized access. Corresponds to the JSON property passwordValidationPolicy



5314
5315
5316
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5314

def password_validation_policy
  @password_validation_policy
end

#performance_capture_configGoogle::Apis::SqladminV1beta4::PerformanceCaptureConfig

Performance Capture configuration. Corresponds to the JSON property performanceCaptureConfig



5319
5320
5321
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5319

def performance_capture_config
  @performance_capture_config
end

#pricing_planString

The pricing plan for this instance. This can be either PER_USE or PACKAGE. Only PER_USE is supported for Second Generation instances. Corresponds to the JSON property pricingPlan

Returns:

  • (String)


5325
5326
5327
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5325

def pricing_plan
  @pricing_plan
end

#read_pool_auto_scale_configGoogle::Apis::SqladminV1beta4::ReadPoolAutoScaleConfig

The read pool auto-scale configuration. Corresponds to the JSON property readPoolAutoScaleConfig



5330
5331
5332
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5330

def read_pool_auto_scale_config
  @read_pool_auto_scale_config
end

#replication_lag_max_secondsFixnum

Optional. Configuration value for recreation of replica after certain replication lag. Corresponds to the JSON property replicationLagMaxSeconds

Returns:

  • (Fixnum)


5336
5337
5338
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5336

def replication_lag_max_seconds
  @replication_lag_max_seconds
end

#replication_typeString

The type of replication this instance uses. This can be either ASYNCHRONOUS or SYNCHRONOUS. (Deprecated) This property was only applicable to First Generation instances. Corresponds to the JSON property replicationType

Returns:

  • (String)


5343
5344
5345
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5343

def replication_type
  @replication_type
end

#retain_backups_on_deleteBoolean Also known as: retain_backups_on_delete?

Optional. When this parameter is set to true, Cloud SQL retains backups of the instance even after the instance is deleted. The ON_DEMAND backup will be retained until customer deletes the backup or the project. The AUTOMATED backup will be retained based on the backups retention setting. Corresponds to the JSON property retainBackupsOnDelete

Returns:

  • (Boolean)


5351
5352
5353
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5351

def retain_backups_on_delete
  @retain_backups_on_delete
end

#settings_versionFixnum

The version of instance settings. This is a required field for update method to make sure concurrent updates are handled properly. During update, use the most recent settingsVersion value for this instance and do not try to update this value. Corresponds to the JSON property settingsVersion

Returns:

  • (Fixnum)


5360
5361
5362
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5360

def settings_version
  @settings_version
end

#sql_server_audit_configGoogle::Apis::SqladminV1beta4::SqlServerAuditConfig

SQL Server specific audit configuration. Corresponds to the JSON property sqlServerAuditConfig



5365
5366
5367
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5365

def sql_server_audit_config
  @sql_server_audit_config
end

#storage_auto_resizeBoolean Also known as: storage_auto_resize?

Configuration to increase storage size automatically. The default value is true. Corresponds to the JSON property storageAutoResize

Returns:

  • (Boolean)


5371
5372
5373
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5371

def storage_auto_resize
  @storage_auto_resize
end

#storage_auto_resize_limitFixnum

The maximum size to which storage capacity can be automatically increased. The default value is 0, which specifies that there is no limit. Corresponds to the JSON property storageAutoResizeLimit

Returns:

  • (Fixnum)


5378
5379
5380
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5378

def storage_auto_resize_limit
  @storage_auto_resize_limit
end

#tierString

The tier (or machine type) for this instance, for example db-custom-1-3840. WARNING: Changing this restarts the instance. Corresponds to the JSON property tier

Returns:

  • (String)


5384
5385
5386
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5384

def tier
  @tier
end

#time_zoneString

Server timezone, relevant only for Cloud SQL for SQL Server. Corresponds to the JSON property timeZone

Returns:

  • (String)


5389
5390
5391
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5389

def time_zone
  @time_zone
end

#user_labelsHash<String,String>

User-provided labels, represented as a dictionary where each label is a single key value pair. Corresponds to the JSON property userLabels

Returns:

  • (Hash<String,String>)


5395
5396
5397
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5395

def user_labels
  @user_labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5402
5403
5404
5405
5406
5407
5408
5409
5410
5411
5412
5413
5414
5415
5416
5417
5418
5419
5420
5421
5422
5423
5424
5425
5426
5427
5428
5429
5430
5431
5432
5433
5434
5435
5436
5437
5438
5439
5440
5441
5442
5443
5444
5445
5446
5447
5448
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5402

def update!(**args)
  @activation_policy = args[:activation_policy] if args.key?(:activation_policy)
  @active_directory_config = args[:active_directory_config] if args.key?(:active_directory_config)
  @advanced_machine_features = args[:advanced_machine_features] if args.key?(:advanced_machine_features)
  @authorized_gae_applications = args[:authorized_gae_applications] if args.key?(:authorized_gae_applications)
  @auto_upgrade_enabled = args[:auto_upgrade_enabled] if args.key?(:auto_upgrade_enabled)
  @availability_type = args[:availability_type] if args.key?(:availability_type)
  @backup_configuration = args[:backup_configuration] if args.key?(:backup_configuration)
  @collation = args[:collation] if args.key?(:collation)
  @connection_pool_config = args[:connection_pool_config] if args.key?(:connection_pool_config)
  @connector_enforcement = args[:connector_enforcement] if args.key?(:connector_enforcement)
  @crash_safe_replication_enabled = args[:crash_safe_replication_enabled] if args.key?(:crash_safe_replication_enabled)
  @data_api_access = args[:data_api_access] if args.key?(:data_api_access)
  @data_cache_config = args[:data_cache_config] if args.key?(:data_cache_config)
  @data_disk_provisioned_iops = args[:data_disk_provisioned_iops] if args.key?(:data_disk_provisioned_iops)
  @data_disk_provisioned_throughput = args[:data_disk_provisioned_throughput] if args.key?(:data_disk_provisioned_throughput)
  @data_disk_size_gb = args[:data_disk_size_gb] if args.key?(:data_disk_size_gb)
  @data_disk_type = args[:data_disk_type] if args.key?(:data_disk_type)
  @database_flags = args[:database_flags] if args.key?(:database_flags)
  @database_replication_enabled = args[:database_replication_enabled] if args.key?(:database_replication_enabled)
  @deletion_protection_enabled = args[:deletion_protection_enabled] if args.key?(:deletion_protection_enabled)
  @deny_maintenance_periods = args[:deny_maintenance_periods] if args.key?(:deny_maintenance_periods)
  @edition = args[:edition] if args.key?(:edition)
  @enable_dataplex_integration = args[:enable_dataplex_integration] if args.key?(:enable_dataplex_integration)
  @enable_google_ml_integration = args[:enable_google_ml_integration] if args.key?(:enable_google_ml_integration)
  @entraid_config = args[:entraid_config] if args.key?(:entraid_config)
  @final_backup_config = args[:final_backup_config] if args.key?(:final_backup_config)
  @insights_config = args[:insights_config] if args.key?(:insights_config)
  @ip_configuration = args[:ip_configuration] if args.key?(:ip_configuration)
  @kind = args[:kind] if args.key?(:kind)
  @location_preference = args[:location_preference] if args.key?(:location_preference)
  @maintenance_window = args[:maintenance_window] if args.key?(:maintenance_window)
  @password_validation_policy = args[:password_validation_policy] if args.key?(:password_validation_policy)
  @performance_capture_config = args[:performance_capture_config] if args.key?(:performance_capture_config)
  @pricing_plan = args[:pricing_plan] if args.key?(:pricing_plan)
  @read_pool_auto_scale_config = args[:read_pool_auto_scale_config] if args.key?(:read_pool_auto_scale_config)
  @replication_lag_max_seconds = args[:replication_lag_max_seconds] if args.key?(:replication_lag_max_seconds)
  @replication_type = args[:replication_type] if args.key?(:replication_type)
  @retain_backups_on_delete = args[:retain_backups_on_delete] if args.key?(:retain_backups_on_delete)
  @settings_version = args[:settings_version] if args.key?(:settings_version)
  @sql_server_audit_config = args[:sql_server_audit_config] if args.key?(:sql_server_audit_config)
  @storage_auto_resize = args[:storage_auto_resize] if args.key?(:storage_auto_resize)
  @storage_auto_resize_limit = args[:storage_auto_resize_limit] if args.key?(:storage_auto_resize_limit)
  @tier = args[:tier] if args.key?(:tier)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
  @user_labels = args[:user_labels] if args.key?(:user_labels)
end