Class: Google::Apis::SqladminV1beta4::SqlInstancesExecuteSqlResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

Execute SQL statements response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SqlInstancesExecuteSqlResponse

Returns a new instance of SqlInstancesExecuteSqlResponse.



5674
5675
5676
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5674

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#messagesArray<Google::Apis::SqladminV1beta4::Message>

A list of notices and warnings generated during query execution. For PostgreSQL, this includes all notices and warnings. For MySQL, this includes warnings generated by the last executed statement. To retrieve all warnings for a multi-statement query, SHOW WARNINGS must be executed after each statement. Corresponds to the JSON property messages



5651
5652
5653
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5651

def messages
  @messages
end

#metadataGoogle::Apis::SqladminV1beta4::Metadata

The additional metadata information regarding the execution of the SQL statements. Corresponds to the JSON property metadata



5657
5658
5659
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5657

def 
  @metadata
end

#resultsArray<Google::Apis::SqladminV1beta4::QueryResult>

The list of results after executing all the SQL statements. Corresponds to the JSON property results



5662
5663
5664
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5662

def results
  @results
end

#statusGoogle::Apis::SqladminV1beta4::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



5672
5673
5674
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5672

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5679
5680
5681
5682
5683
5684
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5679

def update!(**args)
  @messages = args[:messages] if args.key?(:messages)
  @metadata = args[:metadata] if args.key?(:metadata)
  @results = args[:results] if args.key?(:results)
  @status = args[:status] if args.key?(:status)
end