Class: Google::Apis::SqladminV1beta4::SqlInstancesGetLatestRecoveryTimeResponse
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::SqlInstancesGetLatestRecoveryTimeResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
Instance get latest recovery time response.
Instance Attribute Summary collapse
-
#earliest_recovery_time ⇒ String
Timestamp, identifies the earliest recovery time of the source instance.
-
#kind ⇒ String
This is always
sql#getLatestRecoveryTime. -
#latest_recovery_time ⇒ String
Timestamp, identifies the latest recovery time of the source instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SqlInstancesGetLatestRecoveryTimeResponse
constructor
A new instance of SqlInstancesGetLatestRecoveryTimeResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SqlInstancesGetLatestRecoveryTimeResponse
Returns a new instance of SqlInstancesGetLatestRecoveryTimeResponse.
5649 5650 5651 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5649 def initialize(**args) update!(**args) end |
Instance Attribute Details
#earliest_recovery_time ⇒ String
Timestamp, identifies the earliest recovery time of the source instance.
Corresponds to the JSON property earliestRecoveryTime
5637 5638 5639 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5637 def earliest_recovery_time @earliest_recovery_time end |
#kind ⇒ String
This is always sql#getLatestRecoveryTime.
Corresponds to the JSON property kind
5642 5643 5644 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5642 def kind @kind end |
#latest_recovery_time ⇒ String
Timestamp, identifies the latest recovery time of the source instance.
Corresponds to the JSON property latestRecoveryTime
5647 5648 5649 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5647 def latest_recovery_time @latest_recovery_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5654 5655 5656 5657 5658 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5654 def update!(**args) @earliest_recovery_time = args[:earliest_recovery_time] if args.key?(:earliest_recovery_time) @kind = args[:kind] if args.key?(:kind) @latest_recovery_time = args[:latest_recovery_time] if args.key?(:latest_recovery_time) end |