Class: Google::Apis::SqladminV1beta4::SqlInstancesVerifyExternalSyncSettingsRequest
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::SqlInstancesVerifyExternalSyncSettingsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Instance Attribute Summary collapse
-
#migration_type ⇒ String
Optional.
-
#mysql_sync_config ⇒ Google::Apis::SqladminV1beta4::MySqlSyncConfig
MySQL-specific external server sync settings.
-
#selected_objects ⇒ Array<Google::Apis::SqladminV1beta4::ExternalSyncSelectedObject>
Optional.
-
#sync_mode ⇒ String
External sync mode Corresponds to the JSON property
syncMode. -
#sync_parallel_level ⇒ String
Optional.
-
#verify_connection_only ⇒ Boolean
(also: #verify_connection_only?)
Flag to enable verifying connection only Corresponds to the JSON property
verifyConnectionOnly. -
#verify_replication_only ⇒ Boolean
(also: #verify_replication_only?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SqlInstancesVerifyExternalSyncSettingsRequest
constructor
A new instance of SqlInstancesVerifyExternalSyncSettingsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SqlInstancesVerifyExternalSyncSettingsRequest
Returns a new instance of SqlInstancesVerifyExternalSyncSettingsRequest.
5901 5902 5903 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5901 def initialize(**args) update!(**args) end |
Instance Attribute Details
#migration_type ⇒ String
Optional. MigrationType configures the migration to use physical files or
logical dump files. If not set, then the logical dump file configuration is
used. Valid values are LOGICAL or PHYSICAL. Only applicable to MySQL.
Corresponds to the JSON property migrationType
5866 5867 5868 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5866 def migration_type @migration_type end |
#mysql_sync_config ⇒ Google::Apis::SqladminV1beta4::MySqlSyncConfig
MySQL-specific external server sync settings.
Corresponds to the JSON property mysqlSyncConfig
5871 5872 5873 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5871 def mysql_sync_config @mysql_sync_config end |
#selected_objects ⇒ Array<Google::Apis::SqladminV1beta4::ExternalSyncSelectedObject>
Optional. Migrate only the specified objects from the source instance. If this
field is empty, then migrate all objects.
Corresponds to the JSON property selectedObjects
5877 5878 5879 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5877 def selected_objects @selected_objects end |
#sync_mode ⇒ String
External sync mode
Corresponds to the JSON property syncMode
5882 5883 5884 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5882 def sync_mode @sync_mode end |
#sync_parallel_level ⇒ String
Optional. Parallel level for initial data sync. Only applicable for PostgreSQL.
Corresponds to the JSON property syncParallelLevel
5887 5888 5889 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5887 def sync_parallel_level @sync_parallel_level end |
#verify_connection_only ⇒ Boolean Also known as: verify_connection_only?
Flag to enable verifying connection only
Corresponds to the JSON property verifyConnectionOnly
5892 5893 5894 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5892 def verify_connection_only @verify_connection_only end |
#verify_replication_only ⇒ Boolean Also known as: verify_replication_only?
Optional. Flag to verify settings required by replication setup only
Corresponds to the JSON property verifyReplicationOnly
5898 5899 5900 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5898 def verify_replication_only @verify_replication_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5906 5907 5908 5909 5910 5911 5912 5913 5914 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5906 def update!(**args) @migration_type = args[:migration_type] if args.key?(:migration_type) @mysql_sync_config = args[:mysql_sync_config] if args.key?(:mysql_sync_config) @selected_objects = args[:selected_objects] if args.key?(:selected_objects) @sync_mode = args[:sync_mode] if args.key?(:sync_mode) @sync_parallel_level = args[:sync_parallel_level] if args.key?(:sync_parallel_level) @verify_connection_only = args[:verify_connection_only] if args.key?(:verify_connection_only) @verify_replication_only = args[:verify_replication_only] if args.key?(:verify_replication_only) end |