Class: Google::Apis::SqladminV1beta4::SqlInstancesVerifyExternalSyncSettingsRequest
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::SqlInstancesVerifyExternalSyncSettingsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Instance Attribute Summary collapse
-
#migration_type ⇒ String
Optional.
-
#mysql_sync_config ⇒ Google::Apis::SqladminV1beta4::MySqlSyncConfig
MySQL-specific external server sync settings.
-
#selected_objects ⇒ Array<Google::Apis::SqladminV1beta4::ExternalSyncSelectedObject>
Optional.
-
#sync_mode ⇒ String
External sync mode Corresponds to the JSON property
syncMode. -
#sync_parallel_level ⇒ String
Optional.
-
#verify_connection_only ⇒ Boolean
(also: #verify_connection_only?)
Flag to enable verifying connection only Corresponds to the JSON property
verifyConnectionOnly. -
#verify_replication_only ⇒ Boolean
(also: #verify_replication_only?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SqlInstancesVerifyExternalSyncSettingsRequest
constructor
A new instance of SqlInstancesVerifyExternalSyncSettingsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SqlInstancesVerifyExternalSyncSettingsRequest
Returns a new instance of SqlInstancesVerifyExternalSyncSettingsRequest.
5813 5814 5815 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5813 def initialize(**args) update!(**args) end |
Instance Attribute Details
#migration_type ⇒ String
Optional. MigrationType configures the migration to use physical files or
logical dump files. If not set, then the logical dump file configuration is
used. Valid values are LOGICAL or PHYSICAL. Only applicable to MySQL.
Corresponds to the JSON property migrationType
5778 5779 5780 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5778 def migration_type @migration_type end |
#mysql_sync_config ⇒ Google::Apis::SqladminV1beta4::MySqlSyncConfig
MySQL-specific external server sync settings.
Corresponds to the JSON property mysqlSyncConfig
5783 5784 5785 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5783 def mysql_sync_config @mysql_sync_config end |
#selected_objects ⇒ Array<Google::Apis::SqladminV1beta4::ExternalSyncSelectedObject>
Optional. Migrate only the specified objects from the source instance. If this
field is empty, then migrate all objects.
Corresponds to the JSON property selectedObjects
5789 5790 5791 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5789 def selected_objects @selected_objects end |
#sync_mode ⇒ String
External sync mode
Corresponds to the JSON property syncMode
5794 5795 5796 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5794 def sync_mode @sync_mode end |
#sync_parallel_level ⇒ String
Optional. Parallel level for initial data sync. Only applicable for PostgreSQL.
Corresponds to the JSON property syncParallelLevel
5799 5800 5801 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5799 def sync_parallel_level @sync_parallel_level end |
#verify_connection_only ⇒ Boolean Also known as: verify_connection_only?
Flag to enable verifying connection only
Corresponds to the JSON property verifyConnectionOnly
5804 5805 5806 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5804 def verify_connection_only @verify_connection_only end |
#verify_replication_only ⇒ Boolean Also known as: verify_replication_only?
Optional. Flag to verify settings required by replication setup only
Corresponds to the JSON property verifyReplicationOnly
5810 5811 5812 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5810 def verify_replication_only @verify_replication_only end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5818 5819 5820 5821 5822 5823 5824 5825 5826 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 5818 def update!(**args) @migration_type = args[:migration_type] if args.key?(:migration_type) @mysql_sync_config = args[:mysql_sync_config] if args.key?(:mysql_sync_config) @selected_objects = args[:selected_objects] if args.key?(:selected_objects) @sync_mode = args[:sync_mode] if args.key?(:sync_mode) @sync_parallel_level = args[:sync_parallel_level] if args.key?(:sync_parallel_level) @verify_connection_only = args[:verify_connection_only] if args.key?(:verify_connection_only) @verify_replication_only = args[:verify_replication_only] if args.key?(:verify_replication_only) end |