Class: Google::Apis::SqladminV1beta4::SqlSubOperationType

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

The sub operation type based on the operation type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SqlSubOperationType

Returns a new instance of SqlSubOperationType.



6056
6057
6058
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6056

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#maintenance_typeString

The type of maintenance to be performed on the instance. Corresponds to the JSON property maintenanceType

Returns:

  • (String)


6054
6055
6056
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6054

def maintenance_type
  @maintenance_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6061
6062
6063
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6061

def update!(**args)
  @maintenance_type = args[:maintenance_type] if args.key?(:maintenance_type)
end