Class: Google::Apis::SqladminV1beta4::Tier

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

A Google Cloud SQL service tier resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Tier

Returns a new instance of Tier.



6479
6480
6481
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6479

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disk_quotaFixnum

The maximum disk size of this tier in bytes. Corresponds to the JSON property DiskQuota

Returns:

  • (Fixnum)


6456
6457
6458
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6456

def disk_quota
  @disk_quota
end

#kindString

This is always sql#tier. Corresponds to the JSON property kind

Returns:

  • (String)


6466
6467
6468
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6466

def kind
  @kind
end

#ramFixnum

The maximum RAM usage of this tier in bytes. Corresponds to the JSON property RAM

Returns:

  • (Fixnum)


6461
6462
6463
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6461

def ram
  @ram
end

#regionArray<String>

The applicable regions for this tier. Corresponds to the JSON property region

Returns:

  • (Array<String>)


6471
6472
6473
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6471

def region
  @region
end

#tierString

An identifier for the machine type, for example, db-custom-1-3840. For related information, see Pricing. Corresponds to the JSON property tier

Returns:

  • (String)


6477
6478
6479
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6477

def tier
  @tier
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6484
6485
6486
6487
6488
6489
6490
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6484

def update!(**args)
  @disk_quota = args[:disk_quota] if args.key?(:disk_quota)
  @ram = args[:ram] if args.key?(:ram)
  @kind = args[:kind] if args.key?(:kind)
  @region = args[:region] if args.key?(:region)
  @tier = args[:tier] if args.key?(:tier)
end