Class: Google::Apis::SqladminV1beta4::User

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

A Cloud SQL user resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ User

Returns a new instance of User.



6756
6757
6758
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6756

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#database_rolesArray<String>

Optional. Role memberships of the user Corresponds to the JSON property databaseRoles

Returns:

  • (Array<String>)


6679
6680
6681
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6679

def database_roles
  @database_roles
end

#dual_password_typeString

Dual password status for the user. Corresponds to the JSON property dualPasswordType

Returns:

  • (String)


6684
6685
6686
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6684

def dual_password_type
  @dual_password_type
end

#etagString

This field is deprecated and will be removed from a future version of the API. Corresponds to the JSON property etag

Returns:

  • (String)


6689
6690
6691
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6689

def etag
  @etag
end

#hostString

Optional. The host from which the user can connect. For insert operations, host defaults to an empty string. For update operations, host is specified as part of the request URL. The host name cannot be updated after insertion. For a MySQL instance, it's required; for a PostgreSQL or SQL Server instance, it's optional. Corresponds to the JSON property host

Returns:

  • (String)


6698
6699
6700
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6698

def host
  @host
end

#iam_emailString

Optional. The full email for an IAM user. For normal database users, this will not be filled. Only applicable to MySQL database users. Corresponds to the JSON property iamEmail

Returns:

  • (String)


6704
6705
6706
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6704

def iam_email
  @iam_email
end

#iam_statusString

Indicates if a group is active or inactive for IAM database authentication. Corresponds to the JSON property iamStatus

Returns:

  • (String)


6709
6710
6711
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6709

def iam_status
  @iam_status
end

#instanceString

The name of the Cloud SQL instance. This does not include the project ID. Can be omitted for update because it is already specified on the URL. Corresponds to the JSON property instance

Returns:

  • (String)


6715
6716
6717
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6715

def instance
  @instance
end

#kindString

This is always sql#user. Corresponds to the JSON property kind

Returns:

  • (String)


6720
6721
6722
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6720

def kind
  @kind
end

#nameString

The name of the user in the Cloud SQL instance. Can be omitted for update because it is already specified in the URL. Corresponds to the JSON property name

Returns:

  • (String)


6726
6727
6728
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6726

def name
  @name
end

#passwordString

The password for the user. Corresponds to the JSON property password

Returns:

  • (String)


6731
6732
6733
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6731

def password
  @password
end

#password_policyGoogle::Apis::SqladminV1beta4::UserPasswordValidationPolicy

User level password validation policy. Corresponds to the JSON property passwordPolicy



6736
6737
6738
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6736

def password_policy
  @password_policy
end

#projectString

The project ID of the project containing the Cloud SQL database. The Google apps domain is prefixed if applicable. Can be omitted for update because it is already specified on the URL. Corresponds to the JSON property project

Returns:

  • (String)


6743
6744
6745
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6743

def project
  @project
end

#sqlserver_user_detailsGoogle::Apis::SqladminV1beta4::SqlServerUserDetails

Represents a Sql Server user on the Cloud SQL instance. Corresponds to the JSON property sqlserverUserDetails



6748
6749
6750
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6748

def sqlserver_user_details
  @sqlserver_user_details
end

#typeString

The user type. It determines the method to authenticate the user during login. The default is the database's built-in user type. Corresponds to the JSON property type

Returns:

  • (String)


6754
6755
6756
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6754

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6761
6762
6763
6764
6765
6766
6767
6768
6769
6770
6771
6772
6773
6774
6775
6776
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6761

def update!(**args)
  @database_roles = args[:database_roles] if args.key?(:database_roles)
  @dual_password_type = args[:dual_password_type] if args.key?(:dual_password_type)
  @etag = args[:etag] if args.key?(:etag)
  @host = args[:host] if args.key?(:host)
  @iam_email = args[:iam_email] if args.key?(:iam_email)
  @iam_status = args[:iam_status] if args.key?(:iam_status)
  @instance = args[:instance] if args.key?(:instance)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @password = args[:password] if args.key?(:password)
  @password_policy = args[:password_policy] if args.key?(:password_policy)
  @project = args[:project] if args.key?(:project)
  @sqlserver_user_details = args[:sqlserver_user_details] if args.key?(:sqlserver_user_details)
  @type = args[:type] if args.key?(:type)
end