Class: Google::Apis::SqladminV1beta4::User

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

A Cloud SQL user resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ User

Returns a new instance of User.



6628
6629
6630
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6628

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#database_rolesArray<String>

Optional. Role memberships of the user Corresponds to the JSON property databaseRoles

Returns:

  • (Array<String>)


6551
6552
6553
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6551

def database_roles
  @database_roles
end

#dual_password_typeString

Dual password status for the user. Corresponds to the JSON property dualPasswordType

Returns:

  • (String)


6556
6557
6558
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6556

def dual_password_type
  @dual_password_type
end

#etagString

This field is deprecated and will be removed from a future version of the API. Corresponds to the JSON property etag

Returns:

  • (String)


6561
6562
6563
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6561

def etag
  @etag
end

#hostString

Optional. The host from which the user can connect. For insert operations, host defaults to an empty string. For update operations, host is specified as part of the request URL. The host name cannot be updated after insertion. For a MySQL instance, it's required; for a PostgreSQL or SQL Server instance, it's optional. Corresponds to the JSON property host

Returns:

  • (String)


6570
6571
6572
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6570

def host
  @host
end

#iam_emailString

Optional. The full email for an IAM user. For normal database users, this will not be filled. Only applicable to MySQL database users. Corresponds to the JSON property iamEmail

Returns:

  • (String)


6576
6577
6578
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6576

def iam_email
  @iam_email
end

#iam_statusString

Indicates if a group is active or inactive for IAM database authentication. Corresponds to the JSON property iamStatus

Returns:

  • (String)


6581
6582
6583
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6581

def iam_status
  @iam_status
end

#instanceString

The name of the Cloud SQL instance. This does not include the project ID. Can be omitted for update because it is already specified on the URL. Corresponds to the JSON property instance

Returns:

  • (String)


6587
6588
6589
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6587

def instance
  @instance
end

#kindString

This is always sql#user. Corresponds to the JSON property kind

Returns:

  • (String)


6592
6593
6594
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6592

def kind
  @kind
end

#nameString

The name of the user in the Cloud SQL instance. Can be omitted for update because it is already specified in the URL. Corresponds to the JSON property name

Returns:

  • (String)


6598
6599
6600
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6598

def name
  @name
end

#passwordString

The password for the user. Corresponds to the JSON property password

Returns:

  • (String)


6603
6604
6605
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6603

def password
  @password
end

#password_policyGoogle::Apis::SqladminV1beta4::UserPasswordValidationPolicy

User level password validation policy. Corresponds to the JSON property passwordPolicy



6608
6609
6610
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6608

def password_policy
  @password_policy
end

#projectString

The project ID of the project containing the Cloud SQL database. The Google apps domain is prefixed if applicable. Can be omitted for update because it is already specified on the URL. Corresponds to the JSON property project

Returns:

  • (String)


6615
6616
6617
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6615

def project
  @project
end

#sqlserver_user_detailsGoogle::Apis::SqladminV1beta4::SqlServerUserDetails

Represents a Sql Server user on the Cloud SQL instance. Corresponds to the JSON property sqlserverUserDetails



6620
6621
6622
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6620

def sqlserver_user_details
  @sqlserver_user_details
end

#typeString

The user type. It determines the method to authenticate the user during login. The default is the database's built-in user type. Corresponds to the JSON property type

Returns:

  • (String)


6626
6627
6628
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6626

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6633
6634
6635
6636
6637
6638
6639
6640
6641
6642
6643
6644
6645
6646
6647
6648
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6633

def update!(**args)
  @database_roles = args[:database_roles] if args.key?(:database_roles)
  @dual_password_type = args[:dual_password_type] if args.key?(:dual_password_type)
  @etag = args[:etag] if args.key?(:etag)
  @host = args[:host] if args.key?(:host)
  @iam_email = args[:iam_email] if args.key?(:iam_email)
  @iam_status = args[:iam_status] if args.key?(:iam_status)
  @instance = args[:instance] if args.key?(:instance)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @password = args[:password] if args.key?(:password)
  @password_policy = args[:password_policy] if args.key?(:password_policy)
  @project = args[:project] if args.key?(:project)
  @sqlserver_user_details = args[:sqlserver_user_details] if args.key?(:sqlserver_user_details)
  @type = args[:type] if args.key?(:type)
end