Class: Google::Apis::SqladminV1beta4::User
- Inherits:
-
Object
- Object
- Google::Apis::SqladminV1beta4::User
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb
Overview
A Cloud SQL user resource.
Instance Attribute Summary collapse
-
#database_roles ⇒ Array<String>
Optional.
-
#dual_password_type ⇒ String
Dual password status for the user.
-
#etag ⇒ String
This field is deprecated and will be removed from a future version of the API.
-
#host ⇒ String
Optional.
-
#iam_email ⇒ String
Optional.
-
#iam_status ⇒ String
Indicates if a group is active or inactive for IAM database authentication.
-
#instance ⇒ String
The name of the Cloud SQL instance.
-
#kind ⇒ String
This is always
sql#user. -
#name ⇒ String
The name of the user in the Cloud SQL instance.
-
#password ⇒ String
The password for the user.
-
#password_policy ⇒ Google::Apis::SqladminV1beta4::UserPasswordValidationPolicy
User level password validation policy.
-
#project ⇒ String
The project ID of the project containing the Cloud SQL database.
-
#sqlserver_user_details ⇒ Google::Apis::SqladminV1beta4::SqlServerUserDetails
Represents a Sql Server user on the Cloud SQL instance.
-
#type ⇒ String
The user type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ User
constructor
A new instance of User.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ User
Returns a new instance of User.
6578 6579 6580 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6578 def initialize(**args) update!(**args) end |
Instance Attribute Details
#database_roles ⇒ Array<String>
Optional. Role memberships of the user
Corresponds to the JSON property databaseRoles
6501 6502 6503 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6501 def database_roles @database_roles end |
#dual_password_type ⇒ String
Dual password status for the user.
Corresponds to the JSON property dualPasswordType
6506 6507 6508 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6506 def dual_password_type @dual_password_type end |
#etag ⇒ String
This field is deprecated and will be removed from a future version of the API.
Corresponds to the JSON property etag
6511 6512 6513 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6511 def etag @etag end |
#host ⇒ String
Optional. The host from which the user can connect. For insert operations,
host defaults to an empty string. For update operations, host is specified
as part of the request URL. The host name cannot be updated after insertion.
For a MySQL instance, it's required; for a PostgreSQL or SQL Server instance,
it's optional.
Corresponds to the JSON property host
6520 6521 6522 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6520 def host @host end |
#iam_email ⇒ String
Optional. The full email for an IAM user. For normal database users, this will
not be filled. Only applicable to MySQL database users.
Corresponds to the JSON property iamEmail
6526 6527 6528 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6526 def iam_email @iam_email end |
#iam_status ⇒ String
Indicates if a group is active or inactive for IAM database authentication.
Corresponds to the JSON property iamStatus
6531 6532 6533 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6531 def iam_status @iam_status end |
#instance ⇒ String
The name of the Cloud SQL instance. This does not include the project ID. Can
be omitted for update because it is already specified on the URL.
Corresponds to the JSON property instance
6537 6538 6539 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6537 def instance @instance end |
#kind ⇒ String
This is always sql#user.
Corresponds to the JSON property kind
6542 6543 6544 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6542 def kind @kind end |
#name ⇒ String
The name of the user in the Cloud SQL instance. Can be omitted for update
because it is already specified in the URL.
Corresponds to the JSON property name
6548 6549 6550 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6548 def name @name end |
#password ⇒ String
The password for the user.
Corresponds to the JSON property password
6553 6554 6555 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6553 def password @password end |
#password_policy ⇒ Google::Apis::SqladminV1beta4::UserPasswordValidationPolicy
User level password validation policy.
Corresponds to the JSON property passwordPolicy
6558 6559 6560 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6558 def password_policy @password_policy end |
#project ⇒ String
The project ID of the project containing the Cloud SQL database. The Google
apps domain is prefixed if applicable. Can be omitted for update because it
is already specified on the URL.
Corresponds to the JSON property project
6565 6566 6567 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6565 def project @project end |
#sqlserver_user_details ⇒ Google::Apis::SqladminV1beta4::SqlServerUserDetails
Represents a Sql Server user on the Cloud SQL instance.
Corresponds to the JSON property sqlserverUserDetails
6570 6571 6572 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6570 def sqlserver_user_details @sqlserver_user_details end |
#type ⇒ String
The user type. It determines the method to authenticate the user during login.
The default is the database's built-in user type.
Corresponds to the JSON property type
6576 6577 6578 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6576 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6583 6584 6585 6586 6587 6588 6589 6590 6591 6592 6593 6594 6595 6596 6597 6598 |
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6583 def update!(**args) @database_roles = args[:database_roles] if args.key?(:database_roles) @dual_password_type = args[:dual_password_type] if args.key?(:dual_password_type) @etag = args[:etag] if args.key?(:etag) @host = args[:host] if args.key?(:host) @iam_email = args[:iam_email] if args.key?(:iam_email) @iam_status = args[:iam_status] if args.key?(:iam_status) @instance = args[:instance] if args.key?(:instance) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @password = args[:password] if args.key?(:password) @password_policy = args[:password_policy] if args.key?(:password_policy) @project = args[:project] if args.key?(:project) @sqlserver_user_details = args[:sqlserver_user_details] if args.key?(:sqlserver_user_details) @type = args[:type] if args.key?(:type) end |