Class: Google::Apis::SqladminV1beta4::UserPasswordValidationPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/sqladmin_v1beta4/classes.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb,
lib/google/apis/sqladmin_v1beta4/representations.rb

Overview

User level password validation policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserPasswordValidationPolicy

Returns a new instance of UserPasswordValidationPolicy.



6633
6634
6635
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6633

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_failed_attemptsFixnum

Number of failed login attempts allowed before user get locked. Corresponds to the JSON property allowedFailedAttempts

Returns:

  • (Fixnum)


6608
6609
6610
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6608

def allowed_failed_attempts
  @allowed_failed_attempts
end

#enable_failed_attempts_checkBoolean Also known as: enable_failed_attempts_check?

If true, failed login attempts check will be enabled. Corresponds to the JSON property enableFailedAttemptsCheck

Returns:

  • (Boolean)


6613
6614
6615
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6613

def enable_failed_attempts_check
  @enable_failed_attempts_check
end

#enable_password_verificationBoolean Also known as: enable_password_verification?

If true, the user must specify the current password before changing the password. This flag is supported only for MySQL. Corresponds to the JSON property enablePasswordVerification

Returns:

  • (Boolean)


6620
6621
6622
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6620

def enable_password_verification
  @enable_password_verification
end

#password_expiration_durationString

Expiration duration after password is updated. Corresponds to the JSON property passwordExpirationDuration

Returns:

  • (String)


6626
6627
6628
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6626

def password_expiration_duration
  @password_expiration_duration
end

#statusGoogle::Apis::SqladminV1beta4::PasswordStatus

Read-only password status. Corresponds to the JSON property status



6631
6632
6633
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6631

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6638
6639
6640
6641
6642
6643
6644
# File 'lib/google/apis/sqladmin_v1beta4/classes.rb', line 6638

def update!(**args)
  @allowed_failed_attempts = args[:allowed_failed_attempts] if args.key?(:allowed_failed_attempts)
  @enable_failed_attempts_check = args[:enable_failed_attempts_check] if args.key?(:enable_failed_attempts_check)
  @enable_password_verification = args[:enable_password_verification] if args.key?(:enable_password_verification)
  @password_expiration_duration = args[:password_expiration_duration] if args.key?(:password_expiration_duration)
  @status = args[:status] if args.key?(:status)
end